/*
 * Copyright (c) 2008 by inovat, Dipl.-Ing. H. C. Kni
 * ALL RIGHTS RESERVED.
 *
 * THIS SOFTWARE IS  PROVIDED  "AS IS"  AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF  MERCHANTABILITY  AND  FITNESS  FOR  A PARTICULAR  PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL inovat OR ITS CONTRIBUTORS BE
 * LIABLE FOR ANY  DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
 * OR CONSEQUENTIAL DAMAGES  (INCL., BUT NOT LIMITED TO, PROCUREMENT
 * OF SUBSTITUTE GOODS OR SERVICES;  LOSS OF USE, DATA, OR  PROFITS;
 * OR BUSINESS INTERRUPTION)  HOWEVER  CAUSED  AND  ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,  OR TORT (INCL.
 * NEGLIGENCE OR OTHERWISE)  ARISING  IN  ANY  WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */



package de.inovat.buv.gtm.datvew.lib;

//~ NICHT JDK IMPORTE =========================================================

import de.bsvrz.dav.daf.main.config.ConfigurationArea;
import de.bsvrz.dav.daf.main.config.ObjectTimeSpecification;
import de.bsvrz.dav.daf.main.config.SystemObject;
import de.bsvrz.dav.daf.main.config.SystemObjectType;

import de.inovat.buv.gtm.datvew.konstanten.KonstantenGTMGUIResource;

import org.eclipse.swt.graphics.Image;

//~ JDK IMPORTE ===============================================================

import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.List;

//~ KLASSEN ===================================================================

/**
 * Klasse beschreibt ein Objekttyp Objekt als interne Reprsentation.
 *
 * @author inovat
 * @author Dagmar Rostek (DR)
 * @version $Revision: 155 $ / $Date: 2014-10-07 11:11:48 +0200 (Di, 07 Okt 2014) $ / ($Author: LG $)
 */
public class DaVObjektTyp implements ISystemObjekt {

    /** Eltern KB. */
    private DaVKonfigurationsbereichsObjekt _parentKb;

    /** SystemobjektType das den Objekttyp reprsentiert. */
    private SystemObjectType _soType;

    //~ KONSTRUKTOREN  (und vom Konstruktor verwendete Methoden) ==============

    /**
     * Konstruktor inititalisiert die Attribute.
     * @param parentKb Eltern KB-Objekt.
     * @param so  Systemobjekt das den Objekttyp reprsentiert.
     */
    public DaVObjektTyp(DaVKonfigurationsbereichsObjekt parentKb, SystemObjectType so) {
        _parentKb = parentKb;
        _soType   = so;
    }

    //~ GET METHODEN ==========================================================

    @Override
    public Image getImage() {
        return KonstantenGTMGUIResource.ermittleImage(_soType);
    }

    /**
     * Die Methode erzeugt die Liste der internen Reprsentation der Objekttypsystemobjekte.
     * @return die Liste der erzeugten DaVSystemObjekte.
     */
    public List<DaVSystemObjekt> getObjekteListeDesSystemObjTyps() {
        List<SystemObject>    listeSystemObj    = new ArrayList<SystemObject>();
        List<DaVSystemObjekt> listeDaVSystemObj = new ArrayList<DaVSystemObjekt>();

        // TODO fr typ.application kommt doppelte Objekte!
        listeSystemObj.addAll(_soType.getObjects());

        for (SystemObject so : listeSystemObj) {
            DaVSystemObjekt davSO = new DaVSystemObjekt(this, so);

            listeDaVSystemObj.add(davSO);
        }

        // Sortiere:
        Collections.sort(listeDaVSystemObj, DatenVew.COMPARATOR_SO_PID);

        return listeDaVSystemObj;
    }

    /**
     * Die Methode bestimmt die Objekteliste der Objekttypen im Konfigurationsbereich.
     *
     * @return  Nach PID sortierte Liste von DaVSystemObjekten.
     */
    public List<DaVSystemObjekt> getObjekteListeDesSystemObjTypsImKB() {
        List<DaVSystemObjekt> listeDaVSystemObj = new ArrayList<DaVSystemObjekt>();

        if (_parentKb != null) {
            List<SystemObject>           listeSystemObj = new ArrayList<SystemObject>();
            Collection<SystemObjectType> soColleciton   = new ArrayList<SystemObjectType>();

            soColleciton.add(_soType);
            listeSystemObj.addAll(((ConfigurationArea) _parentKb.getSystemObjekt().getConfigurationArea()).getDirectObjects(soColleciton, ObjectTimeSpecification.valid()));

            for (SystemObject so : listeSystemObj) {
                listeDaVSystemObj.add(new DaVSystemObjekt(this, so));
            }

            // Sortiere:
            Collections.sort(listeDaVSystemObj, DatenVew.COMPARATOR_SO_PID);
        }

        return listeDaVSystemObj;
    }

    /**
     *     Getter fr Eigenschaft 'parentKb'.
     *
     *     @return Wert der Eigenschaft 'parentKb'.
     *
     *     @see #_parentKb
     */
    public DaVKonfigurationsbereichsObjekt getParentKb() {
        return _parentKb;
    }

    @Override
    public SystemObject getSystemObjekt() {
        return _soType;
    }
}


//~Formatiert mit 'inovat Kodierkonvention' am 22.02.13
