/*
 * Copyright (c) 2008 by inovat, Dipl.-Ing. H. C. Kni
 * ALL RIGHTS RESERVED.
 *
 * THIS SOFTWARE IS  PROVIDED  "AS IS"  AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF  MERCHANTABILITY  AND  FITNESS  FOR  A PARTICULAR  PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL inovat OR ITS CONTRIBUTORS BE
 * LIABLE FOR ANY  DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
 * OR CONSEQUENTIAL DAMAGES  (INCL., BUT NOT LIMITED TO, PROCUREMENT
 * OF SUBSTITUTE GOODS OR SERVICES;  LOSS OF USE, DATA, OR  PROFITS;
 * OR BUSINESS INTERRUPTION)  HOWEVER  CAUSED  AND  ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,  OR TORT (INCL.
 * NEGLIGENCE OR OTHERWISE)  ARISING  IN  ANY  WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */



package de.inovat.buv.gtm.datvew.lib;

//~ NICHT JDK IMPORTE =========================================================

import de.bsvrz.dav.daf.main.config.ObjectSet;
import de.bsvrz.dav.daf.main.config.SystemObject;
import de.bsvrz.dav.daf.main.impl.config.DafConfigurationObject;

import de.inovat.buv.gtm.datvew.konstanten.KonstantenGTMGUIResource;

import org.eclipse.swt.graphics.Image;

//~ JDK IMPORTE ===============================================================

import java.util.ArrayList;
import java.util.List;

//~ KLASSEN ===================================================================

/**
 * Die Klasse reprsentiert die interne Reprsentation des Datenverteiler Systemobjektes.
 *
 * @author inovat
 * @author Dagmar Rostek (DR)
 * @version $Revision: 155 $ / $Date: 2014-10-07 11:11:48 +0200 (Di, 07 Okt 2014) $ / ($Author: LG $)
 */
public class DaVSystemObjekt implements ISystemObjekt {

    /** Parent DaV-Typ. */
    private DaVObjektTyp _parentDavTyp;

    /** Systemobjekt dass das Systemobjekt reprsentiert. */
    private SystemObject _so;

    //~ KONSTRUKTOREN  (und vom Konstruktor verwendete Methoden) ==============

    /**
     * Konstruktor initialisiert die Attribute.
     * @param parentDavTyp   Parent DaV-Typ.
     * @param so   Systemobjekt.
     */
    public DaVSystemObjekt(DaVObjektTyp parentDavTyp, SystemObject so) {
        _parentDavTyp = parentDavTyp;
        _so           = so;
    }

    //~ GET METHODEN ==========================================================

    @Override
    public Image getImage() {
    	return KonstantenGTMGUIResource.ermittleImage(_so);
    }

    /**
     * Ermittle alle Menge des Elements.
     *
     * @return Alle Menge des Elements oder leere Liste.
     */
    public List<DaVMenge> getMengen() {
        List<DaVMenge> liste = new ArrayList<DaVMenge>();

        try {
            DafConfigurationObject conf = (DafConfigurationObject) _so;

            for (ObjectSet menge : conf.getObjectSets()) {
                liste.add(new DaVMenge(this, menge));
            }
        }
        catch (Exception ignored) {}

        return liste;
    }

    /**
     * Getter fr Eigenschaft 'parentDavTyp'.
     *
     * @return Wert der Eigenschaft 'parentDavTyp'.
     *
     * @see #_parentDavTyp
     */
    public DaVObjektTyp getParentDavTyp() {
        return _parentDavTyp;
    }

    @Override
    public SystemObject getSystemObjekt() {
        return _so;
    }
}


//~Formatiert mit 'inovat Kodierkonvention' am 20.02.13
