/*
 * Copyright (c) 2008 by inovat, Dipl.-Ing. H. C. Kni
 * ALL RIGHTS RESERVED.
 *
 * THIS SOFTWARE IS  PROVIDED  "AS IS"  AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF  MERCHANTABILITY  AND  FITNESS  FOR  A PARTICULAR  PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL inovat OR ITS CONTRIBUTORS BE
 * LIABLE FOR ANY  DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
 * OR CONSEQUENTIAL DAMAGES  (INCL., BUT NOT LIMITED TO, PROCUREMENT
 * OF SUBSTITUTE GOODS OR SERVICES;  LOSS OF USE, DATA, OR  PROFITS;
 * OR BUSINESS INTERRUPTION)  HOWEVER  CAUSED  AND  ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,  OR TORT (INCL.
 * NEGLIGENCE OR OTHERWISE)  ARISING  IN  ANY  WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */



package de.inovat.buv.gtm.datvew.lib;

//~ NICHT JDK IMPORTE =========================================================

import de.bsvrz.dav.daf.main.config.AttributeGroup;
import de.bsvrz.dav.daf.main.config.ConfigurationObject;
import de.bsvrz.dav.daf.main.config.SystemObject;
import de.bsvrz.dav.daf.main.Data;

import de.inovat.buv.gtm.datvew.konstanten.KonstantenGTMGUIResource;

import org.eclipse.swt.graphics.Image;

//~ KLASSEN ===================================================================

/**
 * Die Klasse reprsentiert die Fahrbahnobjekte.
 *
 * @author inovat
 * @author Dagmar Rostek (DR)
 * @version $Revision: 155 $ / $Date: 2014-10-07 11:11:48 +0200 (Di, 07 Okt 2014) $ / ($Author: LG $)
 */
public class Fahrbahnen implements ISystemObjekt, IInformation {

    /** Konfigurationsobjekt. */
    private ConfigurationObject _confObj;

    /** PID oder ID der FahrstreifenQuelle oder null. */
    private String _fsQuellePid;

    /** Lagenummer einer Fahrbahn. */
    private int _lageNr;

    /** Messquerschnitt. */
    private Messquerschnitt _messquerschnitt;

    //~ KONSTRUKTOREN  (und vom Konstruktor verwendete Methoden) ==============

    /**
     * Konstruktor erzeugt ein Fahrbahn objekt.
     * @param configurationObject   Konfigurationsobjekt.
     * @param messquerschnitt Messquerschnitt der Fahrbahn.
     */
    public Fahrbahnen(ConfigurationObject configurationObject, Messquerschnitt messquerschnitt) {
        _messquerschnitt = messquerschnitt;
        _confObj         = configurationObject;
        bestimmeLage();
        bestimmeFsQuellePid();
    }

    //~ METHODEN ==============================================================

    /**
     * Die Methode bestimmt PID oder ID der der FahrstreifenQuelle.
     */
    private void bestimmeFsQuellePid() {
        try {
            AttributeGroup atgFahrStreifen  = _confObj.getDataModel().getAttributeGroup("atg.fahrStreifen");
            Data           dataFahrStreifen = _confObj.getConfigurationData(atgFahrStreifen);
            SystemObject   so               = dataFahrStreifen.getReferenceValue("FahrStreifenQuelle").getSystemObject();

            _fsQuellePid = so.getPidOrId();
        }
        catch (Exception e) {
            _fsQuellePid = null;
        }
    }

    /**
     * Die Methode bestimmt die Lage des Fahrstreifens.
     */
    public void bestimmeLage() {
        AttributeGroup atgFahrStreifen  = _confObj.getDataModel().getAttributeGroup("atg.fahrStreifen");
        Data           dataFahrStreifen = _confObj.getConfigurationData(atgFahrStreifen);

        _lageNr = dataFahrStreifen.getUnscaledValue("Lage").intValue();
    }

    //~ GET METHODEN ==========================================================

    /**
     * Getter fr Eigenschaft 'fsQuellePid'.
     *
     * @return Wert der Eigenschaft 'fsQuellePid'.
     *
     * @see #_fsQuellePid
     */
    public String getFsQuellePid() {
        return _fsQuellePid;
    }

    @Override
    public Image getImage() {
        return KonstantenGTMGUIResource.ICON_GTM_FS;
    }

    @Override
    public String getInfo() {
        return _fsQuellePid;
    }

    /**
     * Getter Messquerschnitt zu der Fahrbahn.
     * @return  Messquerschnitt.
     */
    public Messquerschnitt getParentMQZuEinerFahrbahn() {
        return _messquerschnitt;
    }

    @Override
    public SystemObject getSystemObjekt() {
        return _confObj;
    }

    @Override
    public String getTitel() {
        return "ID der Fahrstreifenquelle";
    }

    //~ INNERE KLASSEN ========================================================

    /**
     *
     * Die innere Klasse reprsentiert ein Comparator fr die Fahrbahnen.
     *
     * @author inovat
     * @author Dagmar Rostek (DR)
     * @version $Revision: 155 $ / $Date: 2014-10-07 11:11:48 +0200 (Di, 07 Okt 2014) $ / ($Author: LG $)
     */
    static class FSComperatorVonAussenNachInnen implements java.util.Comparator<Fahrbahnen> {
        FSComperatorVonAussenNachInnen() {}

        //~ METHODEN ==========================================================

        public int compare(Fahrbahnen fs01, Fahrbahnen fs02) {
            int retValue = 0;

            if (fs01 != fs02) {
                retValue = (fs01._lageNr - fs02._lageNr);
            }

            return retValue;
        }

        public boolean equals(Object obj) {
            return (this == obj);
        }
    }
}


//~Formatiert mit 'inovat Kodierkonvention' am 14.03.12
