/*
 * @(#)Geraet.java   09.02.10
 *
 * Copyright (c) 2008 by inovat, Dipl.-Ing. H. C. Kni
 * ALL RIGHTS RESERVED.
 *
 * THIS SOFTWARE IS  PROVIDED  "AS IS"  AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF  MERCHANTABILITY  AND  FITNESS  FOR  A PARTICULAR  PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL inovat OR ITS CONTRIBUTORS BE
 * LIABLE FOR ANY  DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
 * OR CONSEQUENTIAL DAMAGES  (INCL., BUT NOT LIMITED TO, PROCUREMENT
 * OF SUBSTITUTE GOODS OR SERVICES;  LOSS OF USE, DATA, OR  PROFITS;
 * OR BUSINESS INTERRUPTION)  HOWEVER  CAUSED  AND  ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,  OR TORT (INCL.
 * NEGLIGENCE OR OTHERWISE)  ARISING  IN  ANY  WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */



package de.inovat.buv.gtm.datvew.tls;

//~ NICHT JDK IMPORTE =========================================================

import de.bsvrz.dav.daf.main.config.AttributeGroup;
import de.bsvrz.dav.daf.main.config.ConfigurationObject;
import de.bsvrz.dav.daf.main.config.DataModel;
import de.bsvrz.dav.daf.main.config.ObjectSet;
import de.bsvrz.dav.daf.main.config.SystemObject;
import de.bsvrz.dav.daf.main.Data;

import de.inovat.buv.gtm.datvew.Activator;
import de.inovat.buv.gtm.datvew.konstanten.KonstantenGTMGUIResource;
import de.inovat.buv.gtm.datvew.lib.DatenVew;
import de.inovat.buv.gtm.datvew.lib.ISystemObjekt;
import de.inovat.buv.inovat.lib.debug.Log;
import de.inovat.buv.projektlib.dav.DavDatenVew;

import org.eclipse.swt.graphics.Image;

import static de.inovat.buv.gtm.datvew.konstanten.KonstantenGTMGUIResource.TYP_KRI;
import static de.inovat.buv.gtm.datvew.konstanten.KonstantenGTMGUIResource.TYP_KRI2_b;
import static de.inovat.buv.gtm.datvew.konstanten.KonstantenGTMGUIResource.TYP_KRI2b;
import static de.inovat.buv.gtm.datvew.konstanten.KonstantenGTMGUIResource.TYP_SM;
import static de.inovat.buv.gtm.datvew.konstanten.KonstantenGTMGUIResource.TYP_UZ;
import static de.inovat.buv.gtm.datvew.konstanten.KonstantenGTMGUIResource.TYP_VIZ;
import static de.inovat.buv.gtm.datvew.konstanten.KonstantenGTMGUIResource.TYP_VRZ;

//~ JDK IMPORTE ===============================================================

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

//~ KLASSEN ===================================================================

/**
 * Die Klasse reprstentiert die interne Reprsentation eines Gertes.
 *
 * @author inovat
 * @author Dagmar Rostek (DR)
 * @version $Revision: 155 $ / $Date: 2014-10-07 11:11:48 +0200 (Di, 07 Okt 2014) $ / ($Author: LG $)
 */
public class Geraet implements ISystemObjekt {

    /** Der Gerte Typ. */
    private String _geraeteTyp;

    /** Nach Pid oder ID sortierte Liste alle Kinder-Eak oder leer. */
    private List<Eak> _listeKinderEak;

    /** Nach Pid oder ID sortierte Liste alle Kinder-Gerte. */
    private List<Geraet> _listeKinderGeraete;

    /** SystemObjekt Gert. */
    private SystemObject _soGeraet;

    /** Referenz auf das bergeordnete Gert */
    private Geraet _ueberGeordnetesGeraet;

    //~ KONSTRUKTOREN  (und vom Konstruktor verwendete Methoden) ==============

    /**
     * Erzeugt eine Instanz der Klasse Geraet.
     *
     * @param so SystemObject.
     * @param ueberGeordnetesGeraet bergeordnetes Geraet.
     */
    public Geraet(SystemObject so, Geraet ueberGeordnetesGeraet) {
        _soGeraet              = so;
        _ueberGeordnetesGeraet = ueberGeordnetesGeraet;

        //
        bestimmeGeraetTyp();

        // Initialisiere alle Kinder:
        initKinder();
    }

    //~ METHODEN ==============================================================

    /**
     * Die Methode bestimmt den Gertetyp des Gertes. Bei dem
     * Gertetyp kann es sich um folgende Typen handeln:
     */
    private void bestimmeGeraetTyp() {
        if (_soGeraet.isOfType(TYP_VIZ)) {
            _geraeteTyp = TYP_VIZ;
        } else if (_soGeraet.isOfType(TYP_UZ)) {
            _geraeteTyp = TYP_UZ;
        } else if (_soGeraet.isOfType(TYP_VRZ)) {
            _geraeteTyp = TYP_VRZ;
        } else if (_soGeraet.isOfType(TYP_KRI)) {
            _geraeteTyp = TYP_KRI;
        } else if (_soGeraet.isOfType(TYP_KRI2b)) {
            _geraeteTyp = TYP_KRI2b;
        } else if (_soGeraet.isOfType(TYP_KRI2_b)) {
            _geraeteTyp = TYP_KRI2_b;
        } else if (_soGeraet.isOfType(TYP_SM)) {
            _geraeteTyp = TYP_SM;
        } else {
            _geraeteTyp = "";
            Log.zeigeInterneMeldung(Activator.PLUGIN_ID, new Exception(  //
                String.format("Unbekannter Typ <%s> fr das Gert <%s>", _soGeraet.getType().getPidOrNameOrId(), _soGeraet.getPidOrNameOrId())));
        }
    }

    /**
     * Ermittle alle Kinder.
     *
     * @return Alle Kinder.
     */
    public Object[] ermittleKinder() {
        List<Object> listeKinder = new ArrayList<Object>();

        listeKinder.addAll(_listeKinderGeraete);
        listeKinder.addAll(_listeKinderEak);

        return listeKinder.toArray();
    }

    //~ GET METHODEN ==========================================================

    @Override
    public Image getImage() {
        return KonstantenGTMGUIResource.ermittleImage(_soGeraet);
    }

    @Override
    public SystemObject getSystemObjekt() {
        return _soGeraet;
    }

    /**
     *     Getter fr Eigenschaft 'ueberGeordnetesGeraet'.
     *
     *     @return Wert der Eigenschaft 'ueberGeordnetesGeraet'.
     *
     *     @see #_ueberGeordnetesGeraet
     */
    public Geraet getUeberGeordnetesGeraet() {
        return _ueberGeordnetesGeraet;
    }

    //~ METHODEN ==============================================================

    /**
     * Initialisiere die Liste aller Kinder.
     */
    private void initKinder() {
        _listeKinderGeraete = new ArrayList<Geraet>();
        _listeKinderEak     = new ArrayList<Eak>();

        // -----------------------------------------------------------------------------
        if (!_geraeteTyp.equals(TYP_SM)) {
            DataModel davKonf = DavDatenVew.getInstanz().getDav().getDataModel();
            Data[]    arConfDaten;

            // Hole Konfigurationsobjekt zum aktuellem Gert
            ConfigurationObject aktuellesGeraet = (ConfigurationObject) _soGeraet;

            // Hole die Menge der Anschlusspunktobjekte zu dem Gert
            ObjectSet mengeAPGeraet = aktuellesGeraet.getObjectSet("AnschlussPunkteGert");

            // Fr jeden Anschlusspunkt bestimme die Anschlusspunktkommunikationspartner
            if (mengeAPGeraet != null) {
                for (SystemObject apkp : mengeAPGeraet.getElements()) {
                    ConfigurationObject konfigurationsObjApkp = (ConfigurationObject) apkp;
                    ObjectSet           mengeAPKP             = konfigurationsObjApkp.getObjectSet("AnschlussPunkteKommunikationsPartner");  // Name der Menge, nicht PID !

                    if (mengeAPKP != null) {
                        AttributeGroup atgAnschlussPKommPartner = davKonf.getAttributeGroup("atg.anschlussPunktKommunikationsPartner");

                        arConfDaten = davKonf.getConfigurationData(mengeAPKP.getElements(), atgAnschlussPKommPartner);

                        for (Data data : arConfDaten) {
                            Geraet kindGeraet = new Geraet(data.getReferenceValue("KommunikationsPartner").getSystemObject(), this);

                            _listeKinderGeraete.add(kindGeraet);
                        }
                    }
                }
            }

            // -----------------------------------------------------------------------------
            // KRI2b oder KRI2_b:
            // Diese Gerte knne auch Kinder von Typ Eak haben:
            if ((_soGeraet.isOfType(TYP_KRI2b)) || ((_soGeraet.isOfType(TYP_KRI2_b)))) {

                // if ((_geraeteTyp.equals("KRI2b")) || ((_geraeteTyp.equals("KRI2_b")))) {
                ConfigurationObject confEak = ((ConfigurationObject) _soGeraet);
                ObjectSet           setEak  = confEak.getObjectSet("Eak");

                if (setEak != null) {
                    for (SystemObject soEak : setEak.getElements()) {
                        Eak eak = new Eak(soEak, this);

                        _listeKinderEak.add(eak);
                    }
                }
            }
        }

        // -----------------------------------------------------------------------------
        // SM
        else {
            ConfigurationObject confEak = ((ConfigurationObject) _soGeraet);
            ObjectSet           setEak  = confEak.getObjectSet("Eak");

            /*
            // TODO Log
            System.out.println(String.format("SM: %s %s %s Typ: %s %s",                                   //
                                             _soGeraet.getId(), _soGeraet.getPid(), _soGeraet.getName(),  //
                                             _soGeraet.getType().getId(), _soGeraet.getType().getPidOrNameOrId()));
                                             */

            //
            if (setEak != null) {
                for (SystemObject soEak : setEak.getElements()) {
                    Eak eak = new Eak(soEak, this);

                    _listeKinderEak.add(eak);
                }
            }
        }

        // -----------------------------------------------------------------------------
        // Sortiere:
        Collections.sort(_listeKinderGeraete, DatenVew.COMPARATOR_SO_NAME);
        Collections.sort(_listeKinderEak, DatenVew.COMPARATOR_SO_NAME);
    }
}


//~Formatiert mit 'inovat Kodierkonvention' am 22.02.13
