/*
 * @(#)ReflexionFunktionen.java   18.09.09
 *
 * Copyright (c) 2008 by inovat, Dipl.-Ing. H. C. Kni
 * ALL RIGHTS RESERVED.
 *
 * THIS SOFTWARE IS  PROVIDED  "AS IS"  AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF  MERCHANTABILITY  AND  FITNESS  FOR  A PARTICULAR  PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL inovat OR ITS CONTRIBUTORS BE
 * LIABLE FOR ANY  DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
 * OR CONSEQUENTIAL DAMAGES  (INCL., BUT NOT LIMITED TO, PROCUREMENT
 * OF SUBSTITUTE GOODS OR SERVICES;  LOSS OF USE, DATA, OR  PROFITS;
 * OR BUSINESS INTERRUPTION)  HOWEVER  CAUSED  AND  ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,  OR TORT (INCL.
 * NEGLIGENCE OR OTHERWISE)  ARISING  IN  ANY  WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package de.inovat.buv.inovat.lib.reflexion;

//~ NICHT JDK IMPORTE =========================================================

import de.inovat.buv.inovat.lib.Activator;
import de.inovat.buv.inovat.lib.debug.Log;

import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;

//~ KLASSEN ===================================================================

/**
 * Klasse definiert die ReflexionHilfsfunktionen.
 *
 * @author inovat
 * @author Liliya Givorgizova (LG)
 * @version $Revision: 12 $ / $Date: 2013-09-24 13:23:48 +0200 (Di, 24. Sep 2013) $ / ($Author: LG $)
 */
public class ReflexionFunktionen {

    /**
     * Ruft die Funktion mit dem angegebenen Namen fr die angegebene Instanz auf.
     *
     * @param funktionName Name der Funktion.
     * @param klasseInstanz Instanz der Klasse, aus der die Funktion aufgerufen wird.
     *
     * @return Ergebnis der Funktion oder leeres String, falls ein Exception aufgetreten ist.
     */
    static public Object aufrufenFunktion(String funktionName, Object klasseInstanz) {

        //
        Method funktion;
        Object ergebnis = "";

        // Definiere die Funktion und rufe die auf:
        try {
            funktion = klasseInstanz.getClass().getDeclaredMethod(funktionName, new Class[0]);
            ergebnis = funktion.invoke(klasseInstanz);
        }
        catch (SecurityException e) {
            Log.zeigeInterneMeldung(Activator.PLUGIN_ID, e);
        }
        catch (NoSuchMethodException e) {
            Log.zeigeInterneMeldung(Activator.PLUGIN_ID, e);
        }                            
        catch (IllegalArgumentException e) {
            Log.zeigeInterneMeldung(Activator.PLUGIN_ID, e);
        }
        catch (IllegalAccessException e) {
            Log.zeigeInterneMeldung(Activator.PLUGIN_ID, e);
        }
        catch (InvocationTargetException e) {
            Log.zeigeInterneMeldung(Activator.PLUGIN_ID, e);
        }

        return ergebnis;
    }

    /**
     * Ruft die get-Funktion fr die angegebene Variable auf.
     *
     * Um den Namen der Funktion zu ermitteln,
     * wird der Variablennamen so umgewandelt, dass die 1.Buchstabe gross geschrieben wird,
     * und falls erster Buchstabe '_' ist, wird die weggelassen.
     * Das Prfix der get-Funktion hngt vom Variablentyp
     * ('ist' - falls die Variable vom logischen Typ ist, 'get' - sonst).
     *
     * @param variablenName Variablennamen.
     * @param istVariableBoolean Typ der Variable ist fr das Prfix der get-Funktion ntig.
     * @param klasseInstanz Instanz der Klasse, aus der die get-Funktion aufgerufen wird.
     *
     * @return Ergebnis der get-Funktion
     * oder leeres String, falls ein Exception aufgetreten ist,
     * oder String "null", falls null das Ergebnis der getFunktion ist.
     */
    static public Object aufrufenGetFunktion(String variablenName, boolean istVariableBoolean, Object klasseInstanz) {
        String variable = variablenName;

        if (variablenName.subSequence(0, 1).equals("_")) {
            variable = variable.substring(1);
        }

        // ndere den Namen variableName, so, dass 1.Buchstabe gross geschrieben wird:
        variable = variable.substring(0, 1).toUpperCase() + variable.substring(1);

        String getFunktion;

        if (istVariableBoolean) {
            getFunktion = "is" + variable;
        } else {
            getFunktion = "get" + variable;
        }

        Object ergebnis = aufrufenFunktion(getFunktion, klasseInstanz);

        if (ergebnis == null) {
            ergebnis = "null";
        }

        return ergebnis;
    }
}


//~Formatiert mit 'inovat Kodierkonvention' am 18.02.10
