/*
 * @(#)ImportBenutzerEinstellungenVerwaltung.java   03.09.10
 *
 * Copyright (c) 2008 by inovat, Dipl.-Ing. H. C. Kni
 * ALL RIGHTS RESERVED.
 *
 * THIS SOFTWARE IS  PROVIDED  "AS IS"  AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF  MERCHANTABILITY  AND  FITNESS  FOR  A PARTICULAR  PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL inovat OR ITS CONTRIBUTORS BE
 * LIABLE FOR ANY  DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
 * OR CONSEQUENTIAL DAMAGES  (INCL., BUT NOT LIMITED TO, PROCUREMENT
 * OF SUBSTITUTE GOODS OR SERVICES;  LOSS OF USE, DATA, OR  PROFITS;
 * OR BUSINESS INTERRUPTION)  HOWEVER  CAUSED  AND  ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,  OR TORT (INCL.
 * NEGLIGENCE OR OTHERWISE)  ARISING  IN  ANY  WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */



package de.inovat.buv.plugin.gtm.bast.gui;

//~ NICHT JDK IMPORTE =========================================================

import de.inovat.buv.inovat.lib.debug.Log;
import de.inovat.buv.plugin.gtm.bast.Activator;
import de.inovat.buv.plugin.gtm.bast.KonstantenGTMBast;
import de.inovat.buv.projektlib.speicher.GrundEinstellungen;

import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.ui.PlatformUI;

//~ JDK IMPORTE ===============================================================

import java.beans.XMLDecoder;
import java.beans.XMLEncoder;

import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;

import java.util.HashMap;
import java.util.Hashtable;
import java.util.Map;

//~ KLASSEN ===================================================================

/**
 *
 * Die Klasse Verwaltet die Importbenutzereinstellungen.
 *
 * @author inovat
 * @author Dagmar Rostek (DR)
 * @version $Revision: 88 $ / $Date: 2012-03-09 16:20:38 +0100 (Fr, 09 Mrz 2012) $ / ($Author: LG $)
 */
public class ImportBenutzerEinstellungenVerwaltung {

    /** Map mit allen ImportBenutzerEinstellungen. */
    private Map<String, ImportBenutzerEinstellungen> _mapImportBenutzerEinstellungen = new HashMap<String, ImportBenutzerEinstellungen>();

    //~ KONSTRUKTOREN  (und vom Konstruktor verwendete Methoden) ==============

    /**
     * WICHTIG_: Die Methode darf nicht aufgerufen werden. Die wird von XMLDecoder bentigt.
     *
     * Erzeugt eine Instanz der Klasse Sortierung.
     */
    public ImportBenutzerEinstellungenVerwaltung() {}

    public ImportBenutzerEinstellungenVerwaltung(Map<String, ImportBenutzerEinstellungen> mapImportBenutzerEinstellungen) {
        ladeAlleImportBenutzerEinstellungen(KonstantenGTMBast.ALLE_IMPORT_EINSTELLUNGEN);
        _mapImportBenutzerEinstellungen.putAll(mapImportBenutzerEinstellungen);
    }

    //~ GET METHODEN ==========================================================

    /**
     * Getter der Eigenschaft 'mapImportBenutzerEinstellungen'.
     * @return Map der ImportBenutzereinstellungen.
     */
    public Map<String, ImportBenutzerEinstellungen> getMapImportBenutzerEinstellungen() {
        return _mapImportBenutzerEinstellungen;
    }

    //~ METHODEN ==============================================================

    /**
     * Die Methode liest alle ExportBenutzerEinstellunge ein.
     */
    @SuppressWarnings("unchecked")
    private void ladeAlleImportBenutzerEinstellungen(String alleExportEinstellungenID) {
        _mapImportBenutzerEinstellungen = new Hashtable<String, ImportBenutzerEinstellungen>();

        // Ermittle die String-Representation des Maps aus dem Speicher:
        String mapString = GrundEinstellungen.ermittleParameterWertFuerBenutzer(alleExportEinstellungenID);

        if (mapString != null) {

            // Dekodiere den Parameter:
            try {
                ByteArrayInputStream input     = new ByteArrayInputStream(mapString.getBytes());
                XMLDecoder           xml       = new XMLDecoder(input);
                Object               mapObjekt = xml.readObject();

                xml.close();

                if (mapObjekt instanceof Map) {
                    try {
                        _mapImportBenutzerEinstellungen = (Hashtable<String, ImportBenutzerEinstellungen>) mapObjekt;
                    }
                    catch (Exception e) {
                        Log.zeige(Log.erzeugeMeldung(Log.FEHLER, Activator.PLUGIN_ID, "Importeinstellungen knnen nicht geladen werden!", e));
                    }
                }
            }
            catch (Exception e) {
                Log.zeige(Log.erzeugeMeldung(Log.FEHLER, Activator.PLUGIN_ID, "Importeinstellungen knnen nicht geladen werden!", e));
            }
        }
    }

    //~ SET METHODEN ==========================================================

    /**
     * Setter ImportBenutzereinstellungen.
     * @param mapImportBenutzerEinstellungen mapImportBenutzerEinstellungen.
     */
    public void setMapImportBenutzerEinstellungen(Map<String, ImportBenutzerEinstellungen> mapImportBenutzerEinstellungen) {
        _mapImportBenutzerEinstellungen = mapImportBenutzerEinstellungen;
    }

    //~ METHODEN ==============================================================

    /**
     * Speichert den Inhalt von _mapExportBenutzerEinstellungen in XML format.
     * @param alleImportEinstellungenID - ID des Parameters fr den Speicher.
     */
    public void speichereImportVerwaltungen(String alleImportEinstellungenID) {

        // Kodiere _tabellenVerwaltungsMap ber XML Encoder:
        ByteArrayOutputStream out = new ByteArrayOutputStream();
        XMLEncoder            xml = new XMLEncoder(out);

        xml.writeObject(_mapImportBenutzerEinstellungen);
        xml.close();

        boolean gespeichert = GrundEinstellungen.speichereParameterFuerBenutzer(alleImportEinstellungenID, out.toString(), "BASt-Import Einstellungen");

        if (!gespeichert) {
            MessageDialog.openError(PlatformUI.getWorkbench().getDisplay().getActiveShell(), "Fehler beim Speichern", "Es ist ein Fehler beim Speichern der BASt-Band Exporteinstellungen aufgetretten. Details siehe unten im Meldungsfenster.");
        }
    }
}


//~Formatiert mit 'inovat Kodierkonvention' am 05.11.13
