/*
 * @(#)HelpContextProvider.java   18.02.11
 *
 * Copyright (c) 2008 by inovat, Dipl.-Ing. H. C. Kni
 * ALL RIGHTS RESERVED.
 *
 * THIS SOFTWARE IS  PROVIDED  "AS IS"  AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF  MERCHANTABILITY  AND  FITNESS  FOR  A PARTICULAR  PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL inovat OR ITS CONTRIBUTORS BE
 * LIABLE FOR ANY  DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
 * OR CONSEQUENTIAL DAMAGES  (INCL., BUT NOT LIMITED TO, PROCUREMENT
 * OF SUBSTITUTE GOODS OR SERVICES;  LOSS OF USE, DATA, OR  PROFITS;
 * OR BUSINESS INTERRUPTION)  HOWEVER  CAUSED  AND  ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,  OR TORT (INCL.
 * NEGLIGENCE OR OTHERWISE)  ARISING  IN  ANY  WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */



package de.inovat.buv.plugin.gtm.bast.hilfe;

//~ NICHT JDK IMPORTE =========================================================

import org.eclipse.help.*;

import de.inovat.buv.plugin.gtm.bast.Activator;


//~ KLASSEN ===================================================================

/**
 * Klasse verwaltet die KontextHilfe fr das BASt-Plugin.
 *
 * @author inovat
 * @author Liliya Givorgizova (LG)
 * @version $Revision: 88 $ / $Date: 2012-03-09 16:20:38 +0100 (Fr, 09 Mrz 2012) $ / ($Author: LG $)
 */
public class HelpContextProvider extends AbstractContextProvider {

    /**
     * Ermittle HelpResource.
     *
     * @param name Name.
     * @param anker Anker.
     *
     * @return HelpResource
     */
    private IHelpResource ermittleHelpResource(final String name, final String anker) {
        return new IHelpResource() {
            @Override
            public String getLabel() {
                return name;
            }
            @Override
            public String getHref() {
                return HilfeVew.getInstanz().ermittleHrefGanz(anker);
            }
        };
    }

    //~ GET METHODEN ==========================================================

    @Override
    public IContext getContext(String id, String locale) {
        final String anker = HilfeVew.getInstanz().ermittleAnkerFuerId(id);
        final String name  = HilfeVew.getInstanz().ermittleNameFuerAnker(anker);

        return new IContext() {
            @Override
            public String getText() {
                if (name != null) {
                    return "Hilfe zu " + name;
                } else {
                    return "Hilfe zu " + anker + " wurde nicht gefunden";
                }
            }
            @Override
            public IHelpResource[] getRelatedTopics() {
                if (name != null) {
                    return new IHelpResource[] { ermittleHelpResource(name, anker) };
                } else {
                    return new IHelpResource[0];
                }
            }
        };
    }

    @Override
    public String[] getPlugins() {
        return new String[] { Activator.PLUGIN_ID };
    }
}


//~Formatiert mit 'inovat Kodierkonvention' am 18.02.11
