/*
 * @(#)HilfeVew.java   18.02.11
 *
 * Copyright (c) 2008 by inovat, Dipl.-Ing. H. C. Kni
 * ALL RIGHTS RESERVED.
 *
 * THIS SOFTWARE IS  PROVIDED  "AS IS"  AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF  MERCHANTABILITY  AND  FITNESS  FOR  A PARTICULAR  PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL inovat OR ITS CONTRIBUTORS BE
 * LIABLE FOR ANY  DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
 * OR CONSEQUENTIAL DAMAGES  (INCL., BUT NOT LIMITED TO, PROCUREMENT
 * OF SUBSTITUTE GOODS OR SERVICES;  LOSS OF USE, DATA, OR  PROFITS;
 * OR BUSINESS INTERRUPTION)  HOWEVER  CAUSED  AND  ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,  OR TORT (INCL.
 * NEGLIGENCE OR OTHERWISE)  ARISING  IN  ANY  WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */



package de.inovat.buv.plugin.gtm.lzzs.hilfe;

//~ NICHT JDK IMPORTE =========================================================

import de.inovat.buv.inovat.lib.debug.Log;
import de.inovat.buv.plugin.gtm.lzzs.Activator;

//~ JDK IMPORTE ===============================================================

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

//~ KLASSEN ===================================================================

/**
 * Klasse verwaltet alle Hilfe-Resource abhngig vom geladenen Bundesland.
 *
 * Hier sind alle Anker fr die HilfeTexte als Konstanten definiert.
 * Im ARRAY_HILFE_INHALT ist den HilfeInhalt bestimmt.
 *
 * Als SingleTon realisiert.
 *
 * @author inovat
 * @author Liliya Givorgizova (LG)
 * @version $Revision: 116 $ / $Date: 2012-03-20 17:08:24 +0100 (Di, 20 Mrz 2012) $ / ($Author: LG $)
 */
public class HilfeVew {
    public static final String ANKER_AGGREGATION = "ANKER_AGGREGATION";
    public static final String ANKER_MP_PLUGIN   = "ANKER_MP_PLUGIN";
    public static final String ANKER_PUFFERABRUF = "ANKER_PUFFERABRUF";

    /** Index vom ID im HilfeMap-Eintrag. */
    private static final int INDEX_MAP_ID = 0;

    /** Index vom Name im HilfeMap-Eintrag. */
    private static final int INDEX_MAP_NAME = 1;

    /** Einzige Instanz der Klasse. */
    private static HilfeVew hilfeInstanz = new HilfeVew();

    /**
     * Liste des gesamten HilfeInhalts: Anker, Name.
     * In dieser Reihenfolge wird der HilfeInhalt angezeigt.
     */
    private static List<String[]> LISTE_HILFE_INHALT;

    //~ FELDER ================================================================

    /** Lokale der Hilfe. */
    private String _lokale = "de_DE";

    /** HilfeDatei, die vom gestarteten Bundesland abhngig ist. */
    private String _dateiHilfe;

    /**
     * Menge der Informationen zur allen Hilfeeintrgen.
     *
     * Key: Anker
     * Value: Information: ID, Name.
     */
    private Map<String, String[]> _mapHilfeInfo;

    /** Titel des HilfeInhalts. */
    private String _titelHilfeInhalt;

    //~ KONSTRUKTOREN  (und vom Konstruktor verwendete Methoden) ==============

    /**
     * Erzeugt einzige Instanz der Klasse HilfeVew.
     */
    private HilfeVew() {

        //
        _dateiHilfe = "hilfe/texte/Benutzerhandbuch_LZZS.htm";

        //
        _titelHilfeInhalt = "Hilfe LZZS";

        //
        initialisiereHilfeInhalt();

        //
        _mapHilfeInfo = new HashMap<String, String[]>();

        String anker;
        String name;
        String id;

        for (String[] info : LISTE_HILFE_INHALT) {
            anker = info[0];
            name  = info[1];
            id    = String.format("%s.%s", Activator.PLUGIN_ID, anker);
            _mapHilfeInfo.put(anker, new String[] { id, name });
        }
    }

    //~ METHODEN ==============================================================

    /**
     * Ermittle den Anker fr angegebene Hilfe-Id.
     *
     * @param id Hilfe-ID.
     *
     * @return Anker fr angegebene Hilfe-Id.
     */
    protected String ermittleAnkerFuerId(String id) {
        try {
            return id.substring(Activator.PLUGIN_ID.length() + 1);
        }
        catch (Exception e) {
            Log.zeige(Log.erzeugeMeldung(Log.FEHLER, Activator.PLUGIN_ID, "Anker kann nicht fr <" + id + "> definiert werden.", e));

            return id;
        }
    }

    /**
     * Ermittle die ganze Referenzangabe fr den Anker.
     *
     * @param anker Anker.
     *
     * @return Ganze Referenzangabe fr den Anker.
     */
    protected String ermittleHrefGanz(String anker) {
        return Activator.PLUGIN_ID + "/" + ermittleHrefOhnePluginId(anker);
    }

    /**
     * Ermittle die Referenzangabe fr den Anker ohne die PluginID am Anfang.
     *
     * @param anker Anker.
     *
     * @return Referenzangabe fr den Anker ohne die PluginID am Anfang.
     */
    protected String ermittleHrefOhnePluginId(String anker) {
        return _dateiHilfe + "#" + anker;
    }

    /**
     * Ermittle Hilfe-Id fr angegebenen Anker.
     *
     * @param anker Anker.
     *
     * @return Hilfe-Id fr angegebenen Anker oder null, falls nicht gefunden wird.
     */
    public String ermittleIdFuerAnker(String anker) {
        try {
            return _mapHilfeInfo.get(anker)[INDEX_MAP_ID];
        }
        catch (Exception e) {
            Log.zeige(Log.erzeugeMeldung(Log.FEHLER, Activator.PLUGIN_ID, "Hilfe-ID kann nicht fr <" + anker + "> definiert werden.", e));

            return null;
        }
    }

    /**
     * Ermittle die Liste aller definierten Anker.
     *
     * @return Liste aller definierten Anker.
     */
    protected List<String> ermittleListeAnker() {
        List<String> liste = new ArrayList<String>();

        for (String[] ar : LISTE_HILFE_INHALT) {
            liste.add(ar[0]);
        }

        return liste;
    }

    /**
     * Ermittle den Name fr den angegebenen Anker.
     *
     * @param anker Anker.
     *
     * @return Name fr den angegebenen Anker oder null, falls nicht gefunden wird.
     */
    protected String ermittleNameFuerAnker(String anker) {
        try {
            return _mapHilfeInfo.get(anker)[INDEX_MAP_NAME];
        }
        catch (Exception e) {
            Log.zeige(Log.erzeugeMeldung(Log.FEHLER, Activator.PLUGIN_ID, "Name kann nicht fr <" + anker + "> definiert werden.", e));

            return null;
        }
    }

    //~ GET METHODEN ==========================================================

    /**
     * Ermittelt einzige Instanz der Klasse HilfeVew.
     *
     * @return Einzige Instanz der Klasse HilfeVew
     */
    public static HilfeVew getInstanz() {
        return hilfeInstanz;
    }

    /**
     * Getter fr Eigenschaft 'lokale'.
     *
     * @return Wert der Eigenschaft 'lokale'.
     *
     * @see #_lokale
     */
    protected String getLokale() {
        return _lokale;
    }

    /**
     * Getter fr Eigenschaft 'titelHilfeInhalt'.
     *
     * @return Wert der Eigenschaft 'titelHilfeInhalt'.
     *
     * @see #_titelHilfeInhalt
     */
    protected String getTitelHilfeInhalt() {
        return _titelHilfeInhalt;
    }

    //~ METHODEN ==============================================================

    /**
     * Initialisiere die Liste des gesamten HilfeInhalts: Anker, Name.
     * In dieser Reihenfolge wird der HilfeInhalt angezeigt.
     */
    private void initialisiereHilfeInhalt() {
        LISTE_HILFE_INHALT = new ArrayList<String[]>();
        LISTE_HILFE_INHALT.add(new String[] { ANKER_MP_PLUGIN, "Plugin LZZS" });
        LISTE_HILFE_INHALT.add(new String[] { ANKER_AGGREGATION, "Aggregation" });
        LISTE_HILFE_INHALT.add(new String[] { ANKER_PUFFERABRUF, "Pufferabruf Achslastdaten / Langzeitdaten" });
    }
}


//~Formatiert mit 'inovat Kodierkonvention' am 20.03.12
