/*
 * Copyright (c) 2008 by inovat, Dipl.-Ing. H. C. Kni
 * ALL RIGHTS RESERVED.
 *
 * THIS SOFTWARE IS  PROVIDED  "AS IS"  AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF  MERCHANTABILITY  AND  FITNESS  FOR  A PARTICULAR  PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL inovat OR ITS CONTRIBUTORS BE
 * LIABLE FOR ANY  DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
 * OR CONSEQUENTIAL DAMAGES  (INCL., BUT NOT LIMITED TO, PROCUREMENT
 * OF SUBSTITUTE GOODS OR SERVICES;  LOSS OF USE, DATA, OR  PROFITS;
 * OR BUSINESS INTERRUPTION)  HOWEVER  CAUSED  AND  ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,  OR TORT (INCL.
 * NEGLIGENCE OR OTHERWISE)  ARISING  IN  ANY  WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */



package de.inovat.buv.plugin.gtm.navigation.tabellen;

//~ NICHT JDK IMPORTE =========================================================

import java.util.Arrays;

import de.bsvrz.buv.rw.basislib.tabellen.ITabellenZeile;

//~ KLASSEN ===================================================================

/**
 * Die Klasse reprsentiert ein Zeilenobjekt.
 * @author inovat
 * @author Dagmar Rostek (DR)
 * @version $Revision: 155 $ / $Date: 2014-10-07 11:11:48 +0200 (Di, 07 Okt 2014) $ / ($Author: LG $)
 */
public class ZeilenObjekt implements ITabellenZeile {

    /**
     * Attributliste mit der aktuellen Ausprgung der Attribute des jeweiligen
     * Bezugsobjektes.
     */
    private Object[] _attributListe = null;

  
	/**
     * Objekt, zu dem diese Zeile gehrt. Knnte z.B. ein Systemobjekt sein.
     */
    private Object _zeilenObjekt = null;

    //~ KONSTRUKTOREN  (und vom Konstruktor verwendete Methoden) ==============

    public ZeilenObjekt(Object zeilenObjekt, Object[] attributListe) {
        _zeilenObjekt  = zeilenObjekt;
        _attributListe = attributListe;
    }

    //~ METHODEN ==============================================================

    public ZeilenObjekt() {
		
	}

	@Override
    public int compareTo(ITabellenZeile o) {
        int     re       = 0;
        boolean ungleich = false;

        if (this.getAnzahlAttribute() == o.getAnzahlAttribute()) {
            for (int i = 0; i < this.getAnzahlAttribute(); i++) {
                if (!o.getAttribut(i).equals(this.getAttribut(i))) {
                    ungleich = true;

                    break;
                }
            }

            if (ungleich) {
                re = 1;
            }
        }

        return re;
    }

    //~ GET METHODEN ==========================================================

    @Override
    public int getAnzahlAttribute() {
        int re = 0;

        if (_attributListe != null) {
            re = _attributListe.length;
        }

        return re;
    }

    @Override
    public Object getAttribut(int idx) {
        Object re = null;

        if (_attributListe != null) {
            if (idx < _attributListe.length) {
                re = _attributListe[idx];
            }
        }

        return re;
    }

    @Override
    public Object getZeilenObject() {
        return _zeilenObjekt;
    }

    @Override

    /**
     * In dieser Tabelle mssen die Indizies angegeben werden, die
     * bei der nderungsdarstellung bercksichtigt werden.
     */
    public int[] getZuBeruecksichtigendeAttribute() {
        int[] re = new int[_attributListe.length - 3];

        for (int i = 3; i < _attributListe.length; i++) {
            re[i - 3] = i;
        }

        return re;
    }

	/**
	 * Getter fr Eigenschaft 'attributListe'.
	 * 
	 * @return Wert der Eigenschaft 'attributListe'.
	 * 
	 * @see #_attributListe
	 */
	public Object[] getAttributListe() {
		return _attributListe;
	}

	/**
	 * Setter fr Eigenschaft 'attributListe'.
	 *
	 * @param attributListe Wert zum Setzen der Eigenschaft 'attributListe'. 
	 *
	 * @see #_attributListe
	 */
	public void setAttributListe(Object[] attributListe) {
		_attributListe = attributListe;
	}

	/**
	 * Getter fr Eigenschaft 'zeilenObjekt'.
	 * 
	 * @return Wert der Eigenschaft 'zeilenObjekt'.
	 * 
	 * @see #_zeilenObjekt
	 */
	public Object getZeilenObjekt() {
		return _zeilenObjekt;
	}

	/**
	 * Setter fr Eigenschaft 'zeilenObjekt'.
	 *
	 * @param zeilenObjekt Wert zum Setzen der Eigenschaft 'zeilenObjekt'. 
	 *
	 * @see #_zeilenObjekt
	 */
	public void setZeilenObjekt(Object zeilenObjekt) {
		_zeilenObjekt = zeilenObjekt;
	}

	/* (non-Javadoc)
	 * @see java.lang.Object#hashCode()
	 */
	@Override
	public int hashCode() {
		final int prime = 31;
		int result = 1;
		result = prime * result + Arrays.hashCode(_attributListe);
		result = prime * result
				+ ((_zeilenObjekt == null) ? 0 : _zeilenObjekt.hashCode());
		return result;
	}

	/* (non-Javadoc)
	 * @see java.lang.Object#equals(java.lang.Object)
	 */
	@Override
	public boolean equals(Object obj) {
		if (this == obj) {
			return true;
		}
		if (obj == null) {
			return false;
		}
		if (!(obj instanceof ZeilenObjekt)) {
			return false;
		}
		ZeilenObjekt other = (ZeilenObjekt) obj;
		if (!Arrays.equals(_attributListe, other._attributListe)) {
			return false;
		}
		if (_zeilenObjekt == null) {
			if (other._zeilenObjekt != null) {
				return false;
			}
		} else if (!_zeilenObjekt.equals(other._zeilenObjekt)) {
			return false;
		}
		return true;
	}
 
	
	
	
}


//~Formatiert mit 'inovat Kodierkonvention' am 04.03.10
