/*
 * Copyright (c) 2008 by inovat, Dipl.-Ing. H. C. Kni
 * ALL RIGHTS RESERVED.
 *
 * THIS SOFTWARE IS  PROVIDED  "AS IS"  AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF  MERCHANTABILITY  AND  FITNESS  FOR  A PARTICULAR  PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL inovat OR ITS CONTRIBUTORS BE
 * LIABLE FOR ANY  DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
 * OR CONSEQUENTIAL DAMAGES  (INCL., BUT NOT LIMITED TO, PROCUREMENT
 * OF SUBSTITUTE GOODS OR SERVICES;  LOSS OF USE, DATA, OR  PROFITS;
 * OR BUSINESS INTERRUPTION)  HOWEVER  CAUSED  AND  ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,  OR TORT (INCL.
 * NEGLIGENCE OR OTHERWISE)  ARISING  IN  ANY  WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */



package de.inovat.buv.plugin.gtm.navigation.tabellenverwaltung;

//~ NICHT JDK IMPORTE =========================================================

import com.swtdesigner.SWTResourceManager;

import de.bsvrz.dav.daf.main.config.AttributeGroup;
import de.bsvrz.dav.daf.main.config.DataModel;
import de.bsvrz.dav.daf.main.config.SystemObject;

import de.inovat.buv.gtm.datvew.aktionen.AktionenGTM;
import de.inovat.buv.gtm.datvew.lib.BaumHilfsFunktionen;
import de.inovat.buv.gtm.datvew.lib.SelektionVew;
import de.inovat.buv.inovat.lib.gui.GuiFunktionen;
import de.inovat.buv.inovat.lib.gui.vewdlg.IRahmenVerwaltungsDialogGUI;
import de.inovat.buv.inovat.lib.gui.vewdlg.RahmenVerwaltungsDialogGUI;
import de.inovat.buv.plugin.gtm.navigation.archiv.ArchivanfrageDaten;
import de.inovat.buv.plugin.gtm.navigation.archiv.ArchivanfrageDatenGUIVew;
import de.inovat.buv.plugin.gtm.navigation.archiv.IArchivanfrageGUIVew;
import de.inovat.buv.plugin.gtm.navigation.datenidentifikation.Datenidentifikation;
import de.inovat.buv.plugin.gtm.navigation.datenidentifikation.DatenidentifikationGUIVew;
import de.inovat.buv.plugin.gtm.navigation.filter.AlleFilter;
import de.inovat.buv.plugin.gtm.navigation.filter.FilterEintrag;
import de.inovat.buv.plugin.gtm.navigation.gtmdiag.GewaehlteDarstellung;
import de.inovat.buv.plugin.gtm.navigation.sortierung.AlleSortierungen;
import de.inovat.buv.plugin.gtm.navigation.sortierung.SortierungEintrag;
import de.inovat.buv.plugin.gtm.navigation.ViewFilter;
import de.inovat.buv.plugin.gtm.navigation.ViewSortierung;
import de.inovat.buv.plugin.gtm.navigation.ViewSpaltenauswahl;
import de.inovat.buv.projektlib.dav.DavDatenVew;
import de.inovat.buv.projektlib.rechtevew.aktionen.AktionenVew;
import de.inovat.buv.projektlib.rechtevew.lib.RechteVew;

import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.swt.custom.ScrolledComposite;
import org.eclipse.swt.events.FocusEvent;
import org.eclipse.swt.events.FocusListener;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.graphics.Color;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.SWT;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Combo;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Display;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Spinner;
import org.eclipse.swt.widgets.Text;
import org.eclipse.ui.forms.widgets.FormToolkit;
import org.eclipse.ui.forms.widgets.Section;
import org.eclipse.ui.PlatformUI;

import static de.inovat.buv.inovat.lib.konstanten.Konstanten.NEWLINE;
import static de.inovat.buv.projektlib.konstanten.KonstantenGUIResource.FARBE_WEIS;

//~ JDK IMPORTE ===============================================================

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

//~ KLASSEN ===================================================================

/**
 * Die Klasse verwaltet den Dialog fr die Tabellenverwaltungseinstellungen.
 *
 * @author inovat
 * @author Dagmar Rostek (DR)
 * @version $Revision: 155 $ / $Date: 2014-10-07 11:11:48 +0200 (Di, 07 Okt 2014) $ / ($Author: LG $)
 */
public class TabellenVerwaltungEinstellungen implements IRahmenVerwaltungsDialogGUI, IArchivanfrageGUIVew {

    /** Farbe fr die Statusinformation 'Keine Daten'. */
    public static final Color BACKGROUND = FARBE_WEIS;

    //~ FELDER ================================================================

    /** Filterauswahl. */
    private String _filter = "";

    /** Legt fest, ob die GUI-Daten dem GUI-Bereich equivalent sind. */
    private boolean _guiDatenEqualGUIBereich = true;

    /** String der die selektierte Attributgruppe reprsentiert. */
    private String _selektierteAtg = "";

    /** Sortierauswahl. */
    private String _sortierung = "";

    /** Spaltenauswahl. */
    private String _spaltenAuswahl = "";

    /** Aktuelle Tabellenverwaltungsnahme. */
    private String _tabellenVerwaltungsName = "";

    /** Konstante zur Darstellung, dass keine Filter ausgewhlt wurden. */
    private final String KEINE_FILTER = "Kein Filter";

    /** Konstante zur Darstellung, dass keine Sortierungen ausgewhlt wurden. */
    private final String KEINE_SORTIERUNG = "Keine Sortierung";

    /** Konstante zur Darstellung, dass keine Spaltenauswahl ausgewhlt wurden. */
    private final String KEINE_SPALTENAUSWAHL = "Keine Spaltenauswahl";

    /** FormToolkit. */
    private final FormToolkit formToolkit = new FormToolkit(Display.getDefault());

    /** Liste aller Pidnummern der gewhlten Objekte. */
    private List<String> _pidNummernDerGewaehltenObjekte = new ArrayList<String>();

    /** Instanz der Klasse AlleTabellenVerwaltungen. */
    private AlleTabellenVerwaltungen _alleTabellenVerwaltungenInstanz = AlleTabellenVerwaltungen.getTabellenVerwaltungInstanz();
    private Button                   _btnSortierauswahl;

    /** Schaltflche 'Tabelle ffnen'. */
    private Button _btnTabelleOeffnen;
    private Button _btnVerwFilter;
    private Button _btnVerwSpaltenauswahl;

    /** Checkbox stellt fest, ob die Selektion immer bernommen werden soll. */
    private Button _cbtnSelektionUebernehmen;

    /** Checkbox die angibt ob es sich um eine nderungsdarstellung handelt. */
    private Button _checkAenderungsDarstellung;

    /** Combobox Filter. */
    private Combo _comboFilter;

    /** Combobox Sortierauswahl. */
    private Combo _comboSortierauswahl;

    /** Combobox Spaltenauswahl. */
    private Combo _comboSpalten;

    /** Composite Knotenauswahl. */
    private Composite _compGewaehlteKnotenBaum;

    /** DatenidentifikationGUIVew Instanz. */
    private DatenidentifikationGUIVew _datenIdentifikaitonGUIVew;

    /**
     * RahmenverwaltungsDialogGUI Instanz.
     */
    private RahmenVerwaltungsDialogGUI _guiVew;
    private ArchivanfrageDatenGUIVew   _instanzArchivVew;

    /** Spinnter zum einstellen der Tabellenzeilenzahl. */
    private Spinner _spinnerTabellenZeilen;

    /** Spinner zum einstellen der variablen Attribute. */
    private Spinner _spinnerVarAtt;

    /** TabellenVerwaltungselement. */
    private TabellenVerwaltung _tabellenVerwaltung;

    /** Composite Tabellenverwaltungsauswahl. */
    private Composite _tabellenVerwaltungAuswahl;

    /** Textfeld mit den aktuell gewhlten Knoten. */
    private Text _txtGewaehlteKnoten;

    //~ KONSTRUKTOREN  (und vom Konstruktor verwendete Methoden) ==============

    /**
     * Erzeugt eine Instanz der Klasse TabellenVerwaltungEinstellungen.
     */
    public TabellenVerwaltungEinstellungen() {
        _alleTabellenVerwaltungenInstanz = AlleTabellenVerwaltungen.getTabellenVerwaltungInstanz();

        //
        _instanzArchivVew = new ArchivanfrageDatenGUIVew(this);
    }

    //~ METHODEN ==============================================================

    public void aenderungErfolgt() {
        _selektierteAtg = _datenIdentifikaitonGUIVew.getSelektierteAtg();

        boolean aenderung = false;

        if (!_tabellenVerwaltungsName.equals("")) {
            TabellenVerwaltung tabellenVerwaltung = _alleTabellenVerwaltungenInstanz.getTabellenVerwaltungsObjekt(_tabellenVerwaltungsName);

            if (tabellenVerwaltung != null) {
                List<TabellenVerwaltungEintrag> tabellenVerwaltungsEintraegeListe          = tabellenVerwaltung.getTabellenVerwaltungsEintrag();
                TabellenVerwaltungEintrag       guiTabellenVerwaltungsEintragVergleichsObj = guiVergleichsObjFuellen();

                for (TabellenVerwaltungEintrag tabellenVerwEintrag : tabellenVerwaltungsEintraegeListe) {
                    aenderung = !guiTabellenVerwaltungsEintragVergleichsObj.equals(tabellenVerwEintrag);
                }

                if (tabellenVerwaltungsEintraegeListe.size() == 0) {
                    guiInitialObjFuellen();
                    aenderung = false;
                }
            }
        }

        _guiDatenEqualGUIBereich = !aenderung;

        if (_guiVew != null) {
            _guiVew.getBtnUebernehmen().setEnabled(aenderung);
            _guiVew.getBtnZuruecksetzen().setEnabled(aenderung);
        }
    }

    @Override
    public void archivGuiDatenGeaendert() {
        aenderungErfolgt();
    }

    @Override
    public void btnArchivanfrageExportCsvOhneEinheitSelektiert() {

        // wird nicht aufgerufen.
    }

    @Override
    public void btnArchivanfrageExportCsvSelektiert() {

        // wird nicht aufgerufen.
    }

    @Override
    public void btnArchivanfrageExportHtmlOhneEinheitSelektiert() {

        // wird nicht aufgerufen.
    }

    @Override
    public void btnArchivanfrageExportHtmlSelektiert() {

        // wird nicht aufgerufen.
    }

    @Override
    public void btnArchivanfrageSelektiert() {

        // wird nicht aufgerufen.
    }

    /**
     * Schaltflche "SelektionUebernehmen" wird selektiert.
     */
    private void btnSelektionUebernehmenSelektiert() {

        // Ermittle die ATG des ersten selektierten Elements:
        Object erstes = SelektionVew.getInstanz().ermittleErstSelektiertesObjekt();

        if (erstes == null) {
            MessageDialog.openError(_guiVew.getShell(), "Fehler", "Aktuell sind keine Objekte selektiert!");
        } else {
            boolean              passt                           = false;
            List<AttributeGroup> attributgruppenDerErstenAuswahl = BaumHilfsFunktionen.bestimmeAttributgruppen(erstes, false);

            for (AttributeGroup atg : attributgruppenDerErstenAuswahl) {
                if (atg.getPidOrId().equals(_selektierteAtg)) {
                    passt = true;

                    break;
                }
            }

            // Falls die selektierten Elemente zu im GUI ausgewhlten ATG passen:
            if (passt) {
                List<Object> liste = SelektionVew.getInstanz().ermittleSelektierteObjekteVonTypDesErstenObjekts();

                _pidNummernDerGewaehltenObjekte = BaumHilfsFunktionen.getPidSelektierterObj(liste);
                fuelleTextFeldMitObjekten(_pidNummernDerGewaehltenObjekte);

                //
                aenderungErfolgt();
            } else {
                MessageDialog.openError(_guiVew.getShell(), "Fehler", "Die von Ihnen gewhlte Knotenauswahl im Baum passt nicht zur spezifizierten Datenidentifikaiton!");
            }
        }
    }

    /**
     * Button 'Tabelle ffnen' wird selektiert.
     */
    private void btnTabelleOeffnenSelektiert() {

        // Zuerst prfe die Rechte:
        if (RechteVew.getInstanz().istFunktionFuerAngemeldetenBenutzerErlaubt(AktionenGTM.FUNKTION_ID_TABELLENDARSTELLUNG)) {

            // Ermittle die in der Verwaltung selektierten Objekte:
            ArrayList<Object> mengeObjekte = new ArrayList<Object>();
            DataModel         davKonf      = DavDatenVew.getInstanz().getDav().getDataModel();
            SystemObject      so;
            List<String>      listeFehlendeObjekte = new ArrayList<String>();

            for (String pid : _pidNummernDerGewaehltenObjekte) {
                so = davKonf.getObject(pid);

                if (so != null) {
                    mengeObjekte.add(so);
                } else {
                    listeFehlendeObjekte.add(pid);
                }
            }

            StringBuilder fehler = new StringBuilder();

            // Falls nicht alle Objekte ermittelt werden knnten:
            if (listeFehlendeObjekte.size() > 0) {
                fehler.append("Die Objekte fr die folgenden PIDs wurden nicht gefunden:");
                fehler.append(NEWLINE);
                fehler.append(NEWLINE);

                for (String pid : listeFehlendeObjekte) {
                    fehler.append(pid);
                }

                fehler.append(NEWLINE);
                fehler.append(NEWLINE);
            }

            // Falls die Menge der ausgewhlten Objekte nicht leer sit, ffne die Tabelle:
            if (mengeObjekte.size() > 0) {
                Object ersteWahl                      = mengeObjekte.get(0);
                String tabellenDarstellungsVorauswahl = _tabellenVerwaltung.getTabellenVerwaltungName();

                BaumHilfsFunktionen.oeffneTabellendarstellung(mengeObjekte, ersteWahl, tabellenDarstellungsVorauswahl);
            } else {
                fehler.append("Die Menge der ausgewhlten Objekte ist leer!");
            }

            // FehlerMeldung:
            if (fehler.length() > 0) {
                MessageDialog.openWarning(_guiVew.getShell(), "Achtung", "Sie haben kein Recht mit dem GUI 'Tabellendarstellung' zu arbeiten!");
            }
        }

        // Meldung 'Keine Rechte':
        else {
            MessageDialog.openWarning(_guiVew.getShell(), "Achtung", "Sie haben kein Recht mit dem GUI 'Tabellendarstellung' zu arbeiten!");
        }
    }

    @Override
    public void einfuegenNeuesElement(String objektName) {
        _tabellenVerwaltung = new TabellenVerwaltung(objektName, new ArrayList<TabellenVerwaltungEintrag>());
        _alleTabellenVerwaltungenInstanz.addTabellenVerwaltung(_tabellenVerwaltung);
        speichereMapInXML();
        _guiDatenEqualGUIBereich = true;
    }

    @Override
    public String[] ermittleInputArray() {
        return _alleTabellenVerwaltungenInstanz.getTabellenVerwaltungArray();
    }

    /**
     * Die Methode fuelleAlleComobBoxen sort dafr, dass alle Comboboxen gefllt werden.
     */
    public void fuelleAlleComboBoxen() {
        fuelleComboBoxen(_comboFilter);
        fuelleComboBoxen(_comboSortierauswahl);
        fuelleComboBoxen(_comboSpalten);

        //
        aenderungErfolgt();
    }

    /**
     * Die Methode wird von dem DatenidentifikationsGUI aufgerufen, sobald der Aspekt ausgewhlt worden ist.
     * Die Methode fuelleComboBoxen fllt dann basierend auf den Informationen der Datenidentifikation
     * die Comboboxen Filter, Sotrierung und Spalten insofern, dass immer nur die Elemente in den Comboboxen aufgenommen
     * werden, die unter den Bedingungen der Datenidentifikation auch mglich sind.
     * @param combo  Combobox die gefllt wird.
     */
    private void fuelleComboBoxen(Combo combo) {
        int               count = 0;
        int               index = -1;
        ArrayList<String> list  = new ArrayList<String>();

        if (combo.equals(_comboFilter)) {
            list.add(KEINE_FILTER);

            for (String filterName : AlleFilter.getInstanz().getFilterArray()) {
                List<FilterEintrag> listeFilterEintraege = AlleFilter.getInstanz().getFilterObjekt(filterName).getFilterEintraege();

                for (FilterEintrag fe : listeFilterEintraege) {
                    if (fe.getDatenidentifikation().getAtgGroup().equals(_datenIdentifikaitonGUIVew.getSelektierteAtg()) && (fe.getDatenidentifikation().isArchivDaten() == _datenIdentifikaitonGUIVew.istArchivDaten()) && (fe.getDatenidentifikation().isKonfigurierendeDaten() == _datenIdentifikaitonGUIVew.istKonfigurierendeDaten())) {
                        list.add(filterName);
                    }
                }
            }
        } else if (combo.equals(_comboSortierauswahl)) {
            list.add(KEINE_SORTIERUNG);

            for (String sortierName : AlleSortierungen.getSortierInstanz().getSortierungArray()) {
                List<SortierungEintrag> listeSortierEintraege = AlleSortierungen.getSortierInstanz().getSortierungObjekt(sortierName).getSortierungEintraege();

                for (SortierungEintrag sE : listeSortierEintraege) {
                    if (sE.getDatenidentifikation().getAtgGroup().equals(_datenIdentifikaitonGUIVew.getSelektierteAtg()) && (sE.getDatenidentifikation().isArchivDaten() == _datenIdentifikaitonGUIVew.istArchivDaten()) && (sE.getDatenidentifikation().isKonfigurierendeDaten() == _datenIdentifikaitonGUIVew.istKonfigurierendeDaten())) {
                        list.add(sortierName);
                    }
                }
            }
        } else if (combo.equals(_comboSpalten)) {
            list.add(KEINE_SPALTENAUSWAHL);

            for (String spaltenName : AlleSortierungen.getSpaltenAuswahlInstanz().getSortierungArray()) {
                List<SortierungEintrag> listeSpaltenEintraege = AlleSortierungen.getSpaltenAuswahlInstanz().getSortierungObjekt(spaltenName).getSortierungEintraege();

                for (SortierungEintrag se : listeSpaltenEintraege) {
                    if (se.getDatenidentifikation().getAtgGroup().equals(_datenIdentifikaitonGUIVew.getSelektierteAtg()) && (se.getDatenidentifikation().isArchivDaten() == _datenIdentifikaitonGUIVew.istArchivDaten()) && (se.getDatenidentifikation().isKonfigurierendeDaten() == _datenIdentifikaitonGUIVew.istKonfigurierendeDaten())) {
                        list.add(spaltenName);
                    }
                }
            }
        }

        Collections.sort(list);

        if (combo.equals(_comboFilter)) {
            for (String filter : list) {
                _comboFilter.add(filter);

                if (filter.equals(_filter)) {
                    index   = count;
                    _filter = "";
                }

                count++;
            }

            if (!(index == -1)) {
                _comboFilter.select(index);
            } else if (list.size() > 0) {
                _comboFilter.select(0);
            }
        } else if (combo.equals(_comboSortierauswahl)) {
            for (String sortierung : list) {
                _comboSortierauswahl.add(sortierung);

                if (sortierung.equals(_sortierung)) {
                    index       = count;
                    _sortierung = "";
                }

                count++;
            }

            if (!(index == -1)) {
                _comboSortierauswahl.select(index);
            } else if (list.size() > 0) {
                _comboSortierauswahl.select(0);
            }
        } else if (combo.equals(_comboSpalten)) {
            for (String spalte : list) {
                _comboSpalten.add(spalte);

                if (spalte.equals(_spaltenAuswahl)) {
                    index           = count;
                    _spaltenAuswahl = "";
                }

                count++;
            }

            if (!(index == -1)) {
                _comboSpalten.select(index);
            } else if (list.size() > 0) {
                _comboSpalten.select(0);
            }
        }
    }

    /**
     * Die Methode fllt das Textfeld mit den Pid's aller gewhlten Objekte im Baum.
     *
     * @param gewaehlteObjImBaum Gewhlte Objekte.
     */
    private void fuelleTextFeldMitObjekten(List<String> gewaehlteObjImBaum) {
        int           zaehler      = 0;
        StringBuilder stringBuffer = new StringBuilder();

        for (String pid : gewaehlteObjImBaum) {
            stringBuffer.append(zaehler++);
            stringBuffer.append(":  ");
            stringBuffer.append(pid);
            stringBuffer.append(";");
            stringBuffer.append("\r\n");
        }

        _txtGewaehlteKnoten.setText(stringBuffer.toString());

        // Setze den EnabledWert fr das Button 'Tabelle ffnen':
        setzeEnabledWertFuerTabelleOeffnen();
    }

    /**
     * Die Methode guiVergleichsObjFuellen fllt das Vergleichsobjekt mit den aktuellen Daten des GUI.
     */
    private void guiInitialObjFuellen() {
        ArchivanfrageDaten  archivanfrageDaten   = new ArchivanfrageDaten();
        String              filter               = KEINE_FILTER;
        String              sortierung           = KEINE_SORTIERUNG;
        String              spaltenAuswahl       = KEINE_SPALTENAUSWAHL;
        Datenidentifikation datenIdentifikation  = new Datenidentifikation(_datenIdentifikaitonGUIVew.getSelektierteObjType(), _datenIdentifikaitonGUIVew.getSelektierteAtg(), _datenIdentifikaitonGUIVew.getSelektierteAsp(), false, false);
        boolean             selektionUebernehmen = false;

        _tabellenVerwaltung.getTabellenVerwaltungsEintrag().add(new TabellenVerwaltungEintrag                //
            (false, datenIdentifikation, filter, sortierung, spaltenAuswahl, _spinnerVarAtt.getSelection(),  //
             _spinnerTabellenZeilen.getSelection(), _pidNummernDerGewaehltenObjekte,                         //
             _datenIdentifikaitonGUIVew.istArchivDaten(), archivanfrageDaten, selektionUebernehmen));

        //
        speichereMapInXML();
    }

    /**
     * Die Methode guiVergleichsObjFuellen fllt das Vergleichsobjekt mit den aktuellen Daten des GUI.
     *
     * @return TabellenVerwaltungEintrag mit GUI-Werten.
     */
    private TabellenVerwaltungEintrag guiVergleichsObjFuellen() {

        //
        ArchivanfrageDaten archivanfrageDaten = _instanzArchivVew.ermittleObjektAusGUI();

        //
        int    sortierIndex        = _comboSortierauswahl.getSelectionIndex();
        int    filterIndex         = _comboFilter.getSelectionIndex();
        int    spaltenAuswahlIndex = _comboSpalten.getSelectionIndex();
        String filter              = "";
        String sortierung          = "";
        String spaltenAuswahl      = "";

        if (!(filterIndex == -1)) {
            filter = _comboFilter.getItem(_comboFilter.getSelectionIndex());
        }

        if (!(sortierIndex == -1)) {
            sortierung = _comboSortierauswahl.getItem(_comboSortierauswahl.getSelectionIndex());
        }

        if (!(spaltenAuswahlIndex == -1)) {
            spaltenAuswahl = _comboSpalten.getItem(_comboSpalten.getSelectionIndex());
        }

        Datenidentifikation datenIdentifikation = new Datenidentifikation(_datenIdentifikaitonGUIVew.getSelektierteObjType(), _datenIdentifikaitonGUIVew.getSelektierteAtg(), _datenIdentifikaitonGUIVew.getSelektierteAsp(), _datenIdentifikaitonGUIVew.istArchivDaten(), _datenIdentifikaitonGUIVew.istKonfigurierendeDaten());

        return new TabellenVerwaltungEintrag(_checkAenderungsDarstellung.getSelection(), datenIdentifikation,                                           //
                                             filter, sortierung, spaltenAuswahl, _spinnerVarAtt.getSelection(), _spinnerTabellenZeilen.getSelection(),  //
                                             _pidNummernDerGewaehltenObjekte, _datenIdentifikaitonGUIVew.istArchivDaten(), archivanfrageDaten, _cbtnSelektionUebernehmen.getSelection());
    }

    /**
     * Die Methode initialisiert den GUI Archivbereich.
     */
    private void initArchivBereich() {
        Section sectionArchivanfrage = formToolkit.createSection(_tabellenVerwaltungAuswahl, Section.TWISTIE | Section.TITLE_BAR);

        sectionArchivanfrage.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, true, false, 1, 1));
        formToolkit.paintBordersFor(sectionArchivanfrage);
        sectionArchivanfrage.setText("Archivanfrage");

        // GUI "Archivanfrage":
        _instanzArchivVew.initGUI(sectionArchivanfrage, formToolkit);
        sectionArchivanfrage.setExpanded(true);

        // ID helpcontent!!
        PlatformUI.getWorkbench().getHelpSystem().setHelp(sectionArchivanfrage, "de.inovat.buv.plugin.gtm.rw.basislib.archivoptionen");

        //
    }

    @Override
    public void initialisiereElement() {
        _tabellenVerwaltung = new TabellenVerwaltung("", new ArrayList<TabellenVerwaltungEintrag>());
    }

    /**
     * @wbp.parser.entryPoint
     */
    @Override
    public void initialisiereGUIBereich(Composite parent) {
        ScrolledComposite scrolledComposite = new ScrolledComposite(parent, SWT.H_SCROLL | SWT.V_SCROLL);

        scrolledComposite.setLayoutData(new GridData(SWT.FILL, SWT.FILL, true, true, 1, 1));
        scrolledComposite.setExpandHorizontal(true);
        scrolledComposite.setExpandVertical(true);
        scrolledComposite.setBackground(BACKGROUND);
        _tabellenVerwaltungAuswahl = new Composite(scrolledComposite, SWT.NONE);
        _tabellenVerwaltungAuswahl.setLayout(new GridLayout(1, false));
        _tabellenVerwaltungAuswahl.setLayoutData(new GridData(SWT.FILL, SWT.FILL, true, true, 1, 1));
        _tabellenVerwaltungAuswahl.setBackground(BACKGROUND);

        //
        Composite compTabelleOeffnen = formToolkit.createComposite(_tabellenVerwaltungAuswahl, SWT.NONE);

        formToolkit.paintBordersFor(compTabelleOeffnen);
        compTabelleOeffnen.setLayout(new GridLayout(1, false));
        _btnTabelleOeffnen = formToolkit.createButton(compTabelleOeffnen, "als Tabelle \u00F6ffnen", SWT.NONE);

        GridData gd_btnTabelleOeffnen = new GridData(SWT.LEFT, SWT.CENTER, false, false, 1, 1);

        gd_btnTabelleOeffnen.widthHint = 270;
        _btnTabelleOeffnen.setLayoutData(gd_btnTabelleOeffnen);
        _btnTabelleOeffnen.setEnabled(false);
        _btnTabelleOeffnen.addSelectionListener(new SelectionAdapter() {
            @Override
            public void widgetSelected(SelectionEvent e) {
                btnTabelleOeffnenSelektiert();
            }
        });

        //
        _datenIdentifikaitonGUIVew = new DatenidentifikationGUIVew(_tabellenVerwaltungAuswahl, this, 1);

        //
        initArchivBereich();

        Section sectionDarstellungsOptionen = formToolkit.createSection(_tabellenVerwaltungAuswahl, Section.TWISTIE | Section.TITLE_BAR);

        sectionDarstellungsOptionen.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, true, false, 1, 1));
        formToolkit.paintBordersFor(sectionDarstellungsOptionen);
        sectionDarstellungsOptionen.setText("Darstellungsoptionen");

        Composite compDarstellungsOptionen = new Composite(sectionDarstellungsOptionen, SWT.NONE);

        formToolkit.adapt(compDarstellungsOptionen);
        formToolkit.paintBordersFor(compDarstellungsOptionen);
        sectionDarstellungsOptionen.setClient(compDarstellungsOptionen);
        compDarstellungsOptionen.setLayout(new GridLayout(3, true));

        Label lbAenderungsdarstellung = new Label(compDarstellungsOptionen, SWT.NONE);

        lbAenderungsdarstellung.setLayoutData(new GridData(SWT.RIGHT, SWT.CENTER, false, false, 1, 1));
        formToolkit.adapt(lbAenderungsdarstellung, true, true);
        lbAenderungsdarstellung.setText("\u00C4nderungsdarstellung");
        _checkAenderungsDarstellung = new Button(compDarstellungsOptionen, SWT.CHECK);
        _checkAenderungsDarstellung.addSelectionListener(new SelectionAdapter() {
            @Override
            public void widgetSelected(SelectionEvent e) {
                aenderungErfolgt();
            }
        });
        formToolkit.adapt(_checkAenderungsDarstellung, true, true);
        new Label(compDarstellungsOptionen, SWT.NONE);

        Label lblAnzahlVariableAttribute = new Label(compDarstellungsOptionen, SWT.NONE);

        lblAnzahlVariableAttribute.setLayoutData(new GridData(SWT.RIGHT, SWT.CENTER, false, false, 1, 1));
        formToolkit.adapt(lblAnzahlVariableAttribute, true, true);
        lblAnzahlVariableAttribute.setText("Anzahl Variable Attribute");
        _spinnerVarAtt = new Spinner(compDarstellungsOptionen, SWT.BORDER);
        _spinnerVarAtt.setSelection(1);
        _spinnerVarAtt.addSelectionListener(new SelectionAdapter() {
            @Override
            public void widgetSelected(SelectionEvent e) {
                aenderungErfolgt();
            }
        });
        formToolkit.adapt(_spinnerVarAtt);
        formToolkit.paintBordersFor(_spinnerVarAtt);
        new Label(compDarstellungsOptionen, SWT.NONE);

        Label lblAnzahlTabellenzeilen = new Label(compDarstellungsOptionen, SWT.NONE);

        lblAnzahlTabellenzeilen.setLayoutData(new GridData(SWT.RIGHT, SWT.CENTER, false, false, 1, 1));
        formToolkit.adapt(lblAnzahlTabellenzeilen, true, true);
        lblAnzahlTabellenzeilen.setText("Anzahl Tabellenzeilen");
        _spinnerTabellenZeilen = new Spinner(compDarstellungsOptionen, SWT.BORDER);
        _spinnerTabellenZeilen.setIncrement(10);
        _spinnerTabellenZeilen.setSelection(100);
        _spinnerTabellenZeilen.addSelectionListener(new SelectionAdapter() {
            @Override
            public void widgetSelected(SelectionEvent e) {
                aenderungErfolgt();
            }
        });
        _spinnerTabellenZeilen.setMaximum(10000);
        formToolkit.adapt(_spinnerTabellenZeilen);
        formToolkit.paintBordersFor(_spinnerTabellenZeilen);
        new Label(compDarstellungsOptionen, SWT.NONE);

        Label lblFilterauswahl = new Label(compDarstellungsOptionen, SWT.NONE);

        lblFilterauswahl.setLayoutData(new GridData(SWT.RIGHT, SWT.CENTER, false, false, 1, 1));
        formToolkit.adapt(lblFilterauswahl, true, true);
        lblFilterauswahl.setText("Filterauswahl");
        _comboFilter = new Combo(compDarstellungsOptionen, SWT.READ_ONLY);
        _comboFilter.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, false, false, 1, 1));
        _comboFilter.addFocusListener(new FocusListener() {
            @Override
            public void focusGained(FocusEvent e) {}
            @Override
            public void focusLost(FocusEvent e) {
                _comboFilter.removeAll();
                fuelleComboBoxen(_comboFilter);
            }
        });
        _comboFilter.addSelectionListener(new SelectionAdapter() {
            @Override
            public void widgetSelected(SelectionEvent e) {
                _filter = _comboFilter.getItem(_comboFilter.getSelectionIndex());
                aenderungErfolgt();
            }
        });
        formToolkit.adapt(_comboFilter);
        formToolkit.paintBordersFor(_comboFilter);

        //
        _btnVerwFilter = new Button(compDarstellungsOptionen, SWT.NONE);
        _btnVerwFilter.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, false, false, 1, 1));
        _btnVerwFilter.addSelectionListener(new SelectionAdapter() {
            @Override
            public void widgetSelected(SelectionEvent e) {

                // Aufruf des GUI fr die Filtererstellung.
                if (!(_comboFilter.getSelectionIndex() == -1)) {
                    GewaehlteDarstellung.getInstanz().setGewaehlterFilter(_comboFilter.getItem(_comboFilter.getSelectionIndex()));
                } else {
                    GewaehlteDarstellung.getInstanz().setGewaehlterFilter("");
                }

                if (PlatformUI.getWorkbench().getActiveWorkbenchWindow().getActivePage().findView(ViewFilter.ID) != null) {
                    GuiFunktionen.schliesseSicht(ViewFilter.ID);
                }

                if (AktionenVew.getInstanz().ausfuehrenAktion(AktionenGTM.COMMAND_ID_FILTER) != null) {
                    MessageDialog.openWarning(_guiVew.getShell(), "Achtung", "Sie haben kein Recht mit dem GUI 'Filter' zu arbeiten!");
                }
            }
        });
        formToolkit.adapt(_btnVerwFilter, true, true);
        _btnVerwFilter.setText("Verwaltungsdialog Filter");

        Label lblSortierauswahl = new Label(compDarstellungsOptionen, SWT.NONE);

        lblSortierauswahl.setLayoutData(new GridData(SWT.RIGHT, SWT.CENTER, false, false, 1, 1));
        formToolkit.adapt(lblSortierauswahl, true, true);
        lblSortierauswahl.setText("Sortierauswahl");
        _comboSortierauswahl = new Combo(compDarstellungsOptionen, SWT.READ_ONLY);
        _comboSortierauswahl.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, false, false, 1, 1));
        _comboSortierauswahl.addFocusListener(new FocusListener() {
            @Override
            public void focusLost(FocusEvent e) {}
            @Override
            public void focusGained(FocusEvent e) {
                _comboSortierauswahl.removeAll();
                fuelleComboBoxen(_comboSortierauswahl);
            }
        });
        _comboSortierauswahl.addSelectionListener(new SelectionAdapter() {
            @Override
            public void widgetSelected(SelectionEvent e) {
                _sortierung = _comboSortierauswahl.getItem(_comboSortierauswahl.getSelectionIndex());
                aenderungErfolgt();
            }
        });
        formToolkit.adapt(_comboSortierauswahl);
        formToolkit.paintBordersFor(_comboSortierauswahl);

        //
        _btnSortierauswahl = new Button(compDarstellungsOptionen, SWT.NONE);
        _btnSortierauswahl.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, false, false, 1, 1));
        formToolkit.adapt(_btnSortierauswahl, true, true);
        _btnSortierauswahl.setText("Verwaltungsdialog Sortierauswahl");
        _btnSortierauswahl.addSelectionListener(new SelectionAdapter() {
            public void widgetSelected(SelectionEvent e) {

                // Aufruf des GUI fr die Sortiererstellung.
                if (_comboSortierauswahl.getSelectionIndex() != -1) {
                    GewaehlteDarstellung.getInstanz().setGewaehlteSortierung(_comboSortierauswahl.getItem(_comboSortierauswahl.getSelectionIndex()));
                } else {
                    GewaehlteDarstellung.getInstanz().setGewaehlteSortierung("");
                }

                if (PlatformUI.getWorkbench().getActiveWorkbenchWindow().getActivePage().findView(ViewSortierung.ID) != null) {
                    GuiFunktionen.schliesseSicht(ViewSortierung.ID);
                }

                if (AktionenVew.getInstanz().ausfuehrenAktion(AktionenGTM.COMMAND_ID_SORTIRUNG) != null) {
                    MessageDialog.openWarning(_guiVew.getShell(), "Achtung", "Sie haben kein Recht mit dem GUI 'Sortierauswahl' zu arbeiten!");
                }
            }
        });

        Label lblSpaltenauswahl = new Label(compDarstellungsOptionen, SWT.NONE);

        lblSpaltenauswahl.setLayoutData(new GridData(SWT.RIGHT, SWT.CENTER, false, false, 1, 1));
        formToolkit.adapt(lblSpaltenauswahl, true, true);
        lblSpaltenauswahl.setText("Spaltenauswahl");
        _comboSpalten = new Combo(compDarstellungsOptionen, SWT.READ_ONLY);
        _comboSpalten.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, false, false, 1, 1));
        _comboSpalten.addFocusListener(new FocusListener() {
            @Override
            public void focusLost(FocusEvent e) {}
            @Override
            public void focusGained(FocusEvent e) {
                _comboSpalten.removeAll();
                fuelleComboBoxen(_comboSpalten);
            }
        });
        _comboSpalten.addSelectionListener(new SelectionAdapter() {
            @Override
            public void widgetSelected(SelectionEvent e) {
                _spaltenAuswahl = _comboSpalten.getItem(_comboSpalten.getSelectionIndex());
                aenderungErfolgt();
            }
        });
        formToolkit.adapt(_comboSpalten);
        formToolkit.paintBordersFor(_comboSpalten);

        //
        _btnVerwSpaltenauswahl = new Button(compDarstellungsOptionen, SWT.NONE);
        _btnVerwSpaltenauswahl.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, false, false, 1, 1));
        formToolkit.adapt(_btnVerwSpaltenauswahl, true, true);
        _btnVerwSpaltenauswahl.setText("Verwaltungsdialog Spaltenauswahl");
        _btnVerwSpaltenauswahl.addSelectionListener(new SelectionAdapter() {
            public void widgetSelected(SelectionEvent e) {

                // Aufruf des GUI fr die Spaltenauswahlerstellung.
                if (_comboSpalten.getSelectionIndex() != -1) {
                    GewaehlteDarstellung.getInstanz().setGewaehlteSpalten(_comboSpalten.getItem(_comboSpalten.getSelectionIndex()));
                } else {
                    GewaehlteDarstellung.getInstanz().setGewaehlteSpalten("");
                }

                if (PlatformUI.getWorkbench().getActiveWorkbenchWindow().getActivePage().findView(ViewSpaltenauswahl.ID) != null) {
                    GuiFunktionen.schliesseSicht(ViewSpaltenauswahl.ID);
                }

                if (AktionenVew.getInstanz().ausfuehrenAktion(AktionenGTM.COMMAND_ID_SPALTENAUSWAHL) != null) {
                    MessageDialog.openWarning(_guiVew.getShell(), "Achtung", "Sie haben kein Recht mit dem GUI 'Spaltenauswahl' zu arbeiten!");
                }
            }
        });
        sectionDarstellungsOptionen.setExpanded(true);

        Section sectionKnotenAuswahl = formToolkit.createSection(_tabellenVerwaltungAuswahl, Section.TWISTIE | Section.TITLE_BAR);

        sectionKnotenAuswahl.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, false, false, 1, 1));
        formToolkit.paintBordersFor(sectionKnotenAuswahl);
        sectionKnotenAuswahl.setText("Knotenauswahl");

        Composite composite = new Composite(sectionKnotenAuswahl, SWT.NONE);

        formToolkit.adapt(composite);
        formToolkit.paintBordersFor(composite);
        sectionKnotenAuswahl.setClient(composite);
        composite.setLayout(new GridLayout(1, false));

        Composite compInfoUndButtonKnotenUebernahme = new Composite(composite, SWT.NONE);

        formToolkit.adapt(compInfoUndButtonKnotenUebernahme);
        formToolkit.paintBordersFor(compInfoUndButtonKnotenUebernahme);
        compInfoUndButtonKnotenUebernahme.setLayout(new GridLayout(2, true));

        Button btnSelektionUebernehmen = new Button(compInfoUndButtonKnotenUebernahme, SWT.NONE);

        btnSelektionUebernehmen.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, true, false, 1, 1));
        btnSelektionUebernehmen.setToolTipText("Bet\u00E4tigen Sie die Schaltfl\u00E4che um die gerade im Baum selektierten Knoten zu \u00FCbernehmen.");
        btnSelektionUebernehmen.addSelectionListener(new SelectionAdapter() {
            @Override
            public void widgetSelected(SelectionEvent e) {
                btnSelektionUebernehmenSelektiert();
            }
        });
        formToolkit.adapt(btnSelektionUebernehmen, true, true);
        btnSelektionUebernehmen.setText("Selektion \u00FCbernehmen");

        Button btnSelektionLoeschen = formToolkit.createButton(compInfoUndButtonKnotenUebernahme, "Selektion l\u00F6schen", SWT.NONE);

        btnSelektionLoeschen.addSelectionListener(new SelectionAdapter() {
            @Override
            public void widgetSelected(SelectionEvent e) {
                _pidNummernDerGewaehltenObjekte = new ArrayList<String>();
                fuelleTextFeldMitObjekten(_pidNummernDerGewaehltenObjekte);
                aenderungErfolgt();
            }
        });
        btnSelektionLoeschen.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, true, false, 1, 1));
        _cbtnSelektionUebernehmen = formToolkit.createButton(composite, "Selektion immer in die Darstellung \u00FCbernehmen", SWT.CHECK);
        _cbtnSelektionUebernehmen.addSelectionListener(new SelectionAdapter() {
            @Override
            public void widgetSelected(SelectionEvent e) {
                aenderungErfolgt();
            }
        });
        _compGewaehlteKnotenBaum = new Composite(composite, SWT.NONE);
        _compGewaehlteKnotenBaum.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, true, false, 1, 1));
        _compGewaehlteKnotenBaum.setBackground(SWTResourceManager.getColor(SWT.COLOR_WHITE));
        formToolkit.adapt(_compGewaehlteKnotenBaum);
        formToolkit.paintBordersFor(_compGewaehlteKnotenBaum);
        _compGewaehlteKnotenBaum.setLayout(new GridLayout(1, false));
        _txtGewaehlteKnoten = new Text(_compGewaehlteKnotenBaum, SWT.READ_ONLY | SWT.MULTI | SWT.WRAP | SWT.H_SCROLL | SWT.BORDER | SWT.V_SCROLL);

        GridData gd_txtGewaehlteKnoten = new GridData(SWT.FILL, SWT.FILL, true, false, 1, 1);

        gd_txtGewaehlteKnoten.heightHint = 150;
        _txtGewaehlteKnoten.setLayoutData(gd_txtGewaehlteKnoten);
        _txtGewaehlteKnoten.setEditable(false);
        formToolkit.adapt(_txtGewaehlteKnoten, true, true);
        sectionKnotenAuswahl.setExpanded(true);
        scrolledComposite.setContent(_tabellenVerwaltungAuswahl);
        scrolledComposite.setMinSize(_tabellenVerwaltungAuswahl.computeSize(SWT.DEFAULT, SWT.DEFAULT));

        // ID helpcontent!!
        PlatformUI.getWorkbench().getHelpSystem().setHelp(compDarstellungsOptionen, "de.inovat.buv.plugin.gtm.rw.basislib.darstellungsoptionen");

        //
        // ID helpcontent!!
        PlatformUI.getWorkbench().getHelpSystem().setHelp(sectionKnotenAuswahl, "de.inovat.buv.plugin.gtm.rw.basislib.knotenauswahl");

        // Setze den EnabledWert fr das Button 'Tabelle ffnen':
        setzeEnabledWertFuerTabelleOeffnen();
    }

    @Override
    public boolean istBtnArchivanfrage() {
        return false;
    }

    @Override
    public void kopiereElement(String objektName) {
        List<TabellenVerwaltungEintrag> te = new ArrayList<TabellenVerwaltungEintrag>();

        te.addAll(_tabellenVerwaltung.getTabellenVerwaltungsEintrag());
        _tabellenVerwaltung = new TabellenVerwaltung(objektName, te);
        _alleTabellenVerwaltungenInstanz.addTabellenVerwaltung(_tabellenVerwaltung);
        speichereMapInXML();
        aenderungErfolgt();
    }

    /**
     * Die Methode loescheComboBoxen lscht alle Inhalte aus den Comboboxen.
     */
    private void loescheComboBoxen() {
        _comboFilter.removeAll();
        _comboSortierauswahl.removeAll();
        _comboSpalten.removeAll();
    }

    @Override
    public void loescheElement(String objektName) {
        _alleTabellenVerwaltungenInstanz.loescheTabellenVerwaltung(objektName);
        speichereMapInXML();
        aenderungErfolgt();
    }

    @Override
    public void selektiereElement(String objektName) {
        _tabellenVerwaltung = _alleTabellenVerwaltungenInstanz.getTabellenVerwaltungsObjekt(objektName);
        aenderungErfolgt();
    }

    //~ SET METHODEN ==========================================================

    /**
     * Setter fr Eigenschaft 'vewGui'.
     *
     * @param vewGui Wert zum Setzen der Eigenschaft 'vewGui'.
     *
     * @see #_guiVew
     */
    public void setGuiVew(RahmenVerwaltungsDialogGUI vewGui) {
        _guiVew = vewGui;
    }

    //~ METHODEN ==============================================================

    /**
     * Setze den EnabledWert fr das Button 'Tabelle ffnen':
     */
    private void setzeEnabledWertFuerTabelleOeffnen() {
        _btnTabelleOeffnen.setEnabled(_txtGewaehlteKnoten.getText().length() > 0);
    }

    @Override
    public void setzeGUIbereichMitElementDaten(String objektName) {
        _tabellenVerwaltungsName = objektName;
        _filter                  = "";
        _sortierung              = "";
        _spaltenAuswahl          = "";
        _txtGewaehlteKnoten.setText("");
        _pidNummernDerGewaehltenObjekte = new ArrayList<String>();
        loescheComboBoxen();

        if (_tabellenVerwaltung != null) {
            if (_tabellenVerwaltung.getTabellenVerwaltungsEintrag().isEmpty()) {

                //
                _datenIdentifikaitonGUIVew.initialisiereGUI();

                //
                _instanzArchivVew.setzeGUIbereich(new ArchivanfrageDaten());

                //
                _checkAenderungsDarstellung.setSelection(false);
                _spinnerTabellenZeilen.setSelection(1000);
                _spinnerVarAtt.setSelection(0);
                _cbtnSelektionUebernehmen.setSelection(false);
            } else {
                for (TabellenVerwaltungEintrag te : _tabellenVerwaltung.getTabellenVerwaltungsEintrag()) {
                    _checkAenderungsDarstellung.setSelection(te.isAenderungsdarstellung());
                    _spinnerTabellenZeilen.setSelection(te.getVarTbl());
                    _spinnerVarAtt.setSelection(te.getVarAtt());
                    _filter         = te.getFilterAuswahlName();
                    _sortierung     = te.getSortierAuswahlName();
                    _spaltenAuswahl = te.getSpaltenAuswahlName();
                    _selektierteAtg = te.getDatenidentifikation().getAtgGroup();
                    _datenIdentifikaitonGUIVew.setzeDaten(te.getDatenidentifikation().isArchivDaten(), te.getDatenidentifikation().isKonfigurierendeDaten(),  //
                                                          te.getDatenidentifikation().getObjTyp(), te.getDatenidentifikation().getAtgGroup(), te.getDatenidentifikation().getAspect());
                    _pidNummernDerGewaehltenObjekte.addAll(te.getGewaehlteKnotenBaum());

                    if (te.getArchivanfrageDaten() != null) {
                        _instanzArchivVew.setzeGUIbereich(te.getArchivanfrageDaten());
                    }

                    fuelleTextFeldMitObjekten(te.getGewaehlteKnotenBaum());
                    _cbtnSelektionUebernehmen.setSelection(te.isSelektionUebernehmen());
                }
            }

            fuelleComboBoxen(_comboFilter);
            fuelleComboBoxen(_comboSortierauswahl);
            fuelleComboBoxen(_comboSpalten);
            aenderungErfolgt();
        }
    }

    @Override
    public boolean sindGuiDatenMitElementDatenGleich() {
        return _guiDatenEqualGUIBereich;
    }

    @Override
    public void speichereElement() {

        //
        ArchivanfrageDaten archivanfrageDaten = _instanzArchivVew.ermittleObjektAusGUI();

        // Prfe Zeitbereich des Archivs:
        if (!archivanfrageDaten.istZeitbereichKorrekt()) {
            MessageDialog.openError(_guiVew.getShell(), "Fehler",  //
                                    "Zeitbereich des Archivs ist nicht korrekt \n(Anfang des Bereichs muss kleiner als Ende sein)!\n\nBitte korrigieren Sie zuerst die Zeitangaben.");

            return;
        }

        int    filterIndex         = _comboFilter.getSelectionIndex();
        int    sortierIndex        = _comboSortierauswahl.getSelectionIndex();
        int    spaltenAuswahlIndex = _comboSpalten.getSelectionIndex();
        String filter              = "";
        String sortierung          = "";
        String spaltenAuswahl      = "";

        if (!(filterIndex == -1)) {
            filter = _comboFilter.getItem(filterIndex);
        }

        if (!(sortierIndex == -1)) {
            sortierung = _comboSortierauswahl.getItem(sortierIndex);
        }

        if (!(spaltenAuswahlIndex == -1)) {
            spaltenAuswahl = _comboSpalten.getItem(spaltenAuswahlIndex);
        }

        _tabellenVerwaltung.getTabellenVerwaltungsEintrag().clear();

        //
        Datenidentifikation datId = new Datenidentifikation(_datenIdentifikaitonGUIVew.getSelektierteObjType(), _datenIdentifikaitonGUIVew.getSelektierteAtg(), _datenIdentifikaitonGUIVew.getSelektierteAsp(), _datenIdentifikaitonGUIVew.istArchivDaten(), _datenIdentifikaitonGUIVew.istKonfigurierendeDaten());

        _tabellenVerwaltung.getTabellenVerwaltungsEintrag().add(new TabellenVerwaltungEintrag                                                                              //
            (_checkAenderungsDarstellung.getSelection(), datId, filter, sortierung, spaltenAuswahl, _spinnerVarAtt.getSelection(), _spinnerTabellenZeilen.getSelection(),  //
             _pidNummernDerGewaehltenObjekte, false, archivanfrageDaten, _cbtnSelektionUebernehmen.getSelection()));

        //
        speichereMapInXML();
        aenderungErfolgt();
    }

    /**
     * Speichert die Daten.
     */
    private void speichereMapInXML() {
        _alleTabellenVerwaltungenInstanz.speichereAlleTabellenVerwaltungen();
    }
}


//~Formatiert mit 'inovat Kodierkonvention' am 10.03.14
