/*
 * Copyright 2008 by inovat, innovative systeme - verkehr - tunnel - technik, Dipl.-Ing. H. C. Kni, Kln
 * <p>
 * This file is part of de.inovat.pat.datkat2html
 * <p>
 * de.inovat.pat.datkat2html is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * <p>
 * de.inovat.pat.datkat2html is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * <p>
 * You should have received a copy of the GNU General Public License
 * along with de.inovat.pat.datkat2html; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 * <p>
 * Contact Information:<br>
 * inovat, Dipl.-Ing. H. C. Kni<br>
 * Klner Strae 30<br>
 * 50859 Kln<br>
 * Phone: +49 2234 4301 800<br>
 * mailto: info@inovat.de
 */
package de.inovat.pat.datkat2html.ausgabe.beschreibung;

import java.util.List;

/**
 * Klasse definiert die Ausgabeinformation und dient fr die Formatierung des Textes.
 * 
 * Folgende Typen werden ignoriert:
 * anforderung, listing, schluesselwort, SwExterneSchnittstellen, SwInterneSchnittstellen,
 * SwModulEinzelbeschreibungen, SwModulListe, variable, ze. 
 * 
 * <!ENTITY % local.zeichenauszeichnung.klasse "">
 * 
 * <!ENTITY % zeichenauszeichnung.klasse
 * 		"tief|hoch|code|adresse|pre|index|verweis|anker|schluesselwort|ze|hinweis|variable|wichtig|zitat
 *          %local.zeichenauszeichnung.klasse;">
 * 
 * <!ELEMENT  tief           (#PCDATA| %zeichenauszeichnung.klasse;)*      >
 * <!ELEMENT  hoch           (#PCDATA| %zeichenauszeichnung.klasse;)*      >
 * <!ELEMENT  code           (#PCDATA| %zeichenauszeichnung.klasse;)*      >
 * <!ELEMENT  pre            (#PCDATA| %zeichenauszeichnung.klasse;)*      >
 * <!ELEMENT  adresse        (#PCDATA| %zeichenauszeichnung.klasse;)*      >
 * 
 * <!ELEMENT  index          (#PCDATA| %zeichenauszeichnung.klasse;)*      >
 * <!ATTLIST  index
 *            sichtbar        (j|n)                #IMPLIED
 *            id                 ID                #IMPLIED
 * >
 * 
 * <!ELEMENT  verweis      EMPTY                                           >
 * <!ATTLIST  verweis
 *              pid        NMTOKEN                   #REQUIRED
 *              txt        CDATA                     #IMPLIED
 *              num        (j|n)                     #IMPLIED
 *              klammer    (j|n)                     #IMPLIED
 *              direkt     (j|n)                     #IMPLIED
 *              tooltip    (j|n)                     #IMPLIED
 * >
 * 
 * <!ELEMENT  anker        EMPTY                                           >
 * <!ATTLIST  anker
 *              pid        ID                        #REQUIRED
 *              txt        CDATA                     #IMPLIED
 * >
 * 
 * <!ELEMENT  wichtig           (#PCDATA| %zeichenauszeichnung.klasse;)*    >
 * 
 * <!ELEMENT  zitat           (#PCDATA| %zeichenauszeichnung.klasse;)*      >
 *  
 * <!ELEMENT  hinweis   (#PCDATA | %zeichenauszeichnung.klasse; | %absatzauszeichnung.klasse;)* >
 * <!ATTLIST  hinweis
 *            pid        ID                        #IMPLIED
 *  		  typ        (seite|dokument|absatz)   "seite"
 * >
 * 
 * <!ENTITY % local.absatzauszeichnung.klasse "">
 * <!ENTITY % absatzauszeichnung.klasse
 *	 		"absatz|abbildung|liste|numListe|sektion|anforderung|swModulEinzelbeschreibungen|
 *			swModulListe|swExterneSchnittstellen|swInterneSchnittstellen|
 *          listing|referenz|tabelle|kommentar
 *          %local.absatzauszeichnung.klasse;">
 * 
 * <!ELEMENT  absatz       (#PCDATA | %zeichenauszeichnung.klasse;)*       >
 * 
 * <!ELEMENT  abbildung    (titel?)                                        >
 * <!ATTLIST  abbildung
 *             pid         ID             #IMPLIED
 *             src         CDATA          #REQUIRED
 *             alt         CDATA          #IMPLIED
 *             hoehe       CDATA          #IMPLIED
 *             weite       CDATA          #IMPLIED
 * >
 * <!ELEMENT  liste        (listenPunkt|liste|numListe)+                   >
 * <!ATTLIST  liste   zeichen    (punkt|eckig|kreis)     "punkt"           >
 * 
 * <!ELEMENT  numListe     (listenPunkt|liste|numListe)+                   >
 * <!ATTLIST  numListe
 *              typ        (1|a|A|i|I) "1"
 *              start      CDATA                                 #IMPLIED  >
 * 
 * <!ELEMENT  listenPunkt  (#PCDATA | %absatzauszeichnung.klasse; | %zeichenauszeichnung.klasse;)* >
 *                           
 * <!ELEMENT  referenz      (titel?,info?)                                 >
 * <!ATTLIST  referenz
 *            pid                    ID              #REQUIRED
 *            link                   CDATA           #IMPLIED
 *            inReferenzverzeichnis  (j|n)           #IMPLIED
 * >
 * 
 * <!--                    Tabellenbeschreibung                       -->
 * 
 * <!ELEMENT tabelle   (titel?, spalte*, kopf?, rumpf)>
 * <!ATTLIST  tabelle
 *             pid        ID                              #IMPLIED
 *             rahmen      (0|1|2|3|4|5) "1"
 *             ausrichtung (l|r|m|s)   "m"
 *             transponiert (j|n)      "n" >
 * 
 * <!ELEMENT  spalte  EMPTY   >
 * <!ATTLIST  spalte breite CDATA   #REQUIRED>
 * <!ATTLIST  spalte hintergrund CDATA   #IMPLIED>
 * 
 * <!ELEMENT kopf      (zeile)+>
 * <!ELEMENT rumpf     (zeile)+>
 * 
 * <!ELEMENT zeile     (zelle)+>
 * 
 * <!ELEMENT  zelle   (#PCDATA | %zeichenauszeichnung.klasse; | %absatzauszeichnung.klasse;)* >
 * <!ATTLIST  zelle
 *             ausrichtung (l|r|m)        #IMPLIED
 *             vertikal    (o|m|u)        #IMPLIED
 *             hintergrund CDATA          #IMPLIED
 *             kopf        (j|n)          #IMPLIED
 *             breite      CDATA          #IMPLIED
 *             anzSpalten  NMTOKEN        #IMPLIED
 *             anzZeilen   NMTOKEN        #IMPLIED                         >
 * 
 * <!ELEMENT  titel        (#PCDATA | %zeichenauszeichnung.klasse;)*       >
 * 
 * <!ELEMENT  kommentar   ( #PCDATA| %zeichenauszeichnung.klasse; | %absatzauszeichnung.klasse;)* >
 * <!ATTLIST  kommentar
 * 				titel CDATA #REQUIRED
 * 				status (unklar|erledigt) "unklar"
 * >
 * <!ELEMENT  listenPunkt  (#PCDATA | %absatzauszeichnung.klasse; | %zeichenauszeichnung.klasse;)* >
 * 
 * <!ELEMENT  spalte  EMPTY   >
 * <!ATTLIST  spalte breite CDATA   #REQUIRED>
 * <!ATTLIST  spalte hintergrund CDATA   #IMPLIED>
 * 
 * <!ELEMENT kopf      (zeile)+>
 * 
 * <!ELEMENT rumpf     (zeile)+>
 * 
 * <!ELEMENT zeile     (zelle)+>
 * 
 * <!ELEMENT  zelle   (#PCDATA | %zeichenauszeichnung.klasse; | %absatzauszeichnung.klasse;)* >
 * <!ATTLIST  zelle
 *             ausrichtung (l|r|m)        #IMPLIED
 *             vertikal    (o|m|u)        #IMPLIED
 *             hintergrund CDATA          #IMPLIED
 *             kopf        (j|n)          #IMPLIED
 *             breite      CDATA          #IMPLIED
 *             anzSpalten  NMTOKEN        #IMPLIED
 *             anzZeilen   NMTOKEN        #IMPLIED                         >
 *
 *
 * <!ELEMENT  sektion (titel,(anker|(%absatzauszeichnung.klasse;)|(%verzeichnis.klasse;))*)>
 * <!ATTLIST  sektion
 *            pid        ID  #IMPLIED  >
 *
 * 
 * 
 * @author inovat
 * @author Liliya Givorgizova (LG)
 * @version $Revision: 408 $ / $Date: 2010-04-06 08:14:07 +0200 (Di, 06. Apr 2010) $ / ($Author: HCK $)
 */

public class Inhalt {
// ------------------------------------------------------------------------
// VARIABLENDEKLARATIONEN
// ------------------------------------------------------------------------

// Private ----------------------------------------------------------------;
	/** Definiert den Typ der Instanz. Abhngig vom Typ wird die Formatierung angewandt.*/
	private InhaltTyp _typ;
	/** Weitere Inhalte, die unter diesem Typ (Formatierung) liegen. */
	private List<Inhalt> _listeInhalte;
	/**
	 * Der auszugebende Text.
	 * Wird nur fr den Typ 'string' belegt.
	 */
	private String _text; // #PCDATA

	// Folgende Variable werden nur fr die bestimmten Typen, die eine AttributListe haben, benutzt:

	/** Sichtbar (j|n) fr den Typ index. */
	private String _indexSichtbar;
	/** id fr den Typ index (kann null sein). */
	private String _indexID;

	/** id fr den Typ hinweis (kann null sein). */
	private String _hinweisPID;
	/** typ (seite|dokument|absatz) fr den Typ hinweis. */
	private String _hinweisTyp;

	/** Title fr den Typ kommentar (kann null sein). */
	private String _kommentarTitel;
	/** status (unklar|erledigt) fr den Typ kommentar. */
	private String _kommentarStatus;

	/** pid fr den Typ verweis. */
	private String _verweisPID;
	/** txt fr den Typ verweis (kann null sein). */
	private String _verweisTxt;
	/** num (j|n) fr den Typ verweis. */
	private String _verweisNum;
	/** klammer (j|n) fr den Typ verweis. */
	private String _verweisKlammer;
	/** direkt (j|n) fr den Typ verweis. */
	private String _verweisDirekt;
	/** tooltip (j|n) fr den Typ verweis. */
	private String _verweisTooltip;

	/** pid fr den Typ anker. */
	private String _ankerPID;
	/** txt fr den Typ anker (kann null sein). */
	private String _ankerTxt;

	/** pid fr den Typ abbildung (kann null sein). */
	private String _abbildungPID;
	/** scr fr den Typ abbildung. */
	private String _abbildungScr;
	/** alt fr den Typ abbildung (kann null sein). */
	private String _abbildungAlt;
	/** hoehe fr den Typ abbildung (kann null sein). */
	private String _abbildungHoehe;
	/** weite fr den Typ abbildung (kann null sein). */
	private String _abbildungWeite;

	/** zeichen (punkt|eckig|kreis) fr den Typ liste. */
	private String _listeZeichen;

	/** typ (1|a|A|i|I) fr den Typ numListe. */
	private String _numListeTyp;
	/** start fr den Typ numListe (kann null sein). */
	private String _numListeStart;

	/** pid fr den Typ referenz. */
	private String _referenzPID;
	/** link fr den Typ referenz (kann null sein). */
	private String _referenzLink;
	/** inReferenzverzeichnis  (j|n) fr den Typ referenz. */
	private String _referenzInReferenzverzeichnis;

	/** pid fr den Typ tabelle (kann null sein). */
	private String _tabellePID;
	/** rahmen (0|1|2|3|4|5) fr den Typ tabelle. */
	private String _tabelleRahmen;
	/** ausrichtung (l|r|m|s)  fr den Typ tabelle. */
	private String _tabelleAusrichtung;
	/** transponiert (j|n)  fr den Typ tabelle. */
	private String _tabelleTransponiert;

	/** breite fr den Typ spalte. */
	private String _spalteBreite;
	/** hintergrund fr den Typ spalte (kann null sein). */
	private String _spalteHintergrund;

	/** ausrichtung (l|r|m) fr den Typ zelle. */
	private String _zelleAusrichtung;
	/** vertikal (o|m|u) fr den Typ zelle. */
	private String _zelleVertikal;
	/** hintergrund fr den Typ zelle (kann null sein). */
	private String _zelleHintergrund;
	/** kopf  (j|n) fr den Typ zelle. */
	private String _zelleKopf;
	/** breite fr den Typ zelle (kann null sein). */
	private String _zelleBreite;
	/** anzSpalten fr den Typ zelle (kann null sein). */
	private String _zelleAnzSpalten;
	/** anzZeilen fr den Typ zelle (kann null sein). */
	private String _zelleAnzZeilen;

	/** PID fr den Typ sektion (kann null sein). */
	private String _sektionPid;

// ------------------------------------------------------------------------
// KONSTRUKTOREN  (und vom Konstruktor verwende Methoden)
// ------------------------------------------------------------------------

	/**
	 * Erzeugt eine Instanz der Klasse Inhalt.
	 *
	 * @param typ
	 * @param listeInhalte
	 * @param text
	 */
	public Inhalt(InhaltTyp typ, List<Inhalt> listeInhalte, String text) {
		_typ = typ;
		_listeInhalte = listeInhalte;
		_text = text;
	}

// ------------------------------------------------------------------------
// GETTER / SETTER METHODEN
// ------------------------------------------------------------------------

	/**
	 * Getter fr Eigenschaft 'abbildungAlt'.
	 *
	 * @return Wert der Eigenschaft 'abbildungAlt'.
	 *
	 * @see  {#link _abbildungAlt}
	 */
	public String getAbbildungAlt() {
		return _abbildungAlt;
	}

	/**
	 * Setter fr Eigenschaft 'abbildungAlt'.
	 *
	 * @param abbildungAlt Wert zum Setzen der Eigenschaft 'abbildungAlt'.
	 *
	 * @see {#link _abbildungAlt}
	 */
	public void setAbbildungAlt(String abbildungAlt) {
		_abbildungAlt = abbildungAlt;
	}

	/**
	 * Getter fr Eigenschaft 'abbildungHoehe'.
	 *
	 * @return Wert der Eigenschaft 'abbildungHoehe'.
	 *
	 * @see  {#link _abbildungHoehe}
	 */
	public String getAbbildungHoehe() {
		return _abbildungHoehe;
	}

	/**
	 * Setter fr Eigenschaft 'abbildungHoehe'.
	 *
	 * @param abbildungHoehe Wert zum Setzen der Eigenschaft 'abbildungHoehe'.
	 *
	 * @see {#link _abbildungHoehe}
	 */
	public void setAbbildungHoehe(String abbildungHoehe) {
		_abbildungHoehe = abbildungHoehe;
	}

	/**
	 * Getter fr Eigenschaft 'abbildungPID'.
	 *
	 * @return Wert der Eigenschaft 'abbildungPID'.
	 *
	 * @see  {#link _abbildungPID}
	 */
	public String getAbbildungPID() {
		return _abbildungPID;
	}

	/**
	 * Setter fr Eigenschaft 'abbildungPID'.
	 *
	 * @param abbildungPID Wert zum Setzen der Eigenschaft 'abbildungPID'.
	 *
	 * @see {#link _abbildungPID}
	 */
	public void setAbbildungPID(String abbildungPID) {
		_abbildungPID = abbildungPID;
	}

	/**
	 * Getter fr Eigenschaft 'abbildungScr'.
	 *
	 * @return Wert der Eigenschaft 'abbildungScr'.
	 *
	 * @see  {#link _abbildungScr}
	 */
	public String getAbbildungScr() {
		return _abbildungScr;
	}

	/**
	 * Setter fr Eigenschaft 'abbildungScr'.
	 *
	 * @param abbildungScr Wert zum Setzen der Eigenschaft 'abbildungScr'.
	 *
	 * @see {#link _abbildungScr}
	 */
	public void setAbbildungScr(String abbildungScr) {
		_abbildungScr = abbildungScr;
	}

	/**
	 * Getter fr Eigenschaft 'abbildungWeite'.
	 *
	 * @return Wert der Eigenschaft 'abbildungWeite'.
	 *
	 * @see  {#link _abbildungWeite}
	 */
	public String getAbbildungWeite() {
		return _abbildungWeite;
	}

	/**
	 * Setter fr Eigenschaft 'abbildungWeite'.
	 *
	 * @param abbildungWeite Wert zum Setzen der Eigenschaft 'abbildungWeite'.
	 *
	 * @see {#link _abbildungWeite}
	 */
	public void setAbbildungWeite(String abbildungWeite) {
		_abbildungWeite = abbildungWeite;
	}

	/**
	 * Getter fr Eigenschaft 'ankerPID'.
	 *
	 * @return Wert der Eigenschaft 'ankerPID'.
	 *
	 * @see  {#link _ankerPID}
	 */
	public String getAnkerPID() {
		return _ankerPID;
	}

	/**
	 * Setter fr Eigenschaft 'ankerPID'.
	 *
	 * @param ankerPID Wert zum Setzen der Eigenschaft 'ankerPID'.
	 *
	 * @see {#link _ankerPID}
	 */
	public void setAnkerPID(String ankerPID) {
		_ankerPID = ankerPID;
	}

	/**
	 * Getter fr Eigenschaft 'ankerTxt'.
	 *
	 * @return Wert der Eigenschaft 'ankerTxt'.
	 *
	 * @see  {#link _ankerTxt}
	 */
	public String getAnkerTxt() {
		return _ankerTxt;
	}

	/**
	 * Setter fr Eigenschaft 'ankerTxt'.
	 *
	 * @param ankerTxt Wert zum Setzen der Eigenschaft 'ankerTxt'.
	 *
	 * @see {#link _ankerTxt}
	 */
	public void setAnkerTxt(String ankerTxt) {
		_ankerTxt = ankerTxt;
	}

	/**
	 * Getter fr Eigenschaft 'hinweisPID'.
	 *
	 * @return Wert der Eigenschaft 'hinweisPID'.
	 *
	 * @see  {#link _hinweisPID}
	 */
	public String getHinweisPID() {
		return _hinweisPID;
	}

	/**
	 * Setter fr Eigenschaft 'hinweisPID'.
	 *
	 * @param hinweisPID Wert zum Setzen der Eigenschaft 'hinweisPID'.
	 *
	 * @see {#link _hinweisPID}
	 */
	public void setHinweisPID(String hinweisPID) {
		_hinweisPID = hinweisPID;
	}

	/**
	 * Getter fr Eigenschaft 'hinweisTyp'.
	 *
	 * @return Wert der Eigenschaft 'hinweisTyp'.
	 *
	 * @see  {#link _hinweisTyp}
	 */
	public String getHinweisTyp() {
		return _hinweisTyp;
	}

	/**
	 * Setter fr Eigenschaft 'hinweisTyp'.
	 *
	 * @param hinweisTyp Wert zum Setzen der Eigenschaft 'hinweisTyp'.
	 *
	 * @see {#link _hinweisTyp}
	 */
	public void setHinweisTyp(String hinweisTyp) {
		_hinweisTyp = hinweisTyp;
	}

	/**
	 * Getter fr Eigenschaft 'indexID'.
	 *
	 * @return Wert der Eigenschaft 'indexID'.
	 *
	 * @see  {#link _indexID}
	 */
	public String getIndexID() {
		return _indexID;
	}

	/**
	 * Setter fr Eigenschaft 'indexID'.
	 *
	 * @param indexID Wert zum Setzen der Eigenschaft 'indexID'.
	 *
	 * @see {#link _indexID}
	 */
	public void setIndexID(String indexID) {
		_indexID = indexID;
	}

	/**
	 * Getter fr Eigenschaft 'indexSichtbar'.
	 *
	 * @return Wert der Eigenschaft 'indexSichtbar'.
	 *
	 * @see  {#link _indexSichtbar}
	 */
	public String getIndexSichtbar() {
		return _indexSichtbar;
	}

	/**
	 * Setter fr Eigenschaft 'indexSichtbar'.
	 *
	 * @param indexSichtbar Wert zum Setzen der Eigenschaft 'indexSichtbar'.
	 *
	 * @see {#link _indexSichtbar}
	 */
	public void setIndexSichtbar(String indexSichtbar) {
		_indexSichtbar = indexSichtbar;
	}

	/**
	 * Getter fr Eigenschaft 'kommentarStatus'.
	 *
	 * @return Wert der Eigenschaft 'kommentarStatus'.
	 *
	 * @see  {#link _kommentarStatus}
	 */
	public String getKommentarStatus() {
		return _kommentarStatus;
	}

	/**
	 * Setter fr Eigenschaft 'kommentarStatus'.
	 *
	 * @param kommentarStatus Wert zum Setzen der Eigenschaft 'kommentarStatus'.
	 *
	 * @see {#link _kommentarStatus}
	 */
	public void setKommentarStatus(String kommentarStatus) {
		_kommentarStatus = kommentarStatus;
	}

	/**
	 * Getter fr Eigenschaft 'kommentarTitel'.
	 *
	 * @return Wert der Eigenschaft 'kommentarTitel'.
	 *
	 * @see  {#link _kommentarTitel}
	 */
	public String getKommentarTitel() {
		return _kommentarTitel;
	}

	/**
	 * Setter fr Eigenschaft 'kommentarTitel'.
	 *
	 * @param kommentarTitel Wert zum Setzen der Eigenschaft 'kommentarTitel'.
	 *
	 * @see {#link _kommentarTitel}
	 */
	public void setKommentarTitel(String kommentarTitel) {
		_kommentarTitel = kommentarTitel;
	}

	/**
	 * Getter fr Eigenschaft 'listeInhalte'.
	 *
	 * @return Wert der Eigenschaft 'listeInhalte'.
	 *
	 * @see  {#link _listeInhalte}
	 */
	public List<Inhalt> getListeInhalte() {
		return _listeInhalte;
	}

	/**
	 * Getter fr Eigenschaft 'listeZeichen'.
	 *
	 * @return Wert der Eigenschaft 'listeZeichen'.
	 *
	 * @see  {#link _listeZeichen}
	 */
	public String getListeZeichen() {
		return _listeZeichen;
	}

	/**
	 * Setter fr Eigenschaft 'listeZeichen'.
	 *
	 * @param listeZeichen Wert zum Setzen der Eigenschaft 'listeZeichen'.
	 *
	 * @see {#link _listeZeichen}
	 */
	public void setListeZeichen(String listeZeichen) {
		_listeZeichen = listeZeichen;
	}

	/**
	 * Getter fr Eigenschaft 'numListeStart'.
	 *
	 * @return Wert der Eigenschaft 'numListeStart'.
	 *
	 * @see  {#link _numListeStart}
	 */
	public String getNumListeStart() {
		return _numListeStart;
	}

	/**
	 * Setter fr Eigenschaft 'numListeStart'.
	 *
	 * @param numListeStart Wert zum Setzen der Eigenschaft 'numListeStart'.
	 *
	 * @see {#link _numListeStart}
	 */
	public void setNumListeStart(String numListeStart) {
		_numListeStart = numListeStart;
	}

	/**
	 * Getter fr Eigenschaft 'numListeTyp'.
	 *
	 * @return Wert der Eigenschaft 'numListeTyp'.
	 *
	 * @see  {#link _numListeTyp}
	 */
	public String getNumListeTyp() {
		return _numListeTyp;
	}

	/**
	 * Setter fr Eigenschaft 'numListeTyp'.
	 *
	 * @param numListeTyp Wert zum Setzen der Eigenschaft 'numListeTyp'.
	 *
	 * @see {#link _numListeTyp}
	 */
	public void setNumListeTyp(String numListeTyp) {
		_numListeTyp = numListeTyp;
	}

	/**
	 * Getter fr Eigenschaft 'referenzInReferenzverzeichnis'.
	 *
	 * @return Wert der Eigenschaft 'referenzInReferenzverzeichnis'.
	 *
	 * @see  {#link _referenzInReferenzverzeichnis}
	 */
	public String getReferenzInReferenzverzeichnis() {
		return _referenzInReferenzverzeichnis;
	}

	/**
	 * Setter fr Eigenschaft 'referenzInReferenzverzeichnis'.
	 *
	 * @param referenzInReferenzverzeichnis Wert zum Setzen der Eigenschaft 'referenzInReferenzverzeichnis'.
	 *
	 * @see {#link _referenzInReferenzverzeichnis}
	 */
	public void setReferenzInReferenzverzeichnis(
			String referenzInReferenzverzeichnis) {
		_referenzInReferenzverzeichnis = referenzInReferenzverzeichnis;
	}

	/**
	 * Getter fr Eigenschaft 'referenzLink'.
	 *
	 * @return Wert der Eigenschaft 'referenzLink'.
	 *
	 * @see  {#link _referenzLink}
	 */
	public String getReferenzLink() {
		return _referenzLink;
	}

	/**
	 * Setter fr Eigenschaft 'referenzLink'.
	 *
	 * @param referenzLink Wert zum Setzen der Eigenschaft 'referenzLink'.
	 *
	 * @see {#link _referenzLink}
	 */
	public void setReferenzLink(String referenzLink) {
		_referenzLink = referenzLink;
	}

	/**
	 * Getter fr Eigenschaft 'referenzPID'.
	 *
	 * @return Wert der Eigenschaft 'referenzPID'.
	 *
	 * @see  {#link _referenzPID}
	 */
	public String getReferenzPID() {
		return _referenzPID;
	}

	/**
	 * Setter fr Eigenschaft 'referenzPID'.
	 *
	 * @param referenzPID Wert zum Setzen der Eigenschaft 'referenzPID'.
	 *
	 * @see {#link _referenzPID}
	 */
	public void setReferenzPID(String referenzPID) {
		_referenzPID = referenzPID;
	}

	/**
	 * Getter fr Eigenschaft 'sektionPid'.
	 *
	 * @return Wert der Eigenschaft 'sektionPid'.
	 *
	 * @see  {#link _sektionPid}
	 */
	public String getSektionPid() {
		return _sektionPid;
	}

	/**
	 * Setter fr Eigenschaft 'sektionPid'.
	 *
	 * @param sektionPid Wert zum Setzen der Eigenschaft 'sektionPid'.
	 *
	 * @see {#link _sektionPid}
	 */
	public void setSektionPid(String sektionPid) {
		_sektionPid = sektionPid;
	}

	/**
	 * Getter fr Eigenschaft 'spalteBreite'.
	 *
	 * @return Wert der Eigenschaft 'spalteBreite'.
	 *
	 * @see  {#link _spalteBreite}
	 */
	public String getSpalteBreite() {
		return _spalteBreite;
	}

	/**
	 * Setter fr Eigenschaft 'spalteBreite'.
	 *
	 * @param spalteBreite Wert zum Setzen der Eigenschaft 'spalteBreite'.
	 *
	 * @see {#link _spalteBreite}
	 */
	public void setSpalteBreite(String spalteBreite) {
		_spalteBreite = spalteBreite;
	}

	/**
	 * Getter fr Eigenschaft 'spalteHintergrund'.
	 *
	 * @return Wert der Eigenschaft 'spalteHintergrund'.
	 *
	 * @see  {#link _spalteHintergrund}
	 */
	public String getSpalteHintergrund() {
		return _spalteHintergrund;
	}

	/**
	 * Setter fr Eigenschaft 'spalteHintergrund'.
	 *
	 * @param spalteHintergrund Wert zum Setzen der Eigenschaft 'spalteHintergrund'.
	 *
	 * @see {#link _spalteHintergrund}
	 */
	public void setSpalteHintergrund(String spalteHintergrund) {
		_spalteHintergrund = spalteHintergrund;
	}

	/**
	 * Getter fr Eigenschaft 'tabelleAusrichtung'.
	 *
	 * @return Wert der Eigenschaft 'tabelleAusrichtung'.
	 *
	 * @see  {#link _tabelleAusrichtung}
	 */
	public String getTabelleAusrichtung() {
		return _tabelleAusrichtung;
	}

	/**
	 * Setter fr Eigenschaft 'tabelleAusrichtung'.
	 *
	 * @param tabelleAusrichtung Wert zum Setzen der Eigenschaft 'tabelleAusrichtung'.
	 *
	 * @see {#link _tabelleAusrichtung}
	 */
	public void setTabelleAusrichtung(String tabelleAusrichtung) {
		_tabelleAusrichtung = tabelleAusrichtung;
	}

	/**
	 * Getter fr Eigenschaft 'tabellePID'.
	 *
	 * @return Wert der Eigenschaft 'tabellePID'.
	 *
	 * @see  {#link _tabellePID}
	 */
	public String getTabellePID() {
		return _tabellePID;
	}

	/**
	 * Setter fr Eigenschaft 'tabellePID'.
	 *
	 * @param tabellePID Wert zum Setzen der Eigenschaft 'tabellePID'.
	 *
	 * @see {#link _tabellePID}
	 */
	public void setTabellePID(String tabellePID) {
		_tabellePID = tabellePID;
	}

	/**
	 * Getter fr Eigenschaft 'tabelleRahmen'.
	 *
	 * @return Wert der Eigenschaft 'tabelleRahmen'.
	 *
	 * @see  {#link _tabelleRahmen}
	 */
	public String getTabelleRahmen() {
		return _tabelleRahmen;
	}

	/**
	 * Setter fr Eigenschaft 'tabelleRahmen'.
	 *
	 * @param tabelleRahmen Wert zum Setzen der Eigenschaft 'tabelleRahmen'.
	 *
	 * @see {#link _tabelleRahmen}
	 */
	public void setTabelleRahmen(String tabelleRahmen) {
		_tabelleRahmen = tabelleRahmen;
	}

	/**
	 * Getter fr Eigenschaft 'tabelleTransponiert'.
	 *
	 * @return Wert der Eigenschaft 'tabelleTransponiert'.
	 *
	 * @see  {#link _tabelleTransponiert}
	 */
	public String getTabelleTransponiert() {
		return _tabelleTransponiert;
	}

	/**
	 * Setter fr Eigenschaft 'tabelleTransponiert'.
	 *
	 * @param tabelleTransponiert Wert zum Setzen der Eigenschaft 'tabelleTransponiert'.
	 *
	 * @see {#link _tabelleTransponiert}
	 */
	public void setTabelleTransponiert(String tabelleTransponiert) {
		_tabelleTransponiert = tabelleTransponiert;
	}

	/**
	 * Getter fr Eigenschaft 'text'.
	 *
	 * @return Wert der Eigenschaft 'text'.
	 *
	 * @see  {#link _text}
	 */
	public String getText() {
		return _text;
	}

	/**
	 * Getter fr Eigenschaft 'typ'.
	 *
	 * @return Wert der Eigenschaft 'typ'.
	 *
	 * @see  {#link _typ}
	 */
	public InhaltTyp getTyp() {
		return _typ;
	}

	/**
	 * Getter fr Eigenschaft 'verweisDirekt'.
	 *
	 * @return Wert der Eigenschaft 'verweisDirekt'.
	 *
	 * @see  {#link _verweisDirekt}
	 */
	public String getVerweisDirekt() {
		return _verweisDirekt;
	}

	/**
	 * Setter fr Eigenschaft 'verweisDirekt'.
	 *
	 * @param verweisDirekt Wert zum Setzen der Eigenschaft 'verweisDirekt'.
	 *
	 * @see {#link _verweisDirekt}
	 */
	public void setVerweisDirekt(String verweisDirekt) {
		_verweisDirekt = verweisDirekt;
	}

	/**
	 * Getter fr Eigenschaft 'verweisKlammer'.
	 *
	 * @return Wert der Eigenschaft 'verweisKlammer'.
	 *
	 * @see  {#link _verweisKlammer}
	 */
	public String getVerweisKlammer() {
		return _verweisKlammer;
	}

	/**
	 * Setter fr Eigenschaft 'verweisKlammer'.
	 *
	 * @param verweisKlammer Wert zum Setzen der Eigenschaft 'verweisKlammer'.
	 *
	 * @see {#link _verweisKlammer}
	 */
	public void setVerweisKlammer(String verweisKlammer) {
		_verweisKlammer = verweisKlammer;
	}

	/**
	 * Getter fr Eigenschaft 'verweisNum'.
	 *
	 * @return Wert der Eigenschaft 'verweisNum'.
	 *
	 * @see  {#link _verweisNum}
	 */
	public String getVerweisNum() {
		return _verweisNum;
	}

	/**
	 * Setter fr Eigenschaft 'verweisNum'.
	 *
	 * @param verweisNum Wert zum Setzen der Eigenschaft 'verweisNum'.
	 *
	 * @see {#link _verweisNum}
	 */
	public void setVerweisNum(String verweisNum) {
		_verweisNum = verweisNum;
	}

	/**
	 * Getter fr Eigenschaft 'verweisPID'.
	 *
	 * @return Wert der Eigenschaft 'verweisPID'.
	 *
	 * @see  {#link _verweisPID}
	 */
	public String getVerweisPID() {
		return _verweisPID;
	}

	/**
	 * Setter fr Eigenschaft 'verweisPID'.
	 *
	 * @param verweisPID Wert zum Setzen der Eigenschaft 'verweisPID'.
	 *
	 * @see {#link _verweisPID}
	 */
	public void setVerweisPID(String verweisPID) {
		_verweisPID = verweisPID;
	}

	/**
	 * Getter fr Eigenschaft 'verweisTooltip'.
	 *
	 * @return Wert der Eigenschaft 'verweisTooltip'.
	 *
	 * @see  {#link _verweisTooltip}
	 */
	public String getVerweisTooltip() {
		return _verweisTooltip;
	}

	/**
	 * Setter fr Eigenschaft 'verweisTooltip'.
	 *
	 * @param verweisTooltip Wert zum Setzen der Eigenschaft 'verweisTooltip'.
	 *
	 * @see {#link _verweisTooltip}
	 */
	public void setVerweisTooltip(String verweisTooltip) {
		_verweisTooltip = verweisTooltip;
	}

	/**
	 * Getter fr Eigenschaft 'verweisTxt'.
	 *
	 * @return Wert der Eigenschaft 'verweisTxt'.
	 *
	 * @see  {#link _verweisTxt}
	 */
	public String getVerweisTxt() {
		return _verweisTxt;
	}

	/**
	 * Setter fr Eigenschaft 'verweisTxt'.
	 *
	 * @param verweisTxt Wert zum Setzen der Eigenschaft 'verweisTxt'.
	 *
	 * @see {#link _verweisTxt}
	 */
	public void setVerweisTxt(String verweisTxt) {
		_verweisTxt = verweisTxt;
	}

	/**
	 * Getter fr Eigenschaft 'zelleAnzSpalten'.
	 *
	 * @return Wert der Eigenschaft 'zelleAnzSpalten'.
	 *
	 * @see  {#link _zelleAnzSpalten}
	 */
	public String getZelleAnzSpalten() {
		return _zelleAnzSpalten;
	}

	/**
	 * Setter fr Eigenschaft 'zelleAnzSpalten'.
	 *
	 * @param zelleAnzSpalten Wert zum Setzen der Eigenschaft 'zelleAnzSpalten'.
	 *
	 * @see {#link _zelleAnzSpalten}
	 */
	public void setZelleAnzSpalten(String zelleAnzSpalten) {
		_zelleAnzSpalten = zelleAnzSpalten;
	}

	/**
	 * Getter fr Eigenschaft 'zelleAnzZeilen'.
	 *
	 * @return Wert der Eigenschaft 'zelleAnzZeilen'.
	 *
	 * @see  {#link _zelleAnzZeilen}
	 */
	public String getZelleAnzZeilen() {
		return _zelleAnzZeilen;
	}

	/**
	 * Setter fr Eigenschaft 'zelleAnzZeilen'.
	 *
	 * @param zelleAnzZeilen Wert zum Setzen der Eigenschaft 'zelleAnzZeilen'.
	 *
	 * @see {#link _zelleAnzZeilen}
	 */
	public void setZelleAnzZeilen(String zelleAnzZeilen) {
		_zelleAnzZeilen = zelleAnzZeilen;
	}

	/**
	 * Getter fr Eigenschaft 'zelleAusrichtung'.
	 *
	 * @return Wert der Eigenschaft 'zelleAusrichtung'.
	 *
	 * @see  {#link _zelleAusrichtung}
	 */
	public String getZelleAusrichtung() {
		return _zelleAusrichtung;
	}

	/**
	 * Setter fr Eigenschaft 'zelleAusrichtung'.
	 *
	 * @param zelleAusrichtung Wert zum Setzen der Eigenschaft 'zelleAusrichtung'.
	 *
	 * @see {#link _zelleAusrichtung}
	 */
	public void setZelleAusrichtung(String zelleAusrichtung) {
		_zelleAusrichtung = zelleAusrichtung;
	}

	/**
	 * Getter fr Eigenschaft 'zelleBreite'.
	 *
	 * @return Wert der Eigenschaft 'zelleBreite'.
	 *
	 * @see  {#link _zelleBreite}
	 */
	public String getZelleBreite() {
		return _zelleBreite;
	}

	/**
	 * Setter fr Eigenschaft 'zelleBreite'.
	 *
	 * @param zelleBreite Wert zum Setzen der Eigenschaft 'zelleBreite'.
	 *
	 * @see {#link _zelleBreite}
	 */
	public void setZelleBreite(String zelleBreite) {
		_zelleBreite = zelleBreite;
	}

	/**
	 * Getter fr Eigenschaft 'zelleHintergrund'.
	 *
	 * @return Wert der Eigenschaft 'zelleHintergrund'.
	 *
	 * @see  {#link _zelleHintergrund}
	 */
	public String getZelleHintergrund() {
		return _zelleHintergrund;
	}

	/**
	 * Setter fr Eigenschaft 'zelleHintergrund'.
	 *
	 * @param zelleHintergrund Wert zum Setzen der Eigenschaft 'zelleHintergrund'.
	 *
	 * @see {#link _zelleHintergrund}
	 */
	public void setZelleHintergrund(String zelleHintergrund) {
		_zelleHintergrund = zelleHintergrund;
	}

	/**
	 * Getter fr Eigenschaft 'zelleKopf'.
	 *
	 * @return Wert der Eigenschaft 'zelleKopf'.
	 *
	 * @see  {#link _zelleKopf}
	 */
	public String getZelleKopf() {
		return _zelleKopf;
	}

	/**
	 * Setter fr Eigenschaft 'zelleKopf'.
	 *
	 * @param zelleKopf Wert zum Setzen der Eigenschaft 'zelleKopf'.
	 *
	 * @see {#link _zelleKopf}
	 */
	public void setZelleKopf(String zelleKopf) {
		_zelleKopf = zelleKopf;
	}

	/**
	 * Getter fr Eigenschaft 'zelleVertikal'.
	 *
	 * @return Wert der Eigenschaft 'zelleVertikal'.
	 *
	 * @see  {#link _zelleVertikal}
	 */
	public String getZelleVertikal() {
		return _zelleVertikal;
	}

	/**
	 * Setter fr Eigenschaft 'zelleVertikal'.
	 *
	 * @param zelleVertikal Wert zum Setzen der Eigenschaft 'zelleVertikal'.
	 *
	 * @see {#link _zelleVertikal}
	 */
	public void setZelleVertikal(String zelleVertikal) {
		_zelleVertikal = zelleVertikal;
	}

// ------------------------------------------------------------------------
// ENUMERATIONEN
// ------------------------------------------------------------------------

	/**
	 * Sind folgende Typen definiert:
	 *
	 * 1. Typ #PCDATA:
	 * 		string
	 *
	 * 2. Einfache Typen der Art: (#PCDATA| %zeichenauszeichnung.klasse;)*
	 * 		tief, hoch, code, adresse, pre, wichtig, zitat, absatz
	 *
	 * 3. Komplizierte Typen der Art: ((#PCDATA| %zeichenauszeichnung.klasse;)*
	 *    oder (#PCDATA | %zeichenauszeichnung.klasse; | %absatzauszeichnung.klasse;)*
	 *    und mit Attributlisten)
	 * 		index, hinweis, kommentar
	 *
	 * 4. Komplizierte Typen (EMPTY und mit Attributlisten):
	 * 		verweis, anker
	 *
	 * 5. Komplizierte Typen (mit Attributlisten und Elementen):
	 *		abbildung, liste, numListe, referenz, tabelle
	 *
	 * 6. Zustzliche Typen, die in komplizierten Typen benutzt werden:
	 * 		titel (2), listenPunkt (2), spalte (4), kopf (5*), rumf(5*), zeile(5*), zelle (3)
	 *
	 * 7. Komplizierte Typen der Art 3 und 5:
	 * 		sektion
	 *
	 * 8. Definiert die Instant des ersten im Kurzinfo oder Beschreibung Inhalts.
	 *    Das bedeutet, dass dieser Typ nicht bewertet wird, sondern
	 *    seine Liste _listeInhalte bearbeiten wird:
	 * 		startInfo
	 *
	 */
	public enum InhaltTyp {string,
						tief, hoch, code, adresse, pre, wichtig, zitat, absatz,
						index, hinweis, kommentar,
						verweis, anker,
						abbildung, liste, numListe, referenz, tabelle,
						titel, listenPunkt, spalte, kopf, rumpf, zeile, zelle,
						sektion,
						startInfo,
						unbekannt}
}
