/*
 * Copyright 2008 by inovat, innovative systeme - verkehr - tunnel - technik, Dipl.-Ing. H. C. Kni, Kln
 * <p>
 * This file is part of de.inovat.pat.datkat2html
 * <p>
 * de.inovat.pat.datkat2html is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * <p>
 * de.inovat.pat.datkat2html is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * <p>
 * You should have received a copy of the GNU General Public License
 * along with de.inovat.pat.datkat2html; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 * <p>
 * Contact Information:<br>
 * inovat, Dipl.-Ing. H. C. Kni<br>
 * Klner Strae 30<br>
 * 50859 Kln<br>
 * Phone: +49 2234 4301 800<br>
 * mailto: info@inovat.de
 */
package de.inovat.pat.datkat2html.html;

import de.inovat.pat.datkat2html.Activator;
import de.inovat.pat.datkat2html.Log;
import de.inovat.pat.datkat2html.ausgabe.*;
import de.inovat.pat.datkat2html.ausgabe.ascii.ASCIIAusgabe;
import de.inovat.pat.datkat2html.ausgabe.beschreibung.*;
import de.inovat.pat.datkat2html.ausgabe.html.HTMLAusgabe;
import de.inovat.pat.datkat2html.html.KonvertierungsProzessAenderungen.MeldungsTyp;
import de.inovat.pat.datkat2html.vew.KonfigurationsBereich;
import de.inovat.pat.datkat2html.vew.KonvertierungsVorgabe;
import de.inovat.sys.funclib.bsvrzxml.BSVRZXML;
import org.eclipse.core.runtime.*;

import javax.xml.bind.JAXBException;
import java.io.FileNotFoundException;
import java.util.*;

/**
 * Klasse verwaltet die Ausgabe der Dateien.
 * 
 * @author inovat
 * @author Liliya Givorgizova (LG)
 * @version $Revision: 408 $ / $Date: 2010-04-06 08:14:07 +0200 (Di, 06. Apr 2010) $ / ($Author: HCK $)
 */

public class DateiAusgabe {
// ------------------------------------------------------------------------
// VARIABLENDEKLARATIONEN
// ------------------------------------------------------------------------

// Sonstige ---------------------------------------------------------------
	/**
	 * Die Menge die als Listener bei den KonvertierungsProzess registrierten Klassen.
	 * Diese Klassen implementieren IKonvertierungsProzessAenderungen.
	 */
	private static Set<IKonvertierungsProzessAenderungen> _mengeKonvertierungAenderungenListener=new HashSet<IKonvertierungsProzessAenderungen>();
// Private ----------------------------------------------------------------
	/** Liste alle KBDateien. */
	private List<BSVRZXML> _listeKBDatei=new ArrayList<BSVRZXML>();

	/**
	 * Die fr die Referenz bentigte Information.
	 * Liefert das PID von KonfigurationBereich, wo das Element definiert ist
	 * und Pfad zur XMLDatei, wo KB definiert ist.
	 */
	private ReferenzInformation _refInfo;

	/** Die Angaben zu der Konvertierung. */
	private KonvertierungsVorgabe _konvVorgabe;

	/** Erfasst Definitionen fr alle Elemente aus alle KBDateien */
	private AlleDefinitionen _alleDefinitionen;

	/** Definiert, ob fr diese Ausgabe das Listener benachrichtigt werden soll. */
	private boolean _isListener;

	/**
	 *  Definiert, ob Abbruch gedruckt wurde.
	 *  Wird von GUI gesetzt.
	 *  Abgebrochen werden kann am Anfang der Ausgabe des nchsten KBDatei.
	 */
	private boolean _isAbbruch=false;

	/** Datei, die fr die Ansicht gestartet werden soll. */
	private String _startDatei="";

// ------------------------------------------------------------------------
// STATISCHE METHODEN
// ------------------------------------------------------------------------

	/**
	 * Registriert Klasse als Listener auf IKonvertierungsProzessAenderungen.
	 *
	 * @param klasse
	 *            Klasse, die das Interface IKonvertierungsProzessAenderungen
	 *            implementiert und ber KonvertierungsProzessnderungen informiert werden
	 *            will.
	 */
	public static void addKonvertierungListener(IKonvertierungsProzessAenderungen klasse) {
		_mengeKonvertierungAenderungenListener.add(klasse);
	}

	/**
	 * Lscht die Registrierung einer Klasse als Listener auf
	 * IKonvertierungsProzessAenderungen.
	 *
	 * @param klasse
	 *            Klasse, die sich zuvor mittels addKonvertierungListener
	 *            registriert hat.
	 */
	public static void removeKonvertierungListener(IKonvertierungsProzessAenderungen klasse) {
		_mengeKonvertierungAenderungenListener.remove(klasse);
	}

// ------------------------------------------------------------------------
// KONSTRUKTOREN  (und vom Konstruktor verwende Methoden)
// ------------------------------------------------------------------------

	/**
	 * Erzeuge eine Instanz der Klasse DateiAusgabe.
	 *
	 * @param listeKBDatei Liste aller zu bearbeiteten KBDatei.
	 * @param refInfo Die fr die Referenz bentigte Information.
	 * @param konvVorgabe Die Angaben zu der Konvertierung.
	 */
	public DateiAusgabe(List<KonfigurationsBereich> listeKB,
			KonvertierungsVorgabe konvVorgabe) {
		List<String> listeXMLDatei=new ArrayList<String>();
		Map<String, String> mapDateiPfad=new HashMap<String, String>();
		for(KonfigurationsBereich kb: listeKB){
			listeXMLDatei.add(kb.getPfad());
			mapDateiPfad.put(kb.getKb(), kb.getPfad());
		}
		_listeKBDatei = erzeugeListeKBDatei(listeXMLDatei);

		_refInfo=new ReferenzInformation(_listeKBDatei, mapDateiPfad);

		_konvVorgabe = konvVorgabe;

		_alleDefinitionen=new AlleDefinitionen(_listeKBDatei);
	}

	/**
	 * Erstelle die Liste der KBDateien.
	 *
	 * @param listeXMLDatei Liste enthlt die Namen der XMLDatei.
	 * @return Liste der KBDateien..
	 */
	private List<BSVRZXML> erzeugeListeKBDatei(List<String> listeXMLDatei){
		List<BSVRZXML> listeKBDatei=new ArrayList<BSVRZXML>();
		int anzahlKB=listeXMLDatei.size();
		int i=0;
		for(String xmlDatei: listeXMLDatei){
			try {
				BSVRZXML kbDatei = new BSVRZXML(xmlDatei);
				listeKBDatei.add(kbDatei);

				// Berechne FortschrittGesammt fr dieses Prozess (max=10%):
				Float prozentAll=10f/anzahlKB*i;
				ausloesenListener(null, null, prozentAll.intValue()+10, null, null);
				i++;
			} catch (FileNotFoundException e) {
				Log.zeige(Log.erzeugeMeldung(
						Log.FEHLER, Activator.PLUGIN_ID,
						"Die Datei ["+xmlDatei+"] wird nicht gefunden!", e));
			} catch (JAXBException e) {
				Log.zeige(Log.erzeugeMeldung(
						Log.FEHLER, Activator.PLUGIN_ID,
						"Die Darei ["+xmlDatei+"] ist kein gltiger Konfigurationsbereich!", e));
			}
		}
		return listeKBDatei;
	}

	/**
	 * Erstelle die Instanz der Klasse KonvertierungsProzessAenderungen und
	 * rufe die Methode benachrichtigeKonvertierungAenderungsListener() auf.
	 *
	 * Jeder Parameter kann den Wert null haben.
	 * Das heit, das sein Wert nicht gendert wurde
	 * und seine Vorstellung im GUI kann auch stabil bleiben.
	 *
	 * @param kbPid PID von Konfigurationsbereich.
	 * @param prozentKb Prozent des Fortschritts fr den Konfigurationsbereich.
	 * @param prozentAll Prozent des Fortschritts Gesammt.
	 * @param typModell Status des Modells.
	 * @param typObjekt Status der Objekten.
	 */
	private void ausloesenListener(String kbPid,
			Integer prozentKb, Integer prozentAll,
			MeldungsTyp typModell, MeldungsTyp typObjekt){
		if(_isListener){
			benachrichtigeKonvertierungAenderungsListener(
					new KonvertierungsProzessAenderungen
					(kbPid, prozentKb, prozentAll, typModell, typObjekt));
		}
	}

	/**
	 * Ruft bei nderungen im KonvertierungsProzess die Methode
	 * IKonvertierungsProzessAenderungen.konvertierungsProzessGeaendert}() fr jede als Listener registrierte
	 * Klasse auf.
	 *
	 * @param kpAenderungen
	 *            Beschreibung der Vernderungen des KonvertierungsProzesses.
	 */
	private static void benachrichtigeKonvertierungAenderungsListener( KonvertierungsProzessAenderungen kpAenderungen) {
		for (IKonvertierungsProzessAenderungen klasse : _mengeKonvertierungAenderungenListener) {
			klasse.konvertierungsProzessGeaendert(kpAenderungen);
		}
	}

// ------------------------------------------------------------------------
// GETTER / SETTER METHODEN
// ------------------------------------------------------------------------

	/**
	 * Getter fr Eigenschaft '_startDatei'.
	 *
	 * @return Wert der Eigenschaft '_startDatei'.
	 *
	 * @see (#link _startDatei)
	 */
	public String getStartDatei() {
		return _startDatei;
	}

	/**
	 * Getter fr Eigenschaft '_isAbbruch'.
	 *
	 * @return Wert der Eigenschaft '_isAbbruch'.
	 *
	 * @see {#link _isAbbruch}
	 */
	public boolean isAbbruch() {
		return _isAbbruch;
	}

	/**
	 * Setter fr Eigenschaft '_isAbbruch'.
	 *
	 * @param isAbbruch Wert zum Setzen der Eigenschaft '_isAbbruch'.
	 *
	 * @see {#link _isAbbruch}
	 */
	public void setAbbruch(boolean isAbbruch) {
		_isAbbruch = isAbbruch;
	}

// ------------------------------------------------------------------------
// SONSTIGE METHODEN
// ------------------------------------------------------------------------

	/**
	 * Konvertierung der in der Klasse definierten Dateien.
	 */
	public void ausgebenFormatierteDatei(){
		IAusgabe ascii=new ASCIIAusgabe(_konvVorgabe.getZielOrdner(), _refInfo);
		IAusgabe html=new HTMLAusgabe(_konvVorgabe.getZielOrdner(), _refInfo);

		//ausgebenDatei(ascii, true);
		ausgebenDatei(html, true);
	}

	/**
	 * Ausgabe der Dateien.
	 *
	 * @param ausgabe Definiert das Format der Ausgabe.
	 * @param isListener Definiert, ob fr diese Ausgabe das Listener benachrichtigt werden soll.
	 */
	private void ausgebenDatei(IAusgabe ausgabe, boolean isListener){
		ausgabe.loescheAlteDatei();
		_startDatei=ausgabe.ermittleStartDatei();
		_isListener=isListener;

		String kbPid;
		Float prozentAll;
		Integer prozentKb;
		MeldungsTyp typModell;
		MeldungsTyp typObjekt;

		boolean isModell;
		boolean isObjekt;

		int i=0;

		IStatus meldung;
		MultiStatus multiMeldung=new MultiStatus(Activator.PLUGIN_ID, 0,
				"Meldungen zur bersicht und Ahgngigkeitsmatrix.", null);;

		// 1 *************************************************************
		ausgabe.ausgebenKopfbereich(_konvVorgabe.getKommentar(), _konvVorgabe.getLangBezeichung());

		// 2 *************************************************************
		meldung=ausgabe.ausgebenTabelleKvKb(_alleDefinitionen.getListeKbBeschreibungenSortiert());
		addiereMeldung(meldung, multiMeldung);

		meldung=ausgabe.ausgebenAbhaengigkeitsmatrixKB(_alleDefinitionen.getListeKbBeschreibungenSortiert());
		addiereMeldung(meldung, multiMeldung);

		zeigeMultiMeldung(multiMeldung);

		for(BSVRZXML kbDatei: _listeKBDatei){
			// Abbrechen:
			if(_isAbbruch){
				break;
			}

			kbPid=kbDatei.getKb().getPid();
			KonfigurationsBereich kb=_konvVorgabe.getMapKonfigurationsBereich().get(kbPid);
			isModell=kb.isModell();
			isObjekt=kb.isObjekt();

			typModell=null;
			typObjekt=null;

			// Listener am Anfang:
			if(isModell){
				typModell=MeldungsTyp.inBearbeitung;
			}
			if(isObjekt){
				typObjekt=MeldungsTyp.inBearbeitung;
			}
			prozentAll=80f/_listeKBDatei.size()*i;
			prozentKb=0;
			ausloesenListener(kbPid, prozentKb, prozentAll.intValue()+20, typModell, typObjekt);

			// Ausgebe KB:
			KonvertierungXML2Beschreibung beschreibung=new KonvertierungXML2Beschreibung(_alleDefinitionen, kbDatei);

			MultiStatus[] arrMeldungen;
			arrMeldungen=ausgebenKB( beschreibung, ausgabe, isModell, isObjekt);

			i++;

			// Listener am Ende:
			//   Modell:
			if(isModell){
				if(arrMeldungen[0].getChildren().length>0){
					zeigeMultiMeldung(arrMeldungen[0]);
				}
				typModell=ermittleMeldungsTyp(arrMeldungen[0].getSeverity());
			}
			//   Objekt:
			if(isObjekt){
				if(arrMeldungen[1].getChildren().length>0){
					zeigeMultiMeldung(arrMeldungen[1]);
				}
				typObjekt=ermittleMeldungsTyp(arrMeldungen[1].getSeverity());
			}

			prozentAll=800f/_listeKBDatei.size()*i;
			prozentKb=100;
			ausloesenListener(kbPid, prozentKb, prozentAll.intValue()+20, typModell, typObjekt);
		}
	}

	/**
	 * Addiere Meldung (falls nicht null ist) zur multiMeldung.
	 *
	 * @param meldung
	 * @param multiMeldung
	 */
	private void addiereMeldung(IStatus meldung, MultiStatus multiMeldung){
		if(meldung!=null){
			multiMeldung.add(meldung);
		}
	}

	/**
	 * Gebe einzelnen Konfigurationsbereich aus.
	 *
	 * @param beschreibung Enthlt die Information ber den Konfigurationsbereich im Beschreibung-Format.
	 * @param ausgabe Definiert das Format der Ausgabe.
	 * @param isModell Definiert, ob Modell von Konfigurationsbereich ausgeben werden soll.
	 * @param isObjekt Definiert, ob Objekte von Konfigurationsbereich ausgeben werden sollen.
	 *
	 * @return Array von MultiMeldungen (Erstes Element: MultiMeldung fr Modell, zweites: fr Objekt).
	 */
	private MultiStatus[] ausgebenKB(KonvertierungXML2Beschreibung beschreibung, IAusgabe ausgabe,
			boolean isModell, boolean isObjekt){
		KonfigurationsBereichBeschreibung kbB=beschreibung.getKbB();
		String kbPid="";
		if(kbB!=null){
			kbPid=kbB.getUebersicht().getPid();
		}

		IStatus meldung;
		MultiStatus multiMeldungModell=new MultiStatus(Activator.PLUGIN_ID, 0,
				"Meldungen fr die Modelle des Konfigurationbereichs ["+kbPid+"]", null);
		MultiStatus multiMeldungObjekt=new MultiStatus(Activator.PLUGIN_ID, 0,
				"Meldungen fr die Objekte des Konfigurationbereichs ["+kbPid+"]", null);

		if(kbB!=null){
			ausgabe.initialisieren(kbPid);

			// 3 *************************************************************
			// 4 *************************************************************
			// KV, KB
			meldung=ausgabe.ausgebenKBTitel(kbB);
			addiereMeldung(meldung, multiMeldungModell);

			meldung=ausgabe.ausgebenKonfigurationsAenderungenTabelle(kbB.getListeKA());
			addiereMeldung(meldung, multiMeldungModell);

			ausloesenListener(null, 5, null, null, null);

			List<Uebersicht> listeUebersicht;

			// Modell:
			if((isModell)&&(kbB.getModel()!=null)){
				//5 *************************************************************
				meldung=ausgabe.ausgebenModellTitel();
				addiereMeldung(meldung, multiMeldungModell);

				// 6 *************************************************************
				// bersicht: TypDefinitionen
				listeUebersicht=beschreibung.getListeUebersichtTypDefinitionSortiert();
				meldung=ausgabe.ausgebenUebersichtListe(listeUebersicht, "TypDefinitionen");
				addiereMeldung(meldung, multiMeldungModell);

				// 6 *************************************************************
				// bersicht: MengenDefinitionen
				listeUebersicht=beschreibung.getListeUebersichtMengenDefinitionSortiert();
				meldung=ausgabe.ausgebenUebersichtListe(listeUebersicht,"MengenDefinitionen");
				addiereMeldung(meldung, multiMeldungModell);

				// 6 *************************************************************
				// bersicht: AttributGruppenDefinitionen
				listeUebersicht=beschreibung.getListeUebersichtAttributgruppenDefinitionSortiert();
				meldung=ausgabe.ausgebenUebersichtListe(listeUebersicht,"AttributGruppenDefinitionen");
				addiereMeldung(meldung, multiMeldungModell);

				ausloesenListener(null, 10, null, null, null);

				// 6 *************************************************************
				// bersicht: AttributListenDefinitionen
				listeUebersicht=beschreibung.getListeUebersichtAttributlistenDefinitionSortiert();
				meldung=ausgabe.ausgebenUebersichtListe(listeUebersicht,"AttributListenDefinitionen");
				addiereMeldung(meldung, multiMeldungModell);

				// 6 *************************************************************
				// bersicht: AttributDefinitionen
				listeUebersicht=beschreibung.getListeUebersichtAttributDefinitionSortiert();
				meldung=ausgabe.ausgebenUebersichtListe(listeUebersicht,"AttributDefinitionen");
				addiereMeldung(meldung, multiMeldungModell);

				/*
				// 6 *************************************************************
				// bersicht: AttributAuswahDefinitionen
				listeUebersicht=beschreibung.getListeUebersichtAttributauswahlDefinitionSortiert();
				meldung=ausgabe.ausgebenUebersichtListe(listeUebersicht,"AttributauswahDefinitionen");
				addiereMeldung(meldung, multiMeldungModell);
				*/

				// 6 *************************************************************
				// bersicht: AspektDefinitionen
				listeUebersicht=beschreibung.getListeUebersichtAspektDefinitionSortiert();
				meldung=ausgabe.ausgebenUebersichtListe(listeUebersicht,"AspektDefinitionen");
				addiereMeldung(meldung, multiMeldungModell);

				ausloesenListener(null, 15, null, null, null);

				// 7 *************************************************************
				// Einzelbeschreibung: TypDefinitionen
				List<TypDefinitionBeschreibung> listeTypDefB=beschreibung.getListeTypDefinitionBSortiert();
				meldung=ausgabe.ausgebenTypDefBeschreibungListe(listeTypDefB);
				addiereMeldung(meldung, multiMeldungModell);

				ausloesenListener(null, 25, null, null, null);

				// 7 *************************************************************
				// Einzelbeschreibung: MengenDefinitionen
				List<MengenDefinitionBeschreibung> listeMengeDefB=beschreibung.getListeMengeDefinitionBSortiert();
				meldung=ausgabe.ausgebenMengenDefinitionBeschreibungListe(listeMengeDefB);
				addiereMeldung(meldung, multiMeldungModell);

				ausloesenListener(null, 35, null, null, null);

				// 7 *************************************************************
				// Einzelbeschreibung: AttributgruppenDefinitionen
				List<AttributgruppenDefinitionBeschreibung> listeATGDefB=beschreibung.getListeAttributgruppenDefinitionBSortiert();
				meldung=ausgabe.ausgebenAtgDefBeschreibungListe(listeATGDefB);
				addiereMeldung(meldung, multiMeldungModell);

				ausloesenListener(null, 45, null, null, null);

				// 7 *************************************************************
				// Einzelbeschreibung: AttributlistenDefinitionen
				List<AttributlistenDefinitionBeschreibung> listeATLDefB=beschreibung.getListeAttributlistenDefinitionBSortiert();
				meldung=ausgabe.ausgebenAtlDefBeschreibungListe(listeATLDefB);
				addiereMeldung(meldung, multiMeldungModell);

				ausloesenListener(null, 55, null, null, null);

				// 7 *************************************************************
				// Einzelbeschreibung: AttributDefinitionen
				List<AttributDefinitionBeschreibung> listeAttributDefB=beschreibung.getListeAttributDefinitionBSortiert();
				meldung=ausgabe.ausgebenAttDefBeschreibungListe(listeAttributDefB);
				addiereMeldung(meldung, multiMeldungModell);

				ausloesenListener(null, 65, null, null, null);

				/*
				// 7 *************************************************************
				// Einzelbeschreibung: AttributAuswahlDefinitionen
				List<AttributauswahlDefinitionBeschreibung> listeAttAuswahlDefB=beschreibung.getListeAttributauswahlDefinitionBSortiert();
				meldung=ausgabe.ausgebenAttAuswahlDefBeschreibungListe(listeAttAuswahlDefB);
				addiereMeldung(meldung, multiMeldungModell);

				ausloesenListener(null, 75, null, null, null);
				*/

				// 7 *************************************************************
				// Einzelbeschreibung: AspektDefinitionen
				List<AspektDefinitionBeschreibung> listeAspektDefB=beschreibung.getListeAspektDefinitionBSortiert();
				meldung=ausgabe.ausgebenAspektDefBeschreibungListe(listeAspektDefB);
				addiereMeldung(meldung, multiMeldungModell);

				ausloesenListener(null, 75, null, null, null);
			}

			// Listener nach der Bearbeitung des Modells:
			MeldungsTyp typModell=null;
			if(isModell){
				typModell=ermittleMeldungsTyp(multiMeldungModell.getSeverity());
			}
			ausloesenListener(kbPid, null, null, typModell, null);

			// Obekte:
			if((isObjekt)&&(!kbB.getObjekte().getListeKObBeschreibung().isEmpty())){
				// 8 *************************************************************
				// Objekte:
				meldung=ausgabe.ausgebenObjekteTitel();
				addiereMeldung(meldung, multiMeldungObjekt);

				// 9 *************************************************************
				// bersicht: Konfigurationsobjekte
				listeUebersicht=beschreibung.getListeUebersichtKonfigurationsObjektDefinitionSortiert();
				meldung=ausgabe.ausgebenUebersichtListe(listeUebersicht,"Konfigurationsobjekte");
				addiereMeldung(meldung, multiMeldungObjekt);

				ausloesenListener(null, 85, null, null, null);

				// 10 *************************************************************
				// Einzelbeschreibung: Konfigurationsobjekte
				List<KonfigurationsObjektBeschreibung> listeKOBeschreibung=beschreibung.getListeKonfigurationsObjektBSortiert();
				meldung=ausgabe.ausgebenKOBeschreibungListe(listeKOBeschreibung);
				addiereMeldung(meldung, multiMeldungObjekt);
			}

			// Listener nach der Bearbeitung der Objekten:
			MeldungsTyp typObjekt=null;
			if(isObjekt){
				typObjekt=ermittleMeldungsTyp(multiMeldungObjekt.getSeverity());
			}
			ausloesenListener(kbPid, null, null, null, typObjekt);

			ausgabe.abschliessen();
		}
		else{
			meldung=new Status(IStatus.ERROR, Activator.PLUGIN_ID, "Konfiguratiobereich ist undefiniert!");
			addiereMeldung(meldung, multiMeldungModell);
			addiereMeldung(meldung, multiMeldungObjekt);
		}

		return new MultiStatus[] {multiMeldungModell, multiMeldungObjekt};
	}

	/**
	 * Zeigt die multiMeldung (falls die die Kinder hat) im "ErrorLog".
	 *
	 * @param multiMeldung
	 */
	private void zeigeMultiMeldung(MultiStatus multiMeldung){
		//if(multiMeldung.getChildren().length>0){
			Activator.getDefault().getLog().log(multiMeldung);
		//}
	}

	/**
	 * Ermittle den MeldungTyp fr den angegebenen Typ von IStatus.
	 *
	 * @param typ Typ von der Meldung (IStatus).
	 * @return MeldungTyp fr den angegebenen Typ von IStatus.
	 */
	private MeldungsTyp ermittleMeldungsTyp(int typ){
		switch (typ) {
		case IStatus.OK:
			return MeldungsTyp.ok;
		case IStatus.WARNING:
			return MeldungsTyp.warnung;
		case IStatus.ERROR:
			return MeldungsTyp.fehler;
		case IStatus.INFO:
			return MeldungsTyp.ok;
		default:
			return MeldungsTyp.ok;
		}
	}
}
