/*
 * Copyright 2008 by inovat, innovative systeme - verkehr - tunnel - technik, Dipl.-Ing. H. C. Kni, Kln
 * <p>
 * This file is part of de.inovat.pat.datkat2html
 * <p>
 * de.inovat.pat.datkat2html is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * <p>
 * de.inovat.pat.datkat2html is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * <p>
 * You should have received a copy of the GNU General Public License
 * along with de.inovat.pat.datkat2html; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 * <p>
 * Contact Information:<br>
 * inovat, Dipl.-Ing. H. C. Kni<br>
 * Klner Strae 30<br>
 * 50859 Kln<br>
 * Phone: +49 2234 4301 800<br>
 * mailto: info@inovat.de
 */
package de.inovat.pat.datkat2html.html;

/**
 * Zustandsklasse zur Beschreibung von nderungen am KovnertierungsProzess.
 * ber ein Objekt dieser Klasse knnen den gerade bearbeitenden Konfigurationsbereich,
 * die Prozente der ausgefhrten Bearbeitung von KB und der gesamten Liste
 * und den MeldungsTyp fr Modelle und Objekte ermittelt werden.
 * 
 * @author inovat
 * @author Liliya Givorgizova (LG)
 * @version $Revision: 408 $ / $Date: 2010-04-06 08:14:07 +0200 (Di, 06. Apr 2010) $ / ($Author: HCK $)
 */

public class KonvertierungsProzessAenderungen {
// ------------------------------------------------------------------------
// VARIABLENDEKLARATIONEN
// ------------------------------------------------------------------------

// Private ----------------------------------------------------------------;
	/** PID von Konfigurationsbereich. */
	private String _kbPid;

	/** Prozent des Fortschritts fr den Konfigurationsbereich.  */
	private Integer _prozentKb;

	/** Prozent des Fortschritts Gesammt. */
	private Integer _prozentAll;

	/** Status des Modells. */
	private MeldungsTyp _typModell;

	/** Status der Objekten. */
	private MeldungsTyp _typObjekt;

// ------------------------------------------------------------------------
// KONSTRUKTOREN  (und vom Konstruktor verwende Methoden)
// ------------------------------------------------------------------------

	/**
	 * Erstellt eine Instanz der Klasse KonvertierungsProzessAenderungen.
	 * Jeder Parameter kann null sein. Das heit, dass entsprechendes Element nicht gendert wird.
	 *
	 * @param kbPid PID von Konfigurationsbereich.
	 * @param prozentKb Prozent des Fortschritts fr den Konfigurationsbereich.
	 * @param prozentAll Prozent des Fortschritts Gesammt.
	 * @param typModell Status des Modells.
	 * @param typObjekt Status der Objekten.
	 */
	public KonvertierungsProzessAenderungen(String kbPid, Integer prozentKb,
			Integer prozentAll, MeldungsTyp typModell, MeldungsTyp typObjekt) {
		_kbPid = kbPid;
		_prozentKb = prozentKb;
		_prozentAll = prozentAll;
		_typModell = typModell;
		_typObjekt = typObjekt;
	}

// ------------------------------------------------------------------------
// GETTER / SETTER METHODEN
// ------------------------------------------------------------------------

	/**
	 * Getter fr Eigenschaft '_kbPid'.
	 * Kann null sein. Das heit, dass das Element nicht gendert wird.
	 *
	 * @return Wert der Eigenschaft '_kbPid'.
	 *
	 * @see {#link _kbPid}
	 */
	public String getKbPid() {
		return _kbPid;
	}

	/**
	 * Getter fr Eigenschaft '_prozentAll'.
	 * Kann null sein. Das heit, dass das Element nicht gendert wird.
	 *
	 * @return Wert der Eigenschaft '_prozentAll'.
	 *
	 * @see {#link _prozentAll}
	 */
	public Integer getProzentAll() {
		return _prozentAll;
	}

	/**
	 * Getter fr Eigenschaft '_prozentKb'.
	 * Kann null sein. Das heit, dass das Element nicht gendert wird.
	 *
	 * @return Wert der Eigenschaft '_prozentKb'.
	 *
	 * @see {#link _prozentKb}
	 */
	public Integer getProzentKb() {
		return _prozentKb;
	}

	/**
	 * Getter fr Eigenschaft '_typModell'.
	 * Kann null sein. Das heit, dass das Element nicht gendert wird.
	 *
	 * @return Wert der Eigenschaft '_typModell'.
	 *
	 * @see {#link _typModell}
	 */
	public MeldungsTyp getTypModell() {
		return _typModell;
	}

	/**
	 * Getter fr Eigenschaft '_typObjekt'.
	 * Kann null sein. Das heit, dass das Element nicht gendert wird.
	 *
	 * @return Wert der Eigenschaft '_typObjekt'.
	 *
	 * @see {#link _typObjekt}
	 */
	public MeldungsTyp getTypObjekt() {
		return _typObjekt;
	}

// ------------------------------------------------------------------------
// ENUMERATIONEN
// ------------------------------------------------------------------------

	/** Aufzhlung der mglichen MeldungsStatus. */
	public enum MeldungsTyp {keineTransformation, nochOffen,
		inBearbeitung, ok, warnung, fehler}
}
