/*
 * @(#)RWService.java   24.09.13
 *
 * Copyright (c) 2008 by inovat, Dipl.-Ing. H. C. Kni
 * ALL RIGHTS RESERVED.
 *
 * THIS SOFTWARE IS  PROVIDED  "AS IS"  AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF  MERCHANTABILITY  AND  FITNESS  FOR  A PARTICULAR  PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL inovat OR ITS CONTRIBUTORS BE
 * LIABLE FOR ANY  DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
 * OR CONSEQUENTIAL DAMAGES  (INCL., BUT NOT LIMITED TO, PROCUREMENT
 * OF SUBSTITUTE GOODS OR SERVICES;  LOSS OF USE, DATA, OR  PROFITS;
 * OR BUSINESS INTERRUPTION)  HOWEVER  CAUSED  AND  ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,  OR TORT (INCL.
 * NEGLIGENCE OR OTHERWISE)  ARISING  IN  ANY  WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */



package de.inovat.pat.datkat2html.rwservice;

//~ NICHT JDK IMPORTE =========================================================

import de.bsvrz.buv.rw.basislib.berechtigung.Berechtigungen;
import de.bsvrz.buv.rw.basislib.einstellungen.Einstellungen;
import de.bsvrz.buv.rw.basislib.Rahmenwerk;

//~ KLASSEN ===================================================================

/**
 * Der Service ermglicht den Zugriff auf die im Rahmenwerk definierten Services.
 *
 * @author inovat
 * @author Liliya Givorgizova (LG)
 * @version $Revision: 0 $ / $Date: 2008-01-01 00:00:00 +0200 (So, 27 Mai 2007) $ / ($Author: LG $)
 */
public class RWService {

    /** Ermglicht den Zugriff auf die im Rahmenwerk definierten Services. */
    private static RWService service;

    //~ FELDER ================================================================

    /** Der Service bietet den Zugriff auf die RW-Berechtigungen. */
    private Berechtigungen _berechtigungen;

    /** Der Service bietet den Zugriff auf die RW-Einstellungen. */
    private Einstellungen _einstellungen;

    /** Der Service bietet den Zugriff auf die Verbindung zum DaV. */
    private Rahmenwerk _rw;

    //~ METHODEN ==============================================================

    protected void activate() {
        RWService.service = this;
    }

    protected void bindBerechtigungen(final Berechtigungen newBerechtigungen) {
        _berechtigungen = newBerechtigungen;
    }

    protected void bindEinstellungen(final Einstellungen newEinstellungen) {
        _einstellungen = newEinstellungen;
    }

    protected void bindRahmenwerk(final Rahmenwerk newRahmenWerk) {
        _rw = newRahmenWerk;
    }

    protected void deactivate() {
        RWService.service = null;
    }

    //~ GET METHODEN ==========================================================

    /**
     * Getter fr Eigenschaft 'berechtigungen'.
     *
     * @return Wert der Eigenschaft 'berechtigungen'.
     *
     * @see #_berechtigungen
     */
    public Berechtigungen getBerechtigungen() {
        return _berechtigungen;
    }

    /**
     *     Getter fr Eigenschaft 'einstellungen'.
     *
     *     @return Wert der Eigenschaft 'einstellungen'.
     *
     *     @see #_einstellungen
     */
    public Einstellungen getEinstellungen() {
        return _einstellungen;
    }

    /**
     * Getter fr Eigenschaft 'rw'.
     *
     * @return Wert der Eigenschaft 'rw'.
     *
     * @see #_rw
     */
    public Rahmenwerk getRw() {
        return _rw;
    }

    /**
     * Ermittle einzige Instanz der Klasse.
     *
     * @return Einzige Instanz der Klasse.
     */
    public static RWService getService() {
        return RWService.service;
    }

    //~ METHODEN ==============================================================

    protected void unbindBerechtigungen(final Berechtigungen oldBerechtigungen) {
        this._berechtigungen = null;
    }

    protected void unbindEinstellungen(final Einstellungen oldEinstellungen) {
        this._einstellungen = null;
    }

    protected void unbindRahmenwerk(final Rahmenwerk oldRahmenWerk) {
        this._rw = null;
    }
}


//~Formatiert mit 'inovat Kodierkonvention' am 08.10.13
