/*
 * Copyright 2008 by inovat, innovative systeme - verkehr - tunnel - technik, Dipl.-Ing. H. C. Kni, Kln
 * <p>
 * This file is part of de.inovat.pat.datkat2html
 * <p>
 * de.inovat.pat.datkat2html is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * <p>
 * de.inovat.pat.datkat2html is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * <p>
 * You should have received a copy of the GNU General Public License
 * along with de.inovat.pat.datkat2html; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 * <p>
 * Contact Information:<br>
 * inovat, Dipl.-Ing. H. C. Kni<br>
 * Klner Strae 30<br>
 * 50859 Kln<br>
 * Phone: +49 2234 4301 800<br>
 * mailto: info@inovat.de
 */

package de.inovat.pat.datkat2html.vew;

import java.util.HashMap;
import java.util.Map;

/**
 * Klasse zur Verwaltung der KonvertierungsVorgabe.
 * 
 * @author inovat, innovative systeme - verkehr - tunnel - technik
 * @author Dipl.-Ing. Hans Christian Kni (HCK)
 * @version $Revision: 408 $ / $Date: 2010-04-06 08:14:07 +0200 (Di, 06. Apr 2010) $ / ($Author: HCK $)
 */

public class KonvertierungsVorgabe {
// ------------------------------------------------------------------------
// VARIABLENDEKLARATIONEN
// ------------------------------------------------------------------------

// Private ----------------------------------------------------------------
	/**
	 * Map von KonfigurationsBereichen.
	 * Schlssel: PID von KB.
	 */
	private Map<String, KonfigurationsBereich> _mapKonfigurationsBereich=new HashMap<String, KonfigurationsBereich>();
	/** Kommentar zur KonvertierungsVorgabe */
	private String _kommentar;
	/** Kurzbezeichnung der KonvertierungsVorgabe */
	private String _kurzBezeichung;
	/** Langbezeichnung der KonvertierungsVorgabe */
	private String _langBezeichung;
	/** Ordner, wo die konvertierten Datei erstell werden. */
	private String _zielOrdner="";
	/** Datei, die in der Sicht gestartet werden. */
	private String _startDatei;

// ------------------------------------------------------------------------
// KONSTRUKTOREN  (und vom Konstruktor verwende Methoden)
// ------------------------------------------------------------------------

	/**
	 * Erzeugt eine Instanz der Klasse KonvertierungsVorgabe.
	 * (wird von XMLDecoder bentigt.)
	 */
	public KonvertierungsVorgabe( ) {};

	/**
	 * Erzeugt eine Instanz der Klasse KonvertierungsVorgabe.
	 *
	 * @param kurzBezeichung Kurzbezeichnung der KonvertierungsVorgabe.
	 */
	public KonvertierungsVorgabe(String kurzBezeichung) {
		_kurzBezeichung = kurzBezeichung;
		_langBezeichung = "";
		_kommentar = "";
		_zielOrdner = "---Zielordner noch nicht festgelegt---";
	}

// ------------------------------------------------------------------------
// GETTER / SETTER METHODEN
// ------------------------------------------------------------------------

	/**
	 * Getter fr Eigenschaft '_kommentar'.
	 *
	 * @return Wert der Eigenschaft '_kommentar'.
	 *
	 * @see {#link _kommentar}
	 */
	public String getKommentar() {
		return _kommentar;
	}

	/**
	 * Setter fr Eigenschaft '_kommentar'.
	 *
	 * @param kommentar Wert zum Setzen der Eigenschaft '_kommentar'.
	 *
	 * @see {#link _kommentar}
	 */
	public void setKommentar(String kommentar) {
		_kommentar = kommentar;
	}

	/**
	 * Getter fr Eigenschaft '_kurzBezeichung'.
	 *
	 * @return Wert der Eigenschaft '_kurzBezeichung'.
	 *
	 * @see {#link _kurzBezeichung}
	 */
	public String getKurzBezeichung() {
		return _kurzBezeichung;
	}

	/**
	 * Setter fr Eigenschaft '_kurzBezeichung'.
	 *
	 * @param kurzBezeichung Wert zum Setzen der Eigenschaft '_kurzBezeichung'.
	 *
	 * @see {#link _kurzBezeichung}
	 */
	public void setKurzBezeichung(String kurzBezeichung) {
		_kurzBezeichung = kurzBezeichung;
	}

	/**
	 * Getter fr Eigenschaft '_langBezeichung'.
	 *
	 * @return Wert der Eigenschaft '_langBezeichung'.
	 *
	 * @see {#link _langBezeichung}
	 */
	public String getLangBezeichung() {
		return _langBezeichung;
	}

	/**
	 * Setter fr Eigenschaft '_langBezeichung'.
	 *
	 * @param langBezeichung Wert zum Setzen der Eigenschaft '_langBezeichung'.
	 *
	 * @see {#link _langBezeichung}
	 */
	public void setLangBezeichung(String langBezeichung) {
		_langBezeichung = langBezeichung;
	}

	/**
	 * Getter fr Eigenschaft '_mapKonfigurationsBereich'.
	 *
	 * @return Wert der Eigenschaft '_mapKonfigurationsBereich'.
	 *
	 * @see {#link _mapKonfigurationsBereich}
	 */
	public Map<String, KonfigurationsBereich> getMapKonfigurationsBereich() {
		return _mapKonfigurationsBereich;
	}

	/**
	 * Setter fr Eigenschaft '_mapKonfigurationsBereich'.
	 *
	 * @param mapKonfigurationsBereich Wert zum Setzen der Eigenschaft '_mapKonfigurationsBereich'.
	 *
	 * @see {#link _mapKonfigurationsBereich}
	 */
	public void setMapKonfigurationsBereich(Map<String, KonfigurationsBereich> mapKonfigurationsBereich) {
		_mapKonfigurationsBereich = mapKonfigurationsBereich;
	}

	/**
	 * Getter fr Eigenschaft '_startDatei'.
	 *
	 * @return Wert der Eigenschaft '_startDatei'.
	 *
	 * @see {#link _startDatei}
	 */
	public String getStartDatei() {
		return _startDatei;
	}

	/**
	 * Setter fr Eigenschaft '_startDatei'.
	 *
	 * @param startDatei Wert zum Setzen der Eigenschaft '_startDatei'.
	 *
	 * @see {#link _startDatei}
	 */
	public void setStartDatei(String startDatei) {
		_startDatei = startDatei;
	}

	/**
	 * Getter fr Eigenschaft '_zielOrdner'.
	 *
	 * @return Wert der Eigenschaft '_zielOrdner'. Kann nicht null sein.
	 *
	 * @see {#link _zielOrdner}
	 */
	public String getZielOrdner() {
		return _zielOrdner;
	}

	/**
	 * Setter fr Eigenschaft '_zielOrdner'.
	 *
	 * @param zielOrdner Wert zum Setzen der Eigenschaft '_zielOrdner'.
	 *
	 * @see {#link _zielOrdner}
	 */
	public void setZielOrdner(String zielOrdner) {
		if(zielOrdner==null){
			zielOrdner="";
		}
		_zielOrdner = zielOrdner;
	}
}
