/*
 * Copyright 2008 by inovat, innovative systeme - verkehr - tunnel - technik, Dipl.-Ing. H. C. Kni, Kln
 * <p>
 * This file is part of de.inovat.pat.datkat2html
 * <p>
 * de.inovat.pat.datkat2html is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * <p>
 * de.inovat.pat.datkat2html is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * <p>
 * You should have received a copy of the GNU General Public License
 * along with de.inovat.pat.datkat2html; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 * <p>
 * Contact Information:<br>
 * inovat, Dipl.-Ing. H. C. Kni<br>
 * Klner Strae 30<br>
 * 50859 Kln<br>
 * Phone: +49 2234 4301 800<br>
 * mailto: info@inovat.de
 */



package de.inovat.pat.datkat2html.vew;

//~ NICHT JDK IMPORTE =========================================================

import de.bsvrz.buv.rw.basislib.einstellungen.EinstellungsAdresse;
import de.bsvrz.buv.rw.basislib.einstellungen.SpeicherKey;
import de.bsvrz.buv.rw.basislib.urlasser.UrlasserInfo;
import de.bsvrz.dav.daf.main.config.SystemObject;

import de.inovat.pat.datkat2html.Activator;
import de.inovat.pat.datkat2html.Log;
import de.inovat.pat.datkat2html.rwservice.RWService;

//~ JDK IMPORTE ===============================================================

import java.beans.XMLDecoder;
import java.beans.XMLEncoder;

import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;

import java.util.Arrays;
import java.util.HashMap;
import java.util.Map;
import java.util.Set;

//~ KLASSEN ===================================================================

/**
 * Klasse verwaltet die Konvertierungsvorgaben.
 *
 * @author inovat, innovative systeme - verkehr - tunnel - technik
 * @author Dipl.-Ing. Hans Christian Kni (HCK)
 * @version $Revision: 408 $ / $Date: 2010-04-06 08:14:07 +0200 (Di, 06. Apr 2010) $ / ($Author: HCK $)
 */
public class KonvertierungsVorgaben {

    /**
     * ID vom Parameter, wo das KonvertierungsVorgabenMap gespeichert ist.
     */
    private static final String ID_PARAMTER = Activator.PLUGIN_ID + ".KonvertierungsVorgaben";

    //~ FELDER ================================================================

    /**
     * Map von definierten KonvertierungsVorgaben.
     * Schlssel: KurzBezeichung der KonvertierungsVorgabe.
     */
    private Map<String, KonvertierungsVorgabe> _mapKonvertierungsVorgaben = new HashMap<String, KonvertierungsVorgabe>();

    /**
     * Speicher von RahmenWerk, wo das KonvertierungsVorgabenMap gespeichert ist.
     */
    private SpeicherKey _speicher = SpeicherKey.allgemeinLokal();

    //~ KONSTRUKTOREN  (und vom Konstruktor verwendete Methoden) ==============

    /**
     * Erzeugt eine Instanz der Klasse KonvertierungsVorgaben.
     */
    public KonvertierungsVorgaben() {
        ladeKonvertierungsVorgaben();

        // Testweise ein paar Konverierungsvorgaben anlegen
        // for(int i=0; i<3; i++) erzeugeNeueKonvertierungsVorgabe();
    }

    //~ METHODEN ==============================================================

    /**
     * Erstellt automatisch die Kurzbezeichnung.
     *
     * @return automatisch erzeugte Kurzbezeichnung.
     */
    private String erstelleKurzbezeichung() {
        int    lfdNr = 0;
        String kurzBezeichung;

        do {
            kurzBezeichung = "KonfigurationsVorgabe (" + lfdNr++ + ")";
        } while (_mapKonvertierungsVorgaben.containsKey(kurzBezeichung));

        return kurzBezeichung;
    }

    /**
     * Erzeugt und speichert neue Konvertierungsvorgabe.
     *
     * @return erzeugte Konvertierungsvorgabe.
     */
    public KonvertierungsVorgabe erzeugeNeueKonvertierungsVorgabe() {

        // Neue Konvertierungsvorgabe erzeugen und speichern.
        KonvertierungsVorgabe konvertierungsVorgabe = new KonvertierungsVorgabe(erstelleKurzbezeichung());

        _mapKonvertierungsVorgaben.put(konvertierungsVorgabe.getKurzBezeichung(), konvertierungsVorgabe);
        speichereKonvertierungsVorgaben();

        return konvertierungsVorgabe;
    }

    //~ GET METHODEN ==========================================================

    /**
     * Getter fr Eigenschaft '_mapKonvertierungsVorgaben'.
     *
     * @return Wert der Eigenschaft '_mapKonvertierungsVorgaben'.
     *
     * @see {#link _mapKonvertierungsVorgaben}
     */
    public Map<String, KonvertierungsVorgabe> getMapKonvertierungsVorgaben() {
        return _mapKonvertierungsVorgaben;
    }

    /**
     * Ermittelt die sortierte Liste der Kurzbezeichnungen von Konvertierungsvorgaben.
     *
     * @return Sortierte Liste der Kurzbezeichnungen von Konvertierungsvorgaben.
     */
    public String[] getSortiereListeDerKonvertierungsVorgabenKurzBezeichungen() {
        Set<String> set            = _mapKonvertierungsVorgaben.keySet();
        String[]    sortierteListe = set.toArray(new String[set.size()]);

        Arrays.sort(sortierteListe);

        return sortierteListe;
    }

    //~ METHODEN ==============================================================

    /**
     * Kopiert die KonvertierungsVorgabe.
     * Diese KonvertierungsVorgabe bekommt die automatisch erzeugte Kurzbezeichnung
     * und wird im Map gespeichert.
     * Das Map von KonvertierungsVorgaben wird ebenso gespeichert.
     *
     * @param konvVorgabe KonvertierungsVorgabe, die kopiert wird.
     * @return neue erzeugte KonvertierungsVorgabe.
     */
    public KonvertierungsVorgabe kopiereKonvertierungsVorgabe(KonvertierungsVorgabe konvVorgabe) {

        // Erzeuge neue Konvertierungsvorgabe:
        KonvertierungsVorgabe konvVorgabeKopie = new KonvertierungsVorgabe(erstelleKurzbezeichung());

        // Kopiere die Daten von konvVorgabe:
        konvVorgabeKopie.setKommentar(konvVorgabe.getKommentar());

        // konvVorgabeKopie.setKurzBezeichung(konvVorgabe.getKurzBezeichung());
        konvVorgabeKopie.setLangBezeichung(konvVorgabe.getLangBezeichung());
        konvVorgabeKopie.setZielOrdner(konvVorgabe.getZielOrdner());

        Map<String, KonfigurationsBereich> mapKBKopie = new HashMap<String, KonfigurationsBereich>();

        for (KonfigurationsBereich kb : konvVorgabe.getMapKonfigurationsBereich().values()) {
            KonfigurationsBereich kbKopie = new KonfigurationsBereich(kb.isModell(), kb.isObjekt(), kb.getKv(), kb.getKb(), kb.getPfad());

            mapKBKopie.put(kbKopie.getKb(), kbKopie);
        }

        konvVorgabeKopie.setMapKonfigurationsBereich(mapKBKopie);

        // Addiere die KonvertierungsVorgabe zum Map und speichere das Map:
        _mapKonvertierungsVorgaben.put(konvVorgabeKopie.getKurzBezeichung(), konvVorgabeKopie);
        speichereKonvertierungsVorgaben();

        return konvVorgabeKopie;
    }

    /**
     * Lade das im RahmenWerk gespeicherte Map von KonvertierungsVorgaben.
     */
    public void ladeKonvertierungsVorgaben() {

        // Lese den im RW gespeicherte Text (Map):
        String mapGelesen = null;
        Object map;

        try {
            map = RWService.getService().getEinstellungen().getValue(  //
                new EinstellungsAdresse(null, ID_PARAMTER, _speicher));

            if (map != null) {
                mapGelesen = map.toString();
            }
        }
        catch (Exception e) {
            Log.zeige(Log.erzeugeMeldung(Log.WARNUNG, Activator.PLUGIN_ID, "Konvertierungsvorgaben konnten nicht geladen werden.", e));
        }

        // TBD HCK: Wieder entfernen, wenn Rahmenwerk korrekt funitioneiert.
        for (int i = 0; i < 15; i++) {
            if (mapGelesen != null) {
                break;
            }

            try {
                Thread.sleep(2000);
            }
            catch (InterruptedException e) {
                e.printStackTrace();
            }

            try {
                map = RWService.getService().getEinstellungen().getValue(  //
                    new EinstellungsAdresse(null, ID_PARAMTER, _speicher));

                if (map != null) {
                    mapGelesen = map.toString();
                }
            }
            catch (Exception e) {

                // Log.zeige(Log.erzeugeMeldung(Log.WARNUNG, Activator.PLUGIN_ID, "Konvertierungsvorgaben konnten nicht geladen werden.", e));
            }
        }

        // Falls das Map erfolgreich ausgelesen wurde,
        // dekodiere das in _mapKonvertierungsVorgaben:
        if (mapGelesen != null) {
            try {
                ByteArrayInputStream input  = new ByteArrayInputStream(mapGelesen.getBytes());
                XMLDecoder           xml    = new XMLDecoder(input);
                Object               result = xml.readObject();

                xml.close();
                _mapKonvertierungsVorgaben = (Map<String, KonvertierungsVorgabe>) result;
            }
            catch (Exception e) {
                Log.zeigeInterneMeldung(Activator.PLUGIN_ID, e);
            }
        }

        if (mapGelesen == null) {
            Log.zeige(Log.erzeugeMeldung(Log.WARNUNG, Activator.PLUGIN_ID, "Es sind noch keine Konvertierungsvorgaben gespeichert!"));
        }
    }

    /**
     * Speichere Map von Konvertierungsvorgaben im Rahmenwerk
     * entsprechend der Instanzvariable _speicherArt.
     */
    public void speichereKonvertierungsVorgaben() {

        // Kodiere das Map ber XMLEncoder:
        ByteArrayOutputStream out = new ByteArrayOutputStream();
        XMLEncoder            xml = new XMLEncoder(out);

        xml.writeObject(_mapKonvertierungsVorgaben);
        xml.close();

        // Erstelle UrlasserInfo:
        SystemObject benutzer = RWService.getService().getRw().getBenutzer();
        String       passwort = RWService.getService().getRw().getPasswort();
        String       benutzerName;

        if (benutzer != null) {
            benutzerName = benutzer.getName();
        } else {
            benutzerName = "offline";
            passwort     = "";
        }

        UrlasserInfo urlasserInfo = new UrlasserInfo(benutzer, passwort, "Konvertierungseinstellungen", benutzerName);

        // Speichere den kodierten Text im RW:
        try {
            RWService.getService().getEinstellungen().setValue(                         //
                new EinstellungsAdresse(null, ID_PARAMTER, _speicher), out.toString(),  //
                urlasserInfo);
        }
        catch (Exception e) {
            Log.zeige(Log.erzeugeMeldung(Log.WARNUNG, Activator.PLUGIN_ID,              //
                                         "Konvertierungseinstellungen konnten nicht in den Speicher eingefgt werden!", e));
        }
    }

    /**
     * Gibt die String-Reprsentation dieses Objekts aus.
     * <p/>
     * Die Formatierung der Ausgabe kann sich ndern und wird nicht garantiert.
     *
     * @return Aktueller Zustand der Klassenvariablen dieses Objekts.
     */
    public String toString() {
        return "KonvertierungsVorgaben{" + "_mapKonvertierungsVorgaben=" + _mapKonvertierungsVorgaben + '}';
    }
}


//~Formatiert mit 'inovat Kodierkonvention' am 11.12.13
