/*
 * Copyright (c) 2008 by inovat, Dipl.-Ing. H. C. Kni
 * ALL RIGHTS RESERVED.
 *
 * THIS SOFTWARE IS  PROVIDED  "AS IS"  AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF  MERCHANTABILITY  AND  FITNESS  FOR  A PARTICULAR  PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL inovat OR ITS CONTRIBUTORS BE
 * LIABLE FOR ANY  DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
 * OR CONSEQUENTIAL DAMAGES  (INCL., BUT NOT LIMITED TO, PROCUREMENT
 * OF SUBSTITUTE GOODS OR SERVICES;  LOSS OF USE, DATA, OR  PROFITS;
 * OR BUSINESS INTERRUPTION)  HOWEVER  CAUSED  AND  ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,  OR TORT (INCL.
 * NEGLIGENCE OR OTHERWISE)  ARISING  IN  ANY  WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */



package de.inovat.buv.gtm.datvew.lib;

//~ NICHT JDK IMPORTE =========================================================

import de.bsvrz.dav.daf.main.config.AttributeGroup;
import de.bsvrz.dav.daf.main.config.ConfigurationObject;
import de.bsvrz.dav.daf.main.config.DataModel;
import de.bsvrz.dav.daf.main.config.SystemObject;
import de.bsvrz.dav.daf.main.Data;

import de.inovat.buv.gtm.datvew.konstanten.KonstantenGTMGUIResource;
import de.inovat.buv.projektlib.dav.DavDatenVew;

import org.eclipse.swt.graphics.Image;

//~ KLASSEN ===================================================================

/**
 * Klasse verwaltet einen Auswertequerschnitt.
 *
 * @author inovat
 * @author Dagmar Rostek (DR)
 * @version $Revision: 155 $ / $Date: 2014-10-07 11:11:48 +0200 (Di, 07 Okt 2014) $ / ($Author: LG $)
 */
public class AuswerteQuerschnitt implements ISystemObjekt {

    /** Konfigurationsobjekt. */
    private ConfigurationObject _confObj;

    /**
     * Messquerschnitt zu dem Auswertequerschnitt.
     */
    private Messquerschnitt _messquerschnitt;

    /** Die Eltern Zhlstelle. */
    private ZaehlStelle _parentZaehlStelle;

    //~ KONSTRUKTOREN  (und vom Konstruktor verwendete Methoden) ==============

    /**
     * Erzeugt eine Instanz der Klasse AuswerteQuerschnitt.
     * @param confObj  Konfigurationsobjekt.
     * @param zaehlStelle   elterliche Zhlstelle.
     *
     */
    public AuswerteQuerschnitt(ConfigurationObject confObj, ZaehlStelle zaehlStelle) {
        _parentZaehlStelle = zaehlStelle;
        _confObj           = confObj;

        //
        DataModel      davKonf                = DavDatenVew.getInstanz().getDav().getDataModel();
        AttributeGroup atgAuswerteQuerschnitt = davKonf.getAttributeGroup("atg.auswerteQuerschnitt");
        Data           oData                  = _confObj.getConfigurationData(atgAuswerteQuerschnitt);

        if (oData != null) {
            _messquerschnitt = new Messquerschnitt((ConfigurationObject) oData.getReferenceValue("Messquerschnitt").getSystemObject(), this);
        }
    }

    //~ GET METHODEN ==========================================================

    @Override
    public Image getImage() {
        return KonstantenGTMGUIResource.ICON_GTM_AMQ;
    }

    /**
     * Getter fr Eigenschaft 'messquerschnitt'.
     *
     * @return Wert der Eigenschaft 'messquerschnitt'.
     *
     * @see #_messquerschnitt
     */
    public Messquerschnitt getMessquerschnitt() {
        return _messquerschnitt;
    }

    /**
     * Methode gibt die Zhlstelle zurck, zu der der Auswertequerschnitt gehrt.
     * @return   eltern Zhlstelle.
     */
    public ZaehlStelle getParentZaehlStelleZuAuswerteQuerschnitt() {
        return _parentZaehlStelle;
    }

    @Override
    public SystemObject getSystemObjekt() {
        return _confObj;
    }
}


//~Formatiert mit 'inovat Kodierkonvention' am 14.03.12
