/*
 * @(#)SelektionVew.java   20.02.12
 *
 * Copyright (c) 2008 by inovat, Dipl.-Ing. H. C. Kni
 * ALL RIGHTS RESERVED.
 *
 * THIS SOFTWARE IS  PROVIDED  "AS IS"  AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF  MERCHANTABILITY  AND  FITNESS  FOR  A PARTICULAR  PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL inovat OR ITS CONTRIBUTORS BE
 * LIABLE FOR ANY  DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
 * OR CONSEQUENTIAL DAMAGES  (INCL., BUT NOT LIMITED TO, PROCUREMENT
 * OF SUBSTITUTE GOODS OR SERVICES;  LOSS OF USE, DATA, OR  PROFITS;
 * OR BUSINESS INTERRUPTION)  HOWEVER  CAUSED  AND  ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,  OR TORT (INCL.
 * NEGLIGENCE OR OTHERWISE)  ARISING  IN  ANY  WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */



package de.inovat.buv.gtm.datvew.lib;

//~ NICHT JDK IMPORTE =========================================================

import de.bsvrz.buv.plugin.selektion.SelektionsTransfer;

import org.eclipse.jface.viewers.IStructuredSelection;

//~ JDK IMPORTE ===============================================================

import java.util.ArrayList;
import java.util.List;

//~ KLASSEN ===================================================================

/**
 * Klasse verwaltet die Selektion.
 * Als singleton realisiert.
 *
 * @author inovat
 * @author Liliya Givorgizova (LG)
 * @version $Revision: 155 $ / $Date: 2014-10-07 11:11:48 +0200 (Di, 07 Okt 2014) $ / ($Author: LG $)
 */
public class SelektionVew {

    /** Einzige Instanz der Klasse. */
    private static SelektionVew _instanz = new SelektionVew();

    //~ METHODEN ==============================================================

    /**
     * Ermittle das erst selektierte Objekt.
     *
     * @return Das erst selektierte Objekt oder null.
     */
    public Object ermittleErstSelektiertesObjekt() {
        try {
            return SelektionsTransfer.getInstanz().getAktuelleSelection().getFirstElement();
        }
        catch (Exception e) {
            return null;
        }
    }

    /**
     * Ermittle die Liste der selektierten Zhlstellen.
     *
     * @return Liste der selektierten Zhlstellen.
     */
    public List<ZaehlStelle> ermittleListeSelektierterZaehlStellen() {
        List<ZaehlStelle> listeZs = new ArrayList<ZaehlStelle>();

        // Hole alle im NavigationBaum selektierte Objekte:
        ZaehlStelle zs;

        // Untersuche die selektierten Objekte:
        List<Object> listeSelektion;

        try {
            listeSelektion = SelektionsTransfer.getInstanz().getAktuelleSelection().toList();
        }
        catch (Exception e) {
            listeSelektion = new ArrayList<Object>();
        }

        for (Object objekt : listeSelektion) {

            // ZaehlStelle:
            if (objekt instanceof ZaehlStelle) {
                zs = (ZaehlStelle) objekt;
                listeZs.add(zs);
            }
        }

        return listeZs;
    }

    /**
     * Ermittle die Liste der zuletzt selektierten Objekte von Typ des ersten Objekts.
     * Objekte sind von Typ SystemObject oder ISystemObjekt.
     *
     * @return Liste der zuletzt selektierten Objekte von Typ des ersten Objekts.
     */
    public List<Object> ermittleSelektierteObjekteVonTypDesErstenObjekts() {
        List<Object>         liste     = new ArrayList<Object>();
        IStructuredSelection selektion = SelektionsTransfer.getInstanz().getAktuelleSelection();

        if (selektion != null) {
            Object erstes = selektion.getFirstElement();

            liste = BaumHilfsFunktionen.filtereListeMitTypDesObjekts(selektion.toList(), erstes);
        }

        return liste;
    }

    //~ GET METHODEN ==========================================================

    /**
     * Ermittle einzige Instanz der Klasse
     *
     * @return Einzige Instanz der Klasse.
     */
    public static SelektionVew getInstanz() {
        return _instanz;
    }
}


//~Formatiert mit 'inovat Kodierkonvention' am 20.03.12
