/*
 * @(#)MenuVew.java   28.03.12
 *
 * Copyright (c) 2008 by inovat, Dipl.-Ing. H. C. Kni
 * ALL RIGHTS RESERVED.
 *
 * THIS SOFTWARE IS  PROVIDED  "AS IS"  AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF  MERCHANTABILITY  AND  FITNESS  FOR  A PARTICULAR  PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL inovat OR ITS CONTRIBUTORS BE
 * LIABLE FOR ANY  DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
 * OR CONSEQUENTIAL DAMAGES  (INCL., BUT NOT LIMITED TO, PROCUREMENT
 * OF SUBSTITUTE GOODS OR SERVICES;  LOSS OF USE, DATA, OR  PROFITS;
 * OR BUSINESS INTERRUPTION)  HOWEVER  CAUSED  AND  ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,  OR TORT (INCL.
 * NEGLIGENCE OR OTHERWISE)  ARISING  IN  ANY  WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */



package de.inovat.buv.gtm.datvew.menu;

//~ NICHT JDK IMPORTE =========================================================

import de.inovat.buv.gtm.datvew.Activator;
import de.inovat.buv.inovat.lib.debug.Log;

import org.eclipse.core.runtime.IConfigurationElement;
import org.eclipse.core.runtime.IExtensionRegistry;
import org.eclipse.core.runtime.Platform;

//~ JDK IMPORTE ===============================================================

import java.util.ArrayList;
import java.util.Collections;
import java.util.Comparator;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

//~ KLASSEN ===================================================================

/**
 * Klasse verwaltet erweiterte Menpunkte fr die Navigation.
 * Die Menpunkte sind als Extension definiert.
 * </p>
 * als Singleton realisiert.
 *
 * @author inovat
 * @author Liliya Givorgizova (LG)
 * @version $Revision: 155 $ / $Date: 2014-10-07 11:11:48 +0200 (Di, 07 Okt 2014) $ / ($Author: LG $)
 */
public class MenuVew {

    /** Einzige Instanz der Klasse. */
    private static MenuVew instanz = new MenuVew();

    //~ FELDER ================================================================

    /** Die nach Namen sortierte Liste alle Menpnkte. */
    private List<IMenuPunkt> _listeMenuPunkte;

    //~ KONSTRUKTOREN  (und vom Konstruktor verwendete Methoden) ==============

    /**
     * Erzeugt einzige Instanz der Klasse MenuVew.
     */
    private MenuVew() {

        // Lade alle Menpunkte:
        ladeAlleMenuPunkte();
    }

    //~ GET METHODEN ==========================================================

    /**
     * Ermittelt einzige Instanz der Klasse MenuVew.
     *
     * @return Einzige Instanz der Klasse MenuVew.
     */
    public static MenuVew getInstanz() {
        return instanz;
    }

    /**
     *     Getter fr Eigenschaft 'listeMenuPunkte'.
     *
     *     @return Wert der Eigenschaft 'listeMenuPunkte'.
     *
     *     @see #_listeMenuPunkte
     */
    public List<IMenuPunkt> getListeMenuPunkte() {
        return _listeMenuPunkte;
    }

    //~ METHODEN ==============================================================

    /**
     * Lade alle Menpunkte, die als Extension definiert sind.
     */
    private void ladeAlleMenuPunkte() {

        // ----------------------------------------------
        // Lese alle Extension Points:
        Map<String, IMenuPunkt> mapMenuPunkte = new HashMap<String, IMenuPunkt>();
        IExtensionRegistry      reg           = Platform.getExtensionRegistry();

        if (reg != null) {
            String     id;
            IMenuPunkt klasse;

            for (IConfigurationElement el : reg.getConfigurationElementsFor(Activator.PLUGIN_ID, "NavigationMenu")) {
                try {

                    // Lese Extension:
                    id     = el.getAttribute("id");
                    klasse = (IMenuPunkt) el.createExecutableExtension("class");

                    // Prfe Extension:
                    if (klasse.getName() == null) {
                        throw new Exception(String.format("Fehler im Extension <%s>: Methode getName() liefert null", id));
                    }

                    if (klasse.getTyp() == null) {
                        throw new Exception(String.format("Fehler im Extension <%s>: Methode getTyp() liefert null", id));
                    }

                    if (klasse.getAktion() == null) {
                        throw new Exception(String.format("Fehler im Extension <%s>: Methode getAktion() liefert null", id));
                    }

                    // Einfgen:
                    if (mapMenuPunkte.put(id, klasse) != null) {
                        Log.zeige(Log.erzeugeMeldung(Log.WARNUNG, Activator.PLUGIN_ID, String.format("Darstellung mit ID <%s> wurde berschrieben", id)));
                    }
                }
                catch (Exception e) {
                    Log.zeigeInterneMeldung(Activator.PLUGIN_ID, e);
                }
            }
        }

        // ----------------------------------------------
        // Erstelle und sortiere die Liste:
        _listeMenuPunkte = new ArrayList<IMenuPunkt>();
        _listeMenuPunkte.addAll(mapMenuPunkte.values());
        Collections.sort(_listeMenuPunkte, new Comparator<IMenuPunkt>() {
            @Override
            public int compare(IMenuPunkt mp1, IMenuPunkt mp2) {
                return mp1.getName().compareTo(mp2.getName());
            }
        });
    }
}


//~Formatiert mit 'inovat Kodierkonvention' am 28.03.12
