/*
 * @(#)Eak.java   09.02.10
 *
 * Copyright (c) 2008 by inovat, Dipl.-Ing. H. C. Kni
 * ALL RIGHTS RESERVED.
 *
 * THIS SOFTWARE IS  PROVIDED  "AS IS"  AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF  MERCHANTABILITY  AND  FITNESS  FOR  A PARTICULAR  PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL inovat OR ITS CONTRIBUTORS BE
 * LIABLE FOR ANY  DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
 * OR CONSEQUENTIAL DAMAGES  (INCL., BUT NOT LIMITED TO, PROCUREMENT
 * OF SUBSTITUTE GOODS OR SERVICES;  LOSS OF USE, DATA, OR  PROFITS;
 * OR BUSINESS INTERRUPTION)  HOWEVER  CAUSED  AND  ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,  OR TORT (INCL.
 * NEGLIGENCE OR OTHERWISE)  ARISING  IN  ANY  WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */



package de.inovat.buv.gtm.datvew.tls;

//~ NICHT JDK IMPORTE =========================================================

import de.bsvrz.dav.daf.main.config.ConfigurationObject;
import de.bsvrz.dav.daf.main.config.ObjectSet;
import de.bsvrz.dav.daf.main.config.SystemObject;

import de.inovat.buv.gtm.datvew.konstanten.KonstantenGTMGUIResource;
import de.inovat.buv.gtm.datvew.lib.DatenVew;
import de.inovat.buv.gtm.datvew.lib.ISystemObjekt;

import org.eclipse.swt.graphics.Image;

//~ JDK IMPORTE ===============================================================

import java.util.ArrayList;
import java.util.Collections;

//~ KLASSEN ===================================================================

/**
 * Die Klasse reprstentiert eine interne Reprsentation eines Eak.
 *
 * @author inovat
 * @author Dagmar Rostek (DR)
 * @version $Revision: 155 $ / $Date: 2014-10-07 11:11:48 +0200 (Di, 07 Okt 2014) $ / ($Author: LG $)
 */
public class Eak implements ISystemObjekt {

    /** Nach Pid oder Id sortierte Liste der De's. */
    private ArrayList<De> _listeDe = new ArrayList<De>();

    /** Das SystemObjekt */
    private SystemObject _eak;

    /** Referenz auf das bergeordnete Gert */
    private Geraet _ueberGeordnetesGeraet;

    //~ KONSTRUKTOREN  (und vom Konstruktor verwendete Methoden) ==============

    /**
     * Erzeugt eine Instanz der Klasse Eak.
     *
     * @param so SystemObject.
     * @param ueberGeordnetesGeraet bergeordnetes Geraet.
     */
    public Eak(SystemObject so, Geraet ueberGeordnetesGeraet) {
        _eak                   = so;
        _ueberGeordnetesGeraet = ueberGeordnetesGeraet;

        //
        initListeDe();
    }

    //~ GET METHODEN ==========================================================

    @Override
    public Image getImage() {
        return KonstantenGTMGUIResource.ICON_GTM_EAK;
    }

    /**
     *     Getter fr Eigenschaft 'listeDe'.
     *
     *     @return Wert der Eigenschaft 'listeDe'.
     *
     *     @see #_listeDe
     */
    public ArrayList<De> getListeDe() {
        return _listeDe;
    }

    @Override
    public SystemObject getSystemObjekt() {
        return _eak;
    }

    /**
     * Getter fr Eigenschaft 'ueberGeordnetesGeraet'.
     *
     * @return Wert der Eigenschaft 'ueberGeordnetesGeraet'.
     *
     * @see #_ueberGeordnetesGeraet
     */
    public Geraet getUeberGeordnetesGeraet() {
        return _ueberGeordnetesGeraet;
    }

    //~ METHODEN ==============================================================

    /**
     * Initialisiere die Liste aller De.
     */
    private void initListeDe() {
        _listeDe = new ArrayList<De>();

        ConfigurationObject confEak = ((ConfigurationObject) _eak);
        ObjectSet           setDe   = confEak.getObjectSet("De");

        /*
        // TODO Log
        System.out.println(String.format("Eak: %s %s %s Typ: %s %s %s",                //
                                         _eak.getId(), _eak.getPid(), _eak.getName(),  //
                                         _eak.getType().getId(), _eak.getType().getPid(), _eak.getType().getName()));
                                         */

        if (setDe == null) {

            // NonMutableSet ms = confEak.getNonMutableSet("De");
            // System.out.println(ms);
            System.out.println("--- FEHLER!");
        } else {

            //
            for (SystemObject deSo : setDe.getElements()) {
                De de = new De(deSo, this);

                _listeDe.add(de);
            }
        }

        // Sortiere:
        Collections.sort(_listeDe, DatenVew.COMPARATOR_SO_NAME);
    }
}


//~Formatiert mit 'inovat Kodierkonvention' am 20.03.12
