/*
 * Copyright (c) 2008 by inovat, Dipl.-Ing. H. C. Kni
 * ALL RIGHTS RESERVED.
 *
 * THIS SOFTWARE IS  PROVIDED  "AS IS"  AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF  MERCHANTABILITY  AND  FITNESS  FOR  A PARTICULAR  PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL inovat OR ITS CONTRIBUTORS BE
 * LIABLE FOR ANY  DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
 * OR CONSEQUENTIAL DAMAGES  (INCL., BUT NOT LIMITED TO, PROCUREMENT
 * OF SUBSTITUTE GOODS OR SERVICES;  LOSS OF USE, DATA, OR  PROFITS;
 * OR BUSINESS INTERRUPTION)  HOWEVER  CAUSED  AND  ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,  OR TORT (INCL.
 * NEGLIGENCE OR OTHERWISE)  ARISING  IN  ANY  WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */



package de.inovat.buv.inovat.lib.gui.vewdlg;

//~ NICHT JDK IMPORTE =========================================================

import de.inovat.buv.inovat.lib.gui.GuiFunktionen;

import org.eclipse.jface.dialogs.Dialog;
import org.eclipse.jface.dialogs.IInputValidator;
import org.eclipse.jface.dialogs.InputDialog;
import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.jface.viewers.ArrayContentProvider;
import org.eclipse.jface.viewers.ISelectionChangedListener;
import org.eclipse.jface.viewers.LabelProvider;
import org.eclipse.jface.viewers.ListViewer;
import org.eclipse.jface.viewers.SelectionChangedEvent;
import org.eclipse.jface.viewers.StructuredSelection;
import org.eclipse.jface.viewers.Viewer;
import org.eclipse.jface.viewers.ViewerFilter;
import org.eclipse.swt.custom.SashForm;
import org.eclipse.swt.events.KeyAdapter;
import org.eclipse.swt.events.KeyEvent;
import org.eclipse.swt.events.ModifyEvent;
import org.eclipse.swt.events.ModifyListener;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.SWT;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Text;

import static de.inovat.buv.inovat.lib.konstanten.Konstanten.NEWLINE;

//~ JDK IMPORTE ===============================================================

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

//~ KLASSEN ===================================================================

/**
 * Die Klasse erstellt allgemeinen Dialog fr die Bearbeitung der Objekten in einer Liste.
 * Wird z.B. fr die Projektfiltereinstellungen benutzt.
 *
 * Dem Konstruktor muss man eine Instanz der Klasse, die das Interface IRahmenVerwaltungsDialogGUI implementiert, bergeben.
 *
 * @author inovat
 * @author Liliya Givorgizova (LG)
 * @version $Revision: 12 $ / $Date: 2013-09-24 13:23:48 +0200 (Di, 24. Sep 2013) $ / ($Author: LG $)
 */
public class RahmenVerwaltungsDialogGUI extends org.eclipse.swt.widgets.Composite {

    /**
     * Eingabe fr die Liste der Objekten.
     */
    private String[]  _inputArray = new String[0];
    private Button    _btnUebernehmen;
    private Button    _btnZuruecksetzen;
    private Composite _compObjekt;

    /**
     * Die Instanz der Klasse, die das Interface IEinstellungen implementiert.
     * Wird im Konstruktor initialisiert.
     */
    private IRahmenVerwaltungsDialogGUI _klasseIE;

    /**
     * Die Liste der Objekten.
     */
    private ListViewer _objektListe;

    /**
     * Name des selektiertes Objekts.
     */
    private String _objektName;
    private Text   _txtFilter;

    /**
     *  ID von der Sicht (View), wo GUI angezeigt wird.
     *  Leerer String, falls GUI im Dialog geffnet wird.
     *  Mit den Schaltflchen OK und Abbruch wird die Sicht ausgeblendet.
     */
    private String _viewID;

    //~ KONSTRUKTOREN  (und vom Konstruktor verwendete Methoden) ==============

    /**
     * Erzeugt eine Instanz der Klasse RahmenVerwaltungsDialogGUI.
     *
     * @param parent Parent-Composite.
     *
     * @param viewID ID von der Sicht (View), wo GUI angezeigt wird.
     * Leerer String, falls GUI im Dialog geffnet wird.
     *
     * @param klasse Muss das Interface IEinstellungen implementieren.
     * @wbp.parser.constructor
     */
    public RahmenVerwaltungsDialogGUI(Composite parent, String viewID, IRahmenVerwaltungsDialogGUI klasse) {
        super(parent, SWT.NONE);
        this._viewID = viewID;
        initialisiereKlasse(klasse);
        initGUI();
    }

    /**
     * Erzeugt eine Instanz der Klasse RahmenVerwaltungsDialogGUI
     * mit gewhlter Darstellung.
     *
     * @param parent Parent-Composite.
     *
     * @param viewID ID von der Sicht (View), wo GUI angezeigt wird.
     * Leerer String, falls GUI im Dialog geffnet wird.
     *
     * @param klasse Muss das Interface IEinstellungen implementieren.
     *
     * @param selektiertesObjekt Objekt, das in der Liste selektiert
     * werden soll, falls solche existiert.
     */
    public RahmenVerwaltungsDialogGUI(Composite parent, String viewID, IRahmenVerwaltungsDialogGUI klasse, String selektiertesObjekt) {
        super(parent, SWT.NONE);
        this._viewID = viewID;
        initialisiereKlasse(klasse);
        initGUI();
        belegeGUIMitVorauswahl(selektiertesObjekt);
    }

    //~ METHODEN ==============================================================

    /**
     * Aktualisiere das GUI.
     *
     * @param klasse IRahmenVerwaltungsDialogGUI.
     */
    public void aktualisiereGUI(IRahmenVerwaltungsDialogGUI klasse) {

        // Lsche alte GUI-Elemente:
        for (Control kind : getChildren()) {
            kind.dispose();
        }

        // Erstelle das GUI neu:
        initialisiereKlasse(klasse);
        initGUI();

        //
        layout();
        getParent().layout();
    }

    /**
     * Die Methode sorgt dafr, dass das GUI mit einer Vorauswahl
     * belegt wird, wenn diese existiert.
     *
     * @param selektiertesObjekt Objekt, das in der Liste selektiert
     * werden soll, falls solche existiert.
     */
    private void belegeGUIMitVorauswahl(String selektiertesObjekt) {
        boolean gefunden = false;

        for (int i = 0; i < _objektListe.getList().getItemCount(); i++) {
            if (selektiertesObjekt.equals(_objektListe.getElementAt(i))) {
                _objektListe.getList().setSelection(i);
                gefunden = true;

                break;
            }
        }

        if (gefunden) {
            _objektName = selektiertesObjekt;
            _klasseIE.selektiereElement(_objektName);
            einblendenCompositeObjekt(true);
            _klasseIE.setzeGUIbereichMitElementDaten(_objektName);
        }
    }

    /**
     * Die Schaltflche Abbruch wird selektiert
     * (den Dialog bzw. die Sicht schlieen).
     */
    private void btnAbbruchSelektiert() {

        // Abbruch = schlieen
        frage_geandertesElementSpeichern();
        GuiFunktionen.schliesseGUI(getParent(), _viewID);
    }

    /**
     * Die Schaltflche Kopieren wird selektiert
     * (ein neues leeres Element in die Liste hinzufgen).
     */
    private void btnKopierenSelektiert() {
        StructuredSelection ss = (StructuredSelection) _objektListe.getSelection();

        // falls ein Element ausgewhlt:
        if (!ss.isEmpty()) {
            _objektName = (String) (ss.getFirstElement());
            frage_geandertesElementSpeichern();

            InputDialog inputDialog = new InputDialog(this.getShell(), "Kopiere Element " + _objektName, "Elementname: ", _objektName, null);

            if (inputDialog.open() == Dialog.OK) {
                _objektName = inputDialog.getValue();

                // der ObjektName darf nicht leer sein:
                if (_objektName.equals("")) {
                    MessageDialog.openError(this.getShell(), "Fehler", "Der Name des Elements darf nicht leer sein!");
                } else {

                    // Der ObjektName darf nicht mehr mal vorkommen:
                    if (_objektListe.getList().indexOf(_objektName) >= 0) {
                        MessageDialog.openError(this.getShell(), "Fehler", "Der Name existiert schon!");
                    } else {
                        _klasseIE.kopiereElement(_objektName);
                        einblendenCompositeObjekt(true);
                        _klasseIE.setzeGUIbereichMitElementDaten(_objektName);

                        // die Liste neu erstellen:
                        _inputArray = _klasseIE.ermittleInputArray();
                        Arrays.sort(_inputArray);
                        _objektListe.setInput(_inputArray);

                        // Neues Element selektieren:
                        List<String> selList = new ArrayList<String>();

                        selList.add(_objektName);

                        StructuredSelection strSel = new StructuredSelection(selList);

                        _objektListe.setSelection(strSel, true);
                    }
                }
            }
        }
    }

    /**
     * Die Schaltflche Lschen wird selektiert
     * (das ausgewhlte Element aus der Liste lschen).
     */
    private void btnLoeschenSelektiert() {
        StructuredSelection ss = (StructuredSelection) _objektListe.getSelection();

        // falls ein Element ausgewhlt:
        if (!ss.isEmpty()) {
            _objektName = (String) (ss.getFirstElement());

            if (MessageDialog.openQuestion(this.getShell(), "Lschen des Elements besttigen", "Mchten Sie Element " + _objektName + " lschen?")) {
                _klasseIE.loescheElement(_objektName);

                /*
                 *  z.B.:
                 * AlleFilter.getInstanz().loescheFilter((String)(ss.getFirstElement()));
                 * AlleFilter.getInstanz().speichere(AlleFilter.FILTER_DATEI);
                 */

                // initialisiere leeres Objekt (GUI Daten):
                _klasseIE.initialisiereElement();
                _objektName = "";
                _klasseIE.setzeGUIbereichMitElementDaten(_objektName);
                einblendenCompositeObjekt(false);

                // die Liste neu erstellen:
                _inputArray = _klasseIE.ermittleInputArray();
                Arrays.sort(_inputArray);
                _objektListe.setInput(_inputArray);
            }
        } else {
            MessageDialog.openError(this.getShell(), "Fehler", "Es ist kein Element ausgewhlt!");
        }
    }

    /**
     * Die Schaltflche Neu wird selektiert
     * (ein neues leeres Element in die Liste hinzufgen).
     */
    private void btnNeuSelektiert() {
        frage_geandertesElementSpeichern();

        // Definiere den Validator:
        IInputValidator validator = new IInputValidator() {
            @Override
            public String isValid(String text) {
                text = text.trim();

                if (text.length() == 0) {
                    return "";
                } else if (Arrays.asList(_inputArray).contains(text)) {
                    return "Der Name existiert schon !";
                }

                return null;
            }
        };

        // InputDialog:
        InputDialog inputDialog = new InputDialog(this.getShell(), "Neues Element", "Elementname: ", "", validator);

        if (inputDialog.open() == Dialog.OK) {
            _objektName = inputDialog.getValue();

            // der ObjektName darf nicht leer sein:
            if (_objektName.equals("")) {
                MessageDialog.openError(this.getShell(), "Fehler", "Der Name des Elements darf nicht leer sein!");
            } else {

                // Der ObjektName darf nicht mehr mal vorkommen:
                if (_objektListe.getList().indexOf(_objektName) >= 0) {
                    MessageDialog.openError(this.getShell(), "Fehler", "Der Name existiert schon!");
                } else {
                    _klasseIE.einfuegenNeuesElement(_objektName);

                    /*
                     *  z.B.:
                     * filterElement=new Filter(filterName);
                     * AlleFilter.getInstanz().addFilter(filterElement);
                     * AlleFilter.getInstanz().speichere(AlleFilter.FILTER_DATEI);
                     */
                    einblendenCompositeObjekt(true);
                    _klasseIE.setzeGUIbereichMitElementDaten(_objektName);

                    // die Liste neu erstellen:
                    _inputArray = _klasseIE.ermittleInputArray();
                    Arrays.sort(_inputArray);
                    _objektListe.setInput(_inputArray);

                    // Neues Element selektieren:
                    List<String> selList = new ArrayList<String>();

                    selList.add(_objektName);

                    StructuredSelection strSel = new StructuredSelection(selList);

                    _objektListe.setSelection(strSel, true);
                }
            }
        }
    }

    /**
     * Die Schaltflche OK wird selektiert
     * (das Objekt mit den Werten aus GUI Bereich speichern
     * und den Dialog bzw. die Sicht schlieen).
     */
    private void btnOkSelektiert() {

        // OK = speichern + schlieen
        btnUebernehmenSelektiert();
        btnAbbruchSelektiert();
    }

    /**
     * Die Schaltflche bernehmen wird selektiert
     * (das Objekt mit den Werten aus GUI Bereich speichern).
     */
    private void btnUebernehmenSelektiert() {

        // <bernehmen> = speichern
        if (!_klasseIE.sindGuiDatenMitElementDatenGleich()) {
            _klasseIE.speichereElement();
        }
    }

    /**
     * Die Schaltflche Zurcksetzen wird selektiert
     * (die Werte des ausgewhlten Elements zurck setzen).
     */
    private void btnZuruecksetzenSelektiert() {

        // zurcksetzen
        _klasseIE.setzeGUIbereichMitElementDaten(_objektName);
    }

    /**
     * Composite mit dem Objekt ein/ausblenden.
     *
     * @param zeigen Ein oder ausblenden.
     */
    private void einblendenCompositeObjekt(boolean zeigen) {
        for (Control kind : _compObjekt.getChildren()) {
            kind.setVisible(zeigen);
        }
    }

    /**
     * Falls der GUI Bereich gendert wird,
     * den Dialog mit der Frage "Speichern?" ffnen
     * und wenn "Ja", speichern.
     */
    private void frage_geandertesElementSpeichern() {
        if (!_klasseIE.sindGuiDatenMitElementDatenGleich()) {
            if (MessageDialog.openQuestion(this.getShell(), "Speichern des Elements besttigen", _objektName + " wurde gendert !" + NEWLINE + NEWLINE + "Sollen die nderungen gespeichert werden?")) {
                btnUebernehmenSelektiert();
            }
        }
    }

    //~ GET METHODEN ==========================================================

    /**
     * Getter fr Eigenschaft 'btnUebernehmen'.
     *
     * @return Wert der Eigenschaft 'btnUebernehmen'.
     *
     * @see #_btnUebernehmen
     */
    public Button getBtnUebernehmen() {
        return _btnUebernehmen;
    }

    /**
     * Getter fr Eigenschaft 'btnZuruecksetzen'.
     *
     * @return Wert der Eigenschaft 'btnZuruecksetzen'.
     *
     * @see #_btnZuruecksetzen
     */
    public Button getBtnZuruecksetzen() {
        return _btnZuruecksetzen;
    }

    //~ METHODEN ==============================================================

    /**
     * Initialisiert GUI (Zeichnet den Dialog).
     */
    private void initGUI() {
        setLayout(new GridLayout(1, false));

        final SashForm sashForm = new SashForm(this, SWT.BORDER);

        sashForm.setLayoutData(new GridData(SWT.FILL, SWT.FILL, true, true, 1, 1));

        //
        final Composite compListe = new Composite(sashForm, SWT.NONE);

        compListe.setLayout(new GridLayout(1, false));

        //
        _txtFilter = new Text(compListe, SWT.BORDER);
        _txtFilter.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, true, false, 1, 1));
        _txtFilter.addModifyListener(new ModifyListener() {
            public void modifyText(ModifyEvent event) {
                if (_objektListe != null) {
                    _objektListe.refresh();
                }
            }
        });
        _txtFilter.addKeyListener(new KeyAdapter() {
            @Override
            public void keyPressed(KeyEvent event) {
                int keyCode = event.keyCode;

                if (keyCode == SWT.ESC) {
                    _txtFilter.setText("");
                }
            }
        });

        //
        final ViewerFilter filter = new ViewerFilter() {
            @Override
            public boolean select(Viewer viewer, Object parentElement, Object element) {
                if (_txtFilter != null) {
                    String filterPattern = _txtFilter.getText().trim().toLowerCase();

                    if (!filterPattern.isEmpty()) {
                        return element.toString().toLowerCase().contains(filterPattern);
                    }
                }

                return true;
            }
        };

        //
        _objektListe = new ListViewer(compListe, SWT.H_SCROLL | SWT.V_SCROLL | SWT.EMBEDDED | SWT.BORDER);
        _objektListe.setFilters(new ViewerFilter[] { filter });

        final org.eclipse.swt.widgets.List list = _objektListe.getList();

        list.setLayoutData(new GridData(SWT.FILL, SWT.FILL, true, true, 1, 1));
        _objektListe.setContentProvider(new ArrayContentProvider());
        _objektListe.setLabelProvider(new LabelProvider());
        _objektListe.addSelectionChangedListener(new ISelectionChangedListener() {
            @Override
            public void selectionChanged(SelectionChangedEvent event) {
                listeSelectionGeaendert(event);
            }
        });
        Arrays.sort(_inputArray);
        _objektListe.setInput(_inputArray);

        //
        final Composite compListeSchaltFlaeche = new Composite(compListe, SWT.NONE);

        compListeSchaltFlaeche.setLayoutData(new GridData(SWT.RIGHT, SWT.CENTER, true, false, 1, 1));
        compListeSchaltFlaeche.setLayout(new GridLayout(3, true));

        Button btnNeu = new Button(compListeSchaltFlaeche, SWT.PUSH | SWT.CENTER);

        btnNeu.addSelectionListener(new SelectionAdapter() {
            @Override
            public void widgetSelected(SelectionEvent e) {
                btnNeuSelektiert();
            }
        });
        btnNeu.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, false, false, 1, 1));
        btnNeu.setText("Neu");

        Button btnKopieren = new Button(compListeSchaltFlaeche, SWT.PUSH | SWT.CENTER);

        btnKopieren.addSelectionListener(new SelectionAdapter() {
            @Override
            public void widgetSelected(SelectionEvent e) {
                btnKopierenSelektiert();
            }
        });
        btnKopieren.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, false, false, 1, 1));
        btnKopieren.setText("Kopieren");

        Button btnLoeschen = new Button(compListeSchaltFlaeche, SWT.PUSH | SWT.CENTER);

        btnLoeschen.addSelectionListener(new SelectionAdapter() {
            @Override
            public void widgetSelected(SelectionEvent e) {
                btnLoeschenSelektiert();
            }
        });
        btnLoeschen.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, false, false, 1, 1));
        btnLoeschen.setText("Lschen");

        //
        _compObjekt = new Composite(sashForm, SWT.NONE);
        _compObjekt.setLayout(new GridLayout(1, false));

        // initialisiere ObjektBereich (zeichne GUI ObjektTeil des Dialogs)
        _klasseIE.initialisiereGUIBereich(_compObjekt);
        einblendenCompositeObjekt(false);

        //
        sashForm.setWeights(new int[] { 1, 3 });

        //
        Composite compDialogSchaltFlaeche = new Composite(this, SWT.NONE);

        compDialogSchaltFlaeche.setLayoutData(new GridData(SWT.RIGHT, SWT.CENTER, false, false, 1, 1));
        compDialogSchaltFlaeche.setLayout(new GridLayout(4, true));
        _btnZuruecksetzen = new Button(compDialogSchaltFlaeche, SWT.PUSH | SWT.CENTER);
        _btnZuruecksetzen.addSelectionListener(new SelectionAdapter() {
            @Override
            public void widgetSelected(SelectionEvent e) {
                btnZuruecksetzenSelektiert();
            }
        });
        _btnZuruecksetzen.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, false, false, 1, 1));
        _btnZuruecksetzen.setText("Zurcksetzen");
        _btnUebernehmen = new Button(compDialogSchaltFlaeche, SWT.PUSH | SWT.CENTER);
        _btnUebernehmen.addSelectionListener(new SelectionAdapter() {
            @Override
            public void widgetSelected(SelectionEvent e) {
                btnUebernehmenSelektiert();
            }
        });
        _btnUebernehmen.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, false, false, 1, 1));
        _btnUebernehmen.setText("bernehmen");

        Button btnOK = new Button(compDialogSchaltFlaeche, SWT.PUSH | SWT.CENTER);

        btnOK.addSelectionListener(new SelectionAdapter() {
            @Override
            public void widgetSelected(SelectionEvent e) {
                btnOkSelektiert();
            }
        });
        btnOK.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, false, false, 1, 1));
        btnOK.setText("OK");

        Button btnAbbruch = new Button(compDialogSchaltFlaeche, SWT.PUSH | SWT.CENTER);

        btnAbbruch.addSelectionListener(new SelectionAdapter() {
            @Override
            public void widgetSelected(SelectionEvent e) {
                btnAbbruchSelektiert();
            }
        });
        btnAbbruch.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, false, false, 1, 1));
        btnAbbruch.setText("Abbruch");
    }

    /**
     * Initialisiert die Objekte.
     *
     * @param klasse Muss das Interface IEinstellungen implementieren.
     */
    private void initialisiereKlasse(IRahmenVerwaltungsDialogGUI klasse) {
        _klasseIE   = klasse;
        _inputArray = _klasseIE.ermittleInputArray();
        _klasseIE.initialisiereElement();
        _objektName = "";
    }

    /**
     * Neues Element wird in der Liste selektiert.
     * @param event SelectionChangedEvent.
     */
    private void listeSelectionGeaendert(SelectionChangedEvent event) {
        frage_geandertesElementSpeichern();

        StructuredSelection ss = (StructuredSelection) (event.getSelection());

        _objektName = (String) ss.getFirstElement();

        // falls kein Element selektiert ist (wird auf dem Baum auerhalb der Elementen mit dem Maus gedrckt):
        if (_objektName != null) {
            _klasseIE.selektiereElement(_objektName);
            einblendenCompositeObjekt(true);
            _klasseIE.setzeGUIbereichMitElementDaten(_objektName);
        }
    }
}


//~Formatiert mit 'inovat Kodierkonvention' am 05.11.13
