/*
 * Copyright (c) 2008 by inovat, Dipl.-Ing. H. C. Kni
 * ALL RIGHTS RESERVED.
 *
 * THIS SOFTWARE IS  PROVIDED  "AS IS"  AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF  MERCHANTABILITY  AND  FITNESS  FOR  A PARTICULAR  PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL inovat OR ITS CONTRIBUTORS BE
 * LIABLE FOR ANY  DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
 * OR CONSEQUENTIAL DAMAGES  (INCL., BUT NOT LIMITED TO, PROCUREMENT
 * OF SUBSTITUTE GOODS OR SERVICES;  LOSS OF USE, DATA, OR  PROFITS;
 * OR BUSINESS INTERRUPTION)  HOWEVER  CAUSED  AND  ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,  OR TORT (INCL.
 * NEGLIGENCE OR OTHERWISE)  ARISING  IN  ANY  WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package de.inovat.buv.inovat.lib.xml;

//~ NICHT JDK IMPORTE =========================================================

import de.inovat.buv.inovat.lib.Activator;
import de.inovat.buv.inovat.lib.debug.Log;

import org.eclipse.core.runtime.FileLocator;

import org.jdom.*;
import org.jdom.input.SAXBuilder;
import org.jdom.output.Format;
import org.jdom.output.XMLOutputter;

//~ JDK IMPORTE ===============================================================

import java.io.*;

import java.net.URL;

//~ KLASSEN ===================================================================

/**
 * Klasse enthlt statische Methoden fr die Arbeit mit den XMLDateien.
 *
 * @author inovat
 * @author Liliya Givorgizova (LG)
 * @version $Revision: 12 $ / $Date: 2013-09-24 13:23:48 +0200 (Di, 24. Sep 2013) $ / ($Author: LG $)
 */
public class XMLFunktionen {

    /**
     * Erstelle ein Document aus der XMLDatei und validiere die, falls Parameter validieren gleich <tt>true</tt> ist.
     * @param fileNameXML - XMLDatei mit dem relativen zu Eclipse Pfad (z.B. "XML/AlleFilter.xml").
     * @param validieren Legt fest, ob die Datei validiert werden soll.
     * @return Dokument von Typ org.jdom.Document, das die XMLDatei enthlt,
     *                      oder leeres Dokument, falls Exception auftritt.
     */
    public static Document erstelleDocumentAusXMLDatei(String fileNameXML, boolean validieren) {
        SAXBuilder builder = new SAXBuilder(validieren);
        Document   doc     = new Document(new Element("null"));
        File       fileXML = new File(fileNameXML);

        if (fileXML.exists()) {
            try {
                doc = builder.build(fileXML);
            }
            catch (JDOMException e) {
                Log.zeigeInterneMeldung(Activator.PLUGIN_ID, e);
            }
            catch (IOException e) {
                Log.zeigeInterneMeldung(Activator.PLUGIN_ID, e);
            }
        } else {
            Log.zeige(Log.erzeugeMeldung(Log.WARNUNG, Activator.PLUGIN_ID, "Datei <" + fileXML.getAbsolutePath() + "> existiert nicht!"));
        }

        return doc;
    }

    // ------------------------------------------------------------------------
    // STATISCHE METHODEN
    // ------------------------------------------------------------------------

    /**
     * Erzeugt den absoluten Pfad zur Datei.
     * @param url - zeigt, wo die Datei sich befinden (kann z.B. mit der Methode getResource() erzeugt werden:
     *  this.getClass().getClassLoader().getResource("src/de/inovat/...lib/FilterTyp.dtd");)
     * @return String, das den absoluten Pfad darstellt, oder leeres String, falls Datei nicht gefunden ist.
     */
    public static String erzeugeAbsolutenPfad(URL url) {
        String pfad = "";

        if (url != null) {
            URL urlAbs;

            try {
                urlAbs = FileLocator.toFileURL(url);
                pfad   = urlAbs.getPath();

                // Erster "/" - weg
                // pfad = pfad.substring(1);
                // pfad = pfad.replace("/", "//");
                if (pfad.contains("!")) {
                    pfad = "jar:" + pfad;
                }
            }
            catch (IOException e) {
                Log.zeigeInterneMultiMeldung(Activator.PLUGIN_ID, "URL [" + url + "] kann nicht ermittelt werden!", e);
            }
        } else {
            Log.zeigeInterneMeldung(Activator.PLUGIN_ID, new Throwable("URL [" + url + "] ist leer."));
        }

        return pfad;
    }

    /**
     * Speichere Dokument in die XML Datei.
     * @param dokument Zu speicherndes XML-Dokument.
     * @param dateiPfad Kompletter Pfadname der zu speichernden Datei.
     */
    public static void speichereDocumentInXMLDatei(Document dokument, String dateiPfad) {
        XMLOutputter     outp = new XMLOutputter();
        File             fl   = new File(dateiPfad);
        FileOutputStream fos;

        try {
            fos = new FileOutputStream(fl);
            outp.setFormat(Format.getPrettyFormat());

            try {
                outp.output(dokument, fos);
                fos.flush();
                fos.close();
            }
            catch (IOException e) {
                Log.zeige(Log.erzeugeMeldung(Log.FEHLER, Activator.PLUGIN_ID, "Fehler beim Screiben in Datei [" + dateiPfad + "]. Datei wird nicht gespeichert!", e));
            }
        }
        catch (FileNotFoundException e1) {
            Log.zeige(Log.erzeugeMeldung(Log.FEHLER, Activator.PLUGIN_ID, "Fehler beim Speichern. Die Datei [" + fl.getAbsolutePath() + "] existiert nicht. Datei wird nicht gespeichert!", e1));
        }
    }
}


//~Formatiert mit 'inovat Kodierkonvention' am 29.05.09
