/*
 * @(#)ArchivanfrageDatenGUIVew.java   10.02.12
 *
 * Copyright (c) 2008 by inovat, Dipl.-Ing. H. C. Kni
 * ALL RIGHTS RESERVED.
 *
 * THIS SOFTWARE IS  PROVIDED  "AS IS"  AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF  MERCHANTABILITY  AND  FITNESS  FOR  A PARTICULAR  PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL inovat OR ITS CONTRIBUTORS BE
 * LIABLE FOR ANY  DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
 * OR CONSEQUENTIAL DAMAGES  (INCL., BUT NOT LIMITED TO, PROCUREMENT
 * OF SUBSTITUTE GOODS OR SERVICES;  LOSS OF USE, DATA, OR  PROFITS;
 * OR BUSINESS INTERRUPTION)  HOWEVER  CAUSED  AND  ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,  OR TORT (INCL.
 * NEGLIGENCE OR OTHERWISE)  ARISING  IN  ANY  WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */



package de.inovat.buv.plugin.gtm.navigation.archiv;

//~ NICHT JDK IMPORTE =========================================================

import de.inovat.buv.gtm.datvew.konstanten.KonstantenGTMGUIResource;
import de.inovat.buv.inovat.lib.funktionen.datum.DatumFunktionen;
import de.inovat.buv.inovat.lib.gui.widget.DatumZeitOhneSekunden;
import de.inovat.buv.plugin.gtm.navigation.archiv.ArchivanfrageDaten.Art;
import de.inovat.buv.plugin.gtm.navigation.archiv.ArchivanfrageDaten.Prioritaet;
import de.inovat.buv.plugin.gtm.navigation.archiv.ArchivanfrageDaten.Sortierung;
import de.inovat.buv.plugin.gtm.navigation.archiv.ArchivanfrageDaten.ZeitBereichDerAnfrage;

import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.SWT;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Combo;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Spinner;
import org.eclipse.ui.forms.widgets.FormToolkit;
import org.eclipse.ui.forms.widgets.Section;

//~ KLASSEN ===================================================================

/**
 * Klasse verwaltet das GUI-Presentation von Archivanfrage-Daten.
 *
 * @author inovat
 * @author Liliya Givorgizova (LG)
 * @version $Revision: 155 $ / $Date: 2014-10-07 11:11:48 +0200 (Di, 07 Okt 2014) $ / ($Author: LG $)
 */
public class ArchivanfrageDatenGUIVew {

    /**
     * Stellt fest, ob die Methode aenderungErfolgt()
     * aufgerufen werden soll.
     */
    private boolean _aenderungErfolgtAufrufen = true;

    /** Button "Neue Archivanfrage". Wird nur fr den GTM-Dialog erstellt. */
    private Button                _btnArchivanfrage;
    private Button                _btnArchivanfrageExportCsv;
    private Button                _btnArchivanfrageExportCsvOhneEinheit;
    private Button                _btnArchivanfrageExportHtml;
    private Button                _btnArchivanfrageExportHtmlOhneEinheit;
    private Button                _cbtnAktuelleDaten;
    private Button                _cbtnAnzahlDatenBegrenzen;
    private Button                _cbtnAufrundenBis;
    private Button                _cbtnAufrundenVon;
    private Button                _cbtnNachgefordertAktuelleDaten;
    private Button                _cbtnNachgefordertNachgelieferteDaten;
    private Button                _cbtnNachgelieferteDaten;
    private Combo                 _comboArt;
    private Combo                 _comboBereich;
    private Combo                 _comboPrioritaet;
    private Combo                 _comboSortierung;
    private Composite             _compZbAbsolut;
    private Composite             _compZbRelativ;
    private DatumZeitOhneSekunden _dzBeginn;
    private DatumZeitOhneSekunden _dzEnde;
    private IArchivanfrageGUIVew  _instanzGuiVew;
    private Label                 _lbAbsolutBis;
    private Label                 _lbAbsolutVon;
    private Button                _rbtnZeitAbsolut;
    private Button                _rbtnZeitRelativ;
    private Spinner               _spAnzahlDaten;
    private Spinner               _spAnzahlMonateBis;
    private Spinner               _spAnzahlMonateVor;
    private Spinner               _spAnzahlStundenBis;
    private Spinner               _spAnzahlStundenVor;
    private Spinner               _spAnzahlTageBis;
    private Spinner               _spAnzahlTageVor;
    private Spinner               _spIndexBis;
    private Spinner               _spIndexVon;

    //~ KONSTRUKTOREN  (und vom Konstruktor verwendete Methoden) ==============

    /**
     * Erzeugt eine Instanz der Klasse ArchivanfrageDatenGUIVew.
     *
     * @param instanzGuiVew IArchivanfrageGUIVew - Instanz der Klasse,
     * die das GUI "Archivanfrage" in sein GUI einbauen will.
     */
    public ArchivanfrageDatenGUIVew(IArchivanfrageGUIVew instanzGuiVew) {
        _instanzGuiVew = instanzGuiVew;
    }

    //~ METHODEN ==============================================================

    /**
     * GUI-Teil "Zeitbereich der Archivanfrage" wird angepasst.
     * (abhngig von ausgewlten GUI-Elementen werden Widgets Gren und Sichtbarkeit gendert)
     */
    private void anpassenArchivZeitBereichGUI() {
        boolean istComboDatenindex = _comboBereich.getText().equals(ZeitBereichDerAnfrage.Datenindex.name());

        // --------------------------------------------------------
        // Falls Combo "Datenindex" --> nur absolute Zeit
        if (istComboDatenindex) {
            _rbtnZeitAbsolut.setSelection(true);
            _rbtnZeitRelativ.setSelection(false);
        }

        // --------------------------------------------------------
        boolean istZeitAbsolut = _rbtnZeitAbsolut.getSelection();

        // --------------------------------------------------------
        // Sichtbarkeit von "Relative Zeitangabe":
        _compZbRelativ.setVisible(!istZeitAbsolut);

        // --------------------------------------------------------
        // Sichtbarkeit von "Absolute Zeitangabe":
        // _compArchivZbAbsolut.setVisible(istZeitAbsolut);
        Control[] arElemente = { _spIndexVon, _dzBeginn, _lbAbsolutBis, _spIndexBis, _dzEnde, _cbtnAnzahlDatenBegrenzen, _spAnzahlDaten };

        for (Control el : arElemente) {
            el.setVisible(istZeitAbsolut);
        }

        // --------------------------------------------------------
        // Absolute Zeitangabe:
        // --------------------------------------------------------
        if (istZeitAbsolut) {

            // --------------------------------------------------------
            // Label-Beschriftung:
            _lbAbsolutVon.setText("Von:");

            // --------------------------------------------------------
            boolean istAnzahlDatenBegrenzt = _cbtnAnzahlDatenBegrenzen.getSelection();
            int     breite                 = -18;

            // --------------------------------------------------------
            // Gre von/bis SpinnerIndex:
            if (istComboDatenindex) {
                breite = 100;
            }

            ((GridData) _spIndexVon.getLayoutData()).widthHint = breite;
            ((GridData) _spIndexBis.getLayoutData()).widthHint = breite;

            // --------------------------------------------------------
            // Gre von/bis DatumZeit:
            if (istComboDatenindex) {
                ((GridData) _dzBeginn.getLayoutData()).widthHint = 1;
                ((GridData) _dzEnde.getLayoutData()).widthHint   = 1;
            } else {
                GridData gd = new GridData(SWT.LEFT, SWT.CENTER, false, false, 1, 1);

                _dzBeginn.setLayoutData(gd);
                _dzEnde.setLayoutData(gd);
            }

            // von:
            // Sichtbarkeit:
            // --------------------------------------------------------
            _lbAbsolutVon.setVisible(!istAnzahlDatenBegrenzt);
            _dzBeginn.setVisible(!istAnzahlDatenBegrenzt &&!istComboDatenindex);
            _spIndexVon.setVisible(!istAnzahlDatenBegrenzt && istComboDatenindex);

            // bis:
            _dzEnde.setVisible(!istComboDatenindex);
            _spIndexBis.setVisible(istComboDatenindex);

            // Anzahl der Datenstze:
            _spAnzahlDaten.setVisible(istAnzahlDatenBegrenzt);
        }

        // --------------------------------------------------------
        // Relative Zeitangabe:
        // --------------------------------------------------------
        else {

            // --------------------------------------------------------
            // ToolTipText:
            _compZbRelativ.setToolTipText(ermittleZeitbereichRelativ());

            // --------------------------------------------------------
            // Label-Sichtbarkeit/Beschriftung:
            _lbAbsolutVon.setVisible(true);

            // _lbAbsolutVon.setText("Relative Zeitangabe von  MONATEN / TAGEN / STUNDEN  vor dem akuellen Zeitpunkt: < " + info.toString() + " >");
            _lbAbsolutVon.setText("Relative Zeitangabe von  MONATEN / TAGEN / STUNDEN  vor dem aktuellen Zeitpunkt:");
        }

        //
        _compZbAbsolut.layout();

        // --------------------------------------------------------
        archivGuiDatenGeaendert();
    }

    /**
     * Reaktion auf nderungen im GUI "Archivanfrage".
     */
    private void archivGuiDatenGeaendert() {
        if (_aenderungErfolgtAufrufen) {
            _instanzGuiVew.archivGuiDatenGeaendert();
        }
    }

    /**
     * Ermittle ArchivanfrageDaten aus GUI.
     *
     * @return ArchivanfrageDaten mit GUI-Werten.
     */
    public ArchivanfrageDaten ermittleObjektAusGUI() {
        ArchivanfrageDaten archivDaten;

        //
        String  zustandsAnfrage                  = _comboArt.getText();
        String  sortierung                       = _comboSortierung.getText();
        String  prioritaet                       = _comboPrioritaet.getText();
        boolean aktuelleDaten                    = _cbtnAktuelleDaten.getSelection();
        boolean nachgelieferteDaten              = _cbtnNachgelieferteDaten.getSelection();
        boolean nachgefordertAktuelleDaten       = _cbtnNachgefordertAktuelleDaten.getSelection();
        boolean nachgefordertNachgelieferteDaten = _cbtnNachgefordertNachgelieferteDaten.getSelection();

        //
        String  zeitBereich = _comboBereich.getText();
        boolean istAbsolut  = _rbtnZeitAbsolut.getSelection();

        // Absoluter Zeitbereich:
        if (istAbsolut) {
            boolean istAnzahlDatenBegrenzt = _cbtnAnzahlDatenBegrenzen.getSelection();
            int     anzDaten               = _spAnzahlDaten.getSelection();

            // von/bis Index:
            if (zeitBereich.equals(ZeitBereichDerAnfrage.Datenindex.name())) {
                archivDaten = new ArchivanfrageDaten(zustandsAnfrage, sortierung, prioritaet,                                                                                               //
                                                     aktuelleDaten, nachgelieferteDaten, nachgefordertAktuelleDaten, nachgefordertNachgelieferteDaten,                                      //
                                                     _spIndexVon.getSelection(), _spIndexBis.getSelection(),                                                                                //
                                                     istAnzahlDatenBegrenzt, anzDaten);
            }

            // von/bis Datum:
            else {
                archivDaten = new ArchivanfrageDaten(zustandsAnfrage, sortierung, prioritaet,                                                                                               //
                                                     aktuelleDaten, nachgelieferteDaten, nachgefordertAktuelleDaten, nachgefordertNachgelieferteDaten,                                      //
                                                     zeitBereich, _dzBeginn.ermittleDatumZeit(), _dzEnde.ermittleDatumZeit(),                                                               //
                                                     istAnzahlDatenBegrenzt, anzDaten);
            }
        }

        // Relativer Zeitbereich:
        else {
            archivDaten = new ArchivanfrageDaten(zustandsAnfrage, sortierung, prioritaet,                                                                                                   //
                                                 aktuelleDaten, nachgelieferteDaten, nachgefordertAktuelleDaten, nachgefordertNachgelieferteDaten,                                          //
                                                 zeitBereich,                                                                                                                               //
                                                 _spAnzahlMonateVor.getSelection(), _spAnzahlTageVor.getSelection(), _spAnzahlStundenVor.getSelection(), _cbtnAufrundenVon.getSelection(),  //
                                                 _spAnzahlMonateBis.getSelection(), _spAnzahlTageBis.getSelection(), _spAnzahlStundenBis.getSelection(), _cbtnAufrundenBis.getSelection());
        }

        //
        return archivDaten;
    }

    /**
     * Ermittle relativen Zeitbereich als Text.
     *
     * @return Relativen Zeitbereich {von, bis}.
     */
    private String ermittleZeitbereichRelativ() {
        long[]        zb   = ArchivanfrageDaten.ermittleZeitbereichRelativ(                                                                            //
            _spAnzahlMonateVor.getSelection(), _spAnzahlTageVor.getSelection(), _spAnzahlStundenVor.getSelection(), _cbtnAufrundenVon.getSelection(),  //
            _spAnzahlMonateBis.getSelection(), _spAnzahlTageBis.getSelection(), _spAnzahlStundenBis.getSelection(), _cbtnAufrundenBis.getSelection());
        StringBuilder info = new StringBuilder();

        info.append(DatumFunktionen.getDatumZeitOhneSekundenAlsString(zb[0]));
        info.append(" - ");
        info.append(DatumFunktionen.getDatumZeitOhneSekundenAlsString(zb[1]));

        return info.toString();
    }

    /**
     * Initialisiere das GUI "Archivanfrage".
     *
     * @param parent Parent.
     * @param formToolkit FormToolkit.
     * @wbp.parser.entryPoint
     */
    public void initGUI(Section parent, FormToolkit formToolkit) {
        Composite compArchivanfrage = new Composite(parent, SWT.NONE);

        formToolkit.adapt(compArchivanfrage);
        formToolkit.paintBordersFor(compArchivanfrage);
        parent.setClient(compArchivanfrage);
        compArchivanfrage.setLayout(new GridLayout(2, false));

        //
        formToolkit.createLabel(compArchivanfrage, "Anfrageart:", SWT.NONE);

        //
        Composite compParameter = formToolkit.createComposite(compArchivanfrage, SWT.NONE);

        compParameter.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, true, false, 1, 1));
        formToolkit.paintBordersFor(compParameter);
        compParameter.setLayout(new GridLayout(5, false));
        _comboArt = new Combo(compParameter, SWT.READ_ONLY);
        _comboArt.setItems(Art.ermittleElemente());
        _comboArt.setToolTipText("Art der Archivanfrage.");
        _comboArt.addSelectionListener(new SelectionAdapter() {
            @Override
            public void widgetSelected(SelectionEvent e) {
                archivGuiDatenGeaendert();
            }
        });
        formToolkit.adapt(_comboArt);
        formToolkit.paintBordersFor(_comboArt);
        formToolkit.createLabel(compParameter, "Sortierreihenfolge Datens\u00E4tze", SWT.NONE);
        _comboSortierung = new Combo(compParameter, SWT.READ_ONLY);
        _comboSortierung.setItems(Sortierung.ermittleElemente());
        _comboSortierung.setToolTipText("Art der Archivanfrage.");
        _comboSortierung.addSelectionListener(new SelectionAdapter() {
            @Override
            public void widgetSelected(SelectionEvent e) {
                archivGuiDatenGeaendert();
            }
        });
        formToolkit.adapt(_comboSortierung);
        formToolkit.paintBordersFor(_comboSortierung);
        formToolkit.createLabel(compParameter, "Priorit\u00E4t", SWT.NONE);
        _comboPrioritaet = new Combo(compParameter, SWT.READ_ONLY);
        _comboPrioritaet.setItems(Prioritaet.ermittleElemente());
        _comboPrioritaet.setToolTipText("Priorit\u00E4t.");
        _comboPrioritaet.addSelectionListener(new SelectionAdapter() {
            @Override
            public void widgetSelected(SelectionEvent e) {
                archivGuiDatenGeaendert();
            }
        });
        formToolkit.adapt(_comboPrioritaet);
        formToolkit.paintBordersFor(_comboPrioritaet);
        new Label(compArchivanfrage, SWT.NONE);

        //
        Composite compArt = formToolkit.createComposite(compArchivanfrage, SWT.NONE);

        compArt.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, true, false, 1, 1));
        formToolkit.paintBordersFor(compArt);

        GridLayout gl_compArt = new GridLayout(4, false);

        compArt.setLayout(gl_compArt);
        _cbtnAktuelleDaten = new Button(compArt, SWT.CHECK);
        _cbtnAktuelleDaten.setText("aktuelle Daten");
        _cbtnAktuelleDaten.setSelection(true);
        _cbtnAktuelleDaten.addSelectionListener(new SelectionAdapter() {
            @Override
            public void widgetSelected(SelectionEvent e) {
                archivGuiDatenGeaendert();
            }
        });
        formToolkit.adapt(_cbtnAktuelleDaten, true, true);
        _cbtnNachgelieferteDaten = new Button(compArt, SWT.CHECK);
        _cbtnNachgelieferteDaten.setText("nachgelieferte Daten");
        formToolkit.adapt(_cbtnNachgelieferteDaten, true, true);
        _cbtnNachgefordertAktuelleDaten = new Button(compArt, SWT.CHECK);
        _cbtnNachgefordertAktuelleDaten.setText("nachgefordert-aktuelle Daten");
        _cbtnNachgefordertAktuelleDaten.addSelectionListener(new SelectionAdapter() {
            @Override
            public void widgetSelected(SelectionEvent e) {
                archivGuiDatenGeaendert();
            }
        });
        formToolkit.adapt(_cbtnNachgefordertAktuelleDaten, true, true);
        _cbtnNachgefordertNachgelieferteDaten = new Button(compArt, SWT.CHECK);
        _cbtnNachgefordertNachgelieferteDaten.setText("nachgefordert-nachgelieferte Daten");
        _cbtnNachgefordertNachgelieferteDaten.addSelectionListener(new SelectionAdapter() {
            @Override
            public void widgetSelected(SelectionEvent e) {
                archivGuiDatenGeaendert();
            }
        });
        formToolkit.adapt(_cbtnNachgefordertNachgelieferteDaten, true, true);
        _cbtnNachgelieferteDaten.addSelectionListener(new SelectionAdapter() {
            @Override
            public void widgetSelected(SelectionEvent e) {
                archivGuiDatenGeaendert();
            }
        });

        //
        formToolkit.createLabel(compArchivanfrage, "(Zeit-)Bereich der Anfrage:", SWT.NONE);

        //
        Composite compZeitBereich = formToolkit.createComposite(compArchivanfrage, SWT.NONE);

        compZeitBereich.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, true, false, 1, 1));
        formToolkit.paintBordersFor(compZeitBereich);
        compZeitBereich.setLayout(new GridLayout(3, false));
        _comboBereich = new Combo(compZeitBereich, SWT.READ_ONLY);
        _comboBereich.setItems(ZeitBereichDerAnfrage.ermittleElemente());
        _comboBereich.setToolTipText("Bereichsauswahl.");
        _comboBereich.addSelectionListener(new SelectionAdapter() {
            @Override
            public void widgetSelected(SelectionEvent e) {
                anpassenArchivZeitBereichGUI();
            }
        });
        formToolkit.adapt(_comboBereich);
        formToolkit.paintBordersFor(_comboBereich);
        _rbtnZeitAbsolut = formToolkit.createButton(compZeitBereich, "feste Zeitangabe", SWT.RADIO);
        _rbtnZeitAbsolut.addSelectionListener(new SelectionAdapter() {
            @Override
            public void widgetSelected(SelectionEvent e) {
                anpassenArchivZeitBereichGUI();
            }
        });
        _rbtnZeitRelativ = formToolkit.createButton(compZeitBereich, "relative Zeitangabe", SWT.RADIO);
        _rbtnZeitRelativ.addSelectionListener(new SelectionAdapter() {
            @Override
            public void widgetSelected(SelectionEvent e) {
                anpassenArchivZeitBereichGUI();
            }
        });
        new Label(compArchivanfrage, SWT.NONE);

        //
        _compZbAbsolut = formToolkit.createComposite(compArchivanfrage, SWT.NONE);
        _compZbAbsolut.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, true, false, 1, 1));
        formToolkit.paintBordersFor(_compZbAbsolut);

        GridLayout gl_compZbAbsolut = new GridLayout(8, false);

        gl_compZbAbsolut.marginHeight = 0;
        _compZbAbsolut.setLayout(gl_compZbAbsolut);
        _lbAbsolutVon = formToolkit.createLabel(_compZbAbsolut, "Von:", SWT.NONE);
        _spIndexVon   = new Spinner(_compZbAbsolut, SWT.BORDER);
        _spIndexVon.addSelectionListener(new SelectionAdapter() {
            @Override
            public void widgetSelected(SelectionEvent e) {
                archivGuiDatenGeaendert();
            }
        });
        formToolkit.adapt(_spIndexVon);
        formToolkit.paintBordersFor(_spIndexVon);
        _dzBeginn = new DatumZeitOhneSekunden(_compZbAbsolut, SWT.BORDER);
        _dzBeginn.setzeDatumZeit(DatumFunktionen.getAktuelleDateTime());
        _dzBeginn.erweitereGroesse(5, 0);
        _dzBeginn.addSelectionListener(new SelectionAdapter() {
            @Override
            public void widgetSelected(SelectionEvent e) {
                archivGuiDatenGeaendert();
            }
        });
        formToolkit.adapt(_dzBeginn);
        formToolkit.paintBordersFor(_dzBeginn);
        _lbAbsolutBis = formToolkit.createLabel(_compZbAbsolut, "Bis:", SWT.NONE);
        _spIndexBis   = new Spinner(_compZbAbsolut, SWT.BORDER);
        _spIndexBis.addSelectionListener(new SelectionAdapter() {
            @Override
            public void widgetSelected(SelectionEvent e) {
                archivGuiDatenGeaendert();
            }
        });
        formToolkit.adapt(_spIndexBis);
        formToolkit.paintBordersFor(_spIndexBis);
        _dzEnde = new DatumZeitOhneSekunden(_compZbAbsolut, SWT.BORDER);
        _dzEnde.setzeDatumZeit(DatumFunktionen.getAktuelleDateTime());
        _dzEnde.erweitereGroesse(5, 0);
        _dzEnde.addSelectionListener(new SelectionAdapter() {
            @Override
            public void widgetSelected(SelectionEvent e) {
                archivGuiDatenGeaendert();
            }
        });
        formToolkit.adapt(_dzEnde);
        formToolkit.paintBordersFor(_dzEnde);
        _cbtnAnzahlDatenBegrenzen = formToolkit.createButton(_compZbAbsolut, "Datenanzahl bergrenzen", SWT.CHECK);
        _cbtnAnzahlDatenBegrenzen.addSelectionListener(new SelectionAdapter() {
            @Override
            public void widgetSelected(SelectionEvent e) {
                anpassenArchivZeitBereichGUI();
            }
        });
        _spAnzahlDaten = new Spinner(_compZbAbsolut, SWT.BORDER);
        _spAnzahlDaten.addSelectionListener(new SelectionAdapter() {
            @Override
            public void widgetSelected(SelectionEvent e) {
                archivGuiDatenGeaendert();
            }
        });
        formToolkit.adapt(_spAnzahlDaten);
        formToolkit.paintBordersFor(_spAnzahlDaten);

        //
        new Label(compArchivanfrage, SWT.NONE);
        _compZbRelativ = formToolkit.createComposite(compArchivanfrage, SWT.NONE);
        _compZbRelativ.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, true, false, 1, 1));
        formToolkit.paintBordersFor(_compZbRelativ);

        GridLayout gl_compZbRelativ = new GridLayout(11, false);

        gl_compZbRelativ.marginHeight = 0;
        _compZbRelativ.setLayout(gl_compZbRelativ);

        //
        formToolkit.createLabel(_compZbRelativ, "Von:", SWT.NONE);
        _spAnzahlMonateVor = new Spinner(_compZbRelativ, SWT.BORDER);
        _spAnzahlMonateVor.addSelectionListener(new SelectionAdapter() {
            @Override
            public void widgetSelected(SelectionEvent e) {
                anpassenArchivZeitBereichGUI();
            }
        });
        formToolkit.adapt(_spAnzahlMonateVor);
        formToolkit.paintBordersFor(_spAnzahlMonateVor);
        _spAnzahlTageVor = new Spinner(_compZbRelativ, SWT.BORDER);
        _spAnzahlTageVor.addSelectionListener(new SelectionAdapter() {
            @Override
            public void widgetSelected(SelectionEvent e) {
                anpassenArchivZeitBereichGUI();
            }
        });
        formToolkit.adapt(_spAnzahlTageVor);
        formToolkit.paintBordersFor(_spAnzahlTageVor);
        _spAnzahlStundenVor = new Spinner(_compZbRelativ, SWT.BORDER);
        _spAnzahlStundenVor.addSelectionListener(new SelectionAdapter() {
            @Override
            public void widgetSelected(SelectionEvent e) {
                anpassenArchivZeitBereichGUI();
            }
        });
        formToolkit.adapt(_spAnzahlStundenVor);
        formToolkit.paintBordersFor(_spAnzahlStundenVor);
        _cbtnAufrundenVon = formToolkit.createButton(_compZbRelativ, "Aufrunden", SWT.CHECK);
        _cbtnAufrundenVon.addSelectionListener(new SelectionAdapter() {
            @Override
            public void widgetSelected(SelectionEvent e) {
                anpassenArchivZeitBereichGUI();
            }
        });
        formToolkit.createLabel(_compZbRelativ, "Bis:", SWT.NONE);
        _spAnzahlMonateBis = new Spinner(_compZbRelativ, SWT.BORDER);
        _spAnzahlMonateBis.addSelectionListener(new SelectionAdapter() {
            @Override
            public void widgetSelected(SelectionEvent e) {
                anpassenArchivZeitBereichGUI();
            }
        });
        formToolkit.adapt(_spAnzahlMonateBis);
        formToolkit.paintBordersFor(_spAnzahlMonateBis);
        _spAnzahlTageBis = new Spinner(_compZbRelativ, SWT.BORDER);
        _spAnzahlTageBis.addSelectionListener(new SelectionAdapter() {
            @Override
            public void widgetSelected(SelectionEvent e) {
                anpassenArchivZeitBereichGUI();
            }
        });
        formToolkit.adapt(_spAnzahlTageBis);
        formToolkit.paintBordersFor(_spAnzahlTageBis);
        _spAnzahlStundenBis = new Spinner(_compZbRelativ, SWT.BORDER);
        _spAnzahlStundenBis.addSelectionListener(new SelectionAdapter() {
            @Override
            public void widgetSelected(SelectionEvent e) {
                anpassenArchivZeitBereichGUI();
            }
        });
        formToolkit.adapt(_spAnzahlStundenBis);
        formToolkit.paintBordersFor(_spAnzahlStundenBis);
        _cbtnAufrundenBis = formToolkit.createButton(_compZbRelativ, "Aufrunden", SWT.CHECK);
        _cbtnAufrundenBis.addSelectionListener(new SelectionAdapter() {
            @Override
            public void widgetSelected(SelectionEvent e) {
                anpassenArchivZeitBereichGUI();
            }
        });

        final Button btnInfo = formToolkit.createButton(_compZbRelativ, "", SWT.NONE);

        btnInfo.setImage(KonstantenGTMGUIResource.ICON_INFO);
        btnInfo.addSelectionListener(new SelectionAdapter() {
            @Override
            public void widgetSelected(SelectionEvent e) {
                StringBuilder info = new StringBuilder();

                info.append("Zeitberech wird ber den Anfang und das Ende (von - bis) definiert.\n");
                info.append("BIS-Zeitpunkt wird dabei aus der Archivanfrage ausgeschlossen.\n\n");

                //
                info.append("Relative Angabe erfolg ber die Anzahl von Monaten, Tagen und Stunden vor einem <bestimmten Zeitpunkt>. ");
                info.append("Falls die Option <Aufrunden> ausgeschalten ist, ist dieser <bestimmte Zeitpunkt> der aktuelle Zeitpunkt. ");

                //
                info.append("Bei der eingeschalteten Option <Aufrunden> wird der <bestimmte Zeitpunkt> aus dem aktuellen Zeitpunkt zuerst wie folgt angepasst:\n");
                info.append("--- Monate > 0: Zeitpunkt ist der Anfang des nchsten Monats.\n");
                info.append("--- Monate = 0, Tage > 0: Zeitpunkt ist der Anfang des nchsten Tages.\n");
                info.append("--- Monate = 0, Tage = 0, Stunden > 0: Zeitpunkt ist der Anfang der nchsten Stunde.\n");
                info.append("--- Monate = 0, Tage = 0, Stunden = 0: aktueller Zeitpunkt.\n\n\n");

                //
                info.append("Aktuell ist folgender Zeitbereich ausgewhlt:\n\n");
                info.append(ermittleZeitbereichRelativ());

                //
                MessageDialog.openInformation(btnInfo.getShell(), "Information", info.toString());
            }
        });

        // Button "Neue Archivanfrage" wird nur fr den GTM-Dialog erstellt:
        //
        if (_instanzGuiVew.istBtnArchivanfrage()) {
            _btnArchivanfrage = formToolkit.createButton(compArchivanfrage, "Neue Archivanfrage", SWT.NONE);
            _btnArchivanfrage.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, false, false, 1, 1));
            _btnArchivanfrage.addSelectionListener(new SelectionAdapter() {
                @Override
                public void widgetSelected(SelectionEvent e) {
                    _instanzGuiVew.btnArchivanfrageSelektiert();
                }
            });
            _btnArchivanfrage.setEnabled(false);

            // ToolTip:
            StringBuilder stringToolTipTextArchiv = new StringBuilder();

            stringToolTipTextArchiv.append("Durch Bet\u00E4tigung der Schaltfl\u00E4che \"Start\" wird jedesmal eine Neuanfrage");
            stringToolTipTextArchiv.append(System.getProperty("line.separator"));
            stringToolTipTextArchiv.append("an das Archivsystem gestellt. Stellt das Archiv mehr Datens\u00E4tze bereit,");
            stringToolTipTextArchiv.append(System.getProperty("line.separator"));
            stringToolTipTextArchiv.append("als Tabellenzeilenmaximum bei den Darstellungsoptionen angegeben worden sind,");
            stringToolTipTextArchiv.append(System.getProperty("line.separator"));
            stringToolTipTextArchiv.append("k\u00F6nnten weitere Datens\u00E4tze mittels der \"Start\" Schaltfl\u00E4che im");
            stringToolTipTextArchiv.append(System.getProperty("line.separator"));
            stringToolTipTextArchiv.append("'Darstellungsoptionen Bereich' angefordert werden.");
            stringToolTipTextArchiv.append(System.getProperty("line.separator"));
            stringToolTipTextArchiv.append("Durch Bet\u00E4tigung der Schaltfl\u00E4che werden 50% der Tabellenzeilen ersetzt.");
            _btnArchivanfrage.setToolTipText(stringToolTipTextArchiv.toString());

            Composite compSchaltflaechen = formToolkit.createComposite(compArchivanfrage, SWT.NONE);

            compSchaltflaechen.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, true, false, 1, 1));
            formToolkit.paintBordersFor(compSchaltflaechen);
            compSchaltflaechen.setLayout(new GridLayout(4, false));

            //
            _btnArchivanfrageExportHtml = formToolkit.createButton(compSchaltflaechen, "Export in html...", SWT.NONE);
            _btnArchivanfrageExportHtml.setEnabled(false);
            _btnArchivanfrageExportHtml.addSelectionListener(new SelectionAdapter() {
                @Override
                public void widgetSelected(SelectionEvent e) {
                    _instanzGuiVew.btnArchivanfrageExportHtmlSelektiert();
                }
            });
            _btnArchivanfrageExportHtml.setToolTipText(String.format("Die Archivanfrage wird gestartet und %nArchivdaten werden in die html-Datei exportiert.%nDie Daten werden dabei nicht in der Tabelle dargestellt."));

            //
            _btnArchivanfrageExportCsv = formToolkit.createButton(compSchaltflaechen, "Export in csv...", SWT.NONE);
            _btnArchivanfrageExportCsv.setEnabled(false);
            _btnArchivanfrageExportCsv.addSelectionListener(new SelectionAdapter() {
                @Override
                public void widgetSelected(SelectionEvent e) {
                    _instanzGuiVew.btnArchivanfrageExportCsvSelektiert();
                }
            });
            _btnArchivanfrageExportCsv.setToolTipText(String.format("Die Archivanfrage wird gestartet und %nArchivdaten werden in die csv-Datei exportiert.%nDie Daten werden dabei nicht in der Tabelle dargestellt."));

            //
            _btnArchivanfrageExportHtmlOhneEinheit = formToolkit.createButton(compSchaltflaechen, "Export in html (ohne Einheit)...", SWT.NONE);
            _btnArchivanfrageExportHtmlOhneEinheit.setEnabled(false);
            _btnArchivanfrageExportHtmlOhneEinheit.addSelectionListener(new SelectionAdapter() {
                @Override
                public void widgetSelected(SelectionEvent e) {
                    _instanzGuiVew.btnArchivanfrageExportHtmlOhneEinheitSelektiert();
                }
            });
            _btnArchivanfrageExportHtmlOhneEinheit.setToolTipText(String.format("Die Archivanfrage wird gestartet und %nArchivdaten werden in die html-Datei exportiert.%nDie Daten werden dabei nicht in der Tabelle dargestellt."));

            //
            _btnArchivanfrageExportCsvOhneEinheit = formToolkit.createButton(compSchaltflaechen, "Export in csv (ohne Einheit)...", SWT.NONE);
            _btnArchivanfrageExportCsvOhneEinheit.setEnabled(false);
            _btnArchivanfrageExportCsvOhneEinheit.addSelectionListener(new SelectionAdapter() {
                @Override
                public void widgetSelected(SelectionEvent e) {
                    _instanzGuiVew.btnArchivanfrageExportCsvOhneEinheitSelektiert();
                }
            });
            _btnArchivanfrageExportCsvOhneEinheit.setToolTipText(String.format("Die Archivanfrage wird gestartet und %nArchivdaten werden in die csv-Datei exportiert.%nDie Daten werden dabei nicht in der Tabelle dargestellt."));
        }
    }

    /**
     * Setze den Enabled-Wert fr alle Schaltflchen der Archivanfrage.
     *
     * @param enabled Neuer Enabled-Wert.
     */
    public void setzeEnabledWertFuerAlleBtnArchivanfrage(boolean enabled) {
        _btnArchivanfrage.setEnabled(enabled);
        _btnArchivanfrageExportHtml.setEnabled(enabled);
        _btnArchivanfrageExportCsv.setEnabled(enabled);
        _btnArchivanfrageExportHtmlOhneEinheit.setEnabled(enabled);
        _btnArchivanfrageExportCsvOhneEinheit.setEnabled(enabled);
    }

    /**
     * Setze GUI-Bereich mit Werten aus ArchivanfrageDaten.
     *
     * @param archivDaten ArchivanfrageDaten.
     */
    public void setzeGUIbereich(ArchivanfrageDaten archivDaten) {

        //
        _comboArt.setText(archivDaten.getIsZustandsAnfrage());
        _comboSortierung.setText(archivDaten.getSortierReihenfolge());
        _comboPrioritaet.setText(archivDaten.getPrioritaetDerAnfrage());

        //
        _cbtnAktuelleDaten.setSelection(archivDaten.isAktuelleDaten());
        _cbtnNachgelieferteDaten.setSelection(archivDaten.isNachgelieferteDaten());
        _cbtnNachgefordertAktuelleDaten.setSelection(archivDaten.isNachgefordertAktuelleDaten());
        _cbtnNachgefordertNachgelieferteDaten.setSelection(archivDaten.isNachgefordertNachgelieferteDaten());

        //
        _comboBereich.setText(archivDaten.getZeitBereichDerAnfrage());
        _rbtnZeitAbsolut.setSelection(archivDaten.isIstAbsoluteZeitangabe());
        _rbtnZeitRelativ.setSelection(!archivDaten.isIstAbsoluteZeitangabe());

        //
        _spIndexVon.setSelection(archivDaten.getVonIndex());
        _spIndexBis.setSelection(archivDaten.getBisIndex());
        _dzBeginn.setzeDatumZeit(archivDaten.getVonDatum());
        _dzEnde.setzeDatumZeit(archivDaten.getBisDatum());
        _cbtnAnzahlDatenBegrenzen.setSelection(archivDaten.isIstDatenanzahlBegrenzt());
        _spAnzahlDaten.setSelection(archivDaten.getAnzahlDaten());

        //
        _spAnzahlMonateVor.setSelection(archivDaten.getVonMonate());
        _spAnzahlTageVor.setSelection(archivDaten.getVonTage());
        _spAnzahlStundenVor.setSelection(archivDaten.getVonStunden());
        _cbtnAufrundenVon.setSelection(archivDaten.isIstVonAufrunden());
        _spAnzahlMonateBis.setSelection(archivDaten.getBisMonate());
        _spAnzahlTageBis.setSelection(archivDaten.getBisTage());
        _spAnzahlStundenBis.setSelection(archivDaten.getBisStunden());
        _cbtnAufrundenBis.setSelection(archivDaten.isIstBisAufrunden());

        //
        _aenderungErfolgtAufrufen = false;
        anpassenArchivZeitBereichGUI();
        _aenderungErfolgtAufrufen = true;
    }
}


//~Formatiert mit 'inovat Kodierkonvention' am 10.03.14
