/*
 * Copyright (c) 2008 by inovat, Dipl.-Ing. H. C. Kni
 * ALL RIGHTS RESERVED.
 *
 * THIS SOFTWARE IS  PROVIDED  "AS IS"  AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF  MERCHANTABILITY  AND  FITNESS  FOR  A PARTICULAR  PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL inovat OR ITS CONTRIBUTORS BE
 * LIABLE FOR ANY  DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
 * OR CONSEQUENTIAL DAMAGES  (INCL., BUT NOT LIMITED TO, PROCUREMENT
 * OF SUBSTITUTE GOODS OR SERVICES;  LOSS OF USE, DATA, OR  PROFITS;
 * OR BUSINESS INTERRUPTION)  HOWEVER  CAUSED  AND  ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,  OR TORT (INCL.
 * NEGLIGENCE OR OTHERWISE)  ARISING  IN  ANY  WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */



package de.inovat.buv.plugin.gtm.navigation.export;

//~ NICHT JDK IMPORTE =========================================================

import java.io.FileWriter;
import java.io.PrintWriter;
import java.util.LinkedList;
import java.util.List;

import org.eclipse.jface.viewers.TableViewer;
import org.eclipse.swt.SWT;
import org.eclipse.swt.widgets.FileDialog;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.ui.PlatformUI;

import de.bsvrz.buv.rw.basislib.tabellen.ITabellenZeile;
import de.bsvrz.buv.rw.basislib.tabellen.TabellenDatenStruktur;
import de.inovat.buv.gtm.datvew.konstanten.KonstantenGTM;
import de.inovat.buv.projektlib.speicher.OrdnerEinstellungen;

//~ KLASSEN ===================================================================

public class CsvExport {

    /** Liste mit der aktuellen spaltenauswahl. */
    private List<String> _spaltenAuswahl;

    /** TabelViewer mit dem Tabelleninhalt, der ausgedruckt werden soll. */
    private TableViewer _tabellenInhalt;

    /** Tabellenkopfzeile. */
    private String[] _tabellenKopfzeile;

    /** Tabellendatenstruktur. */
    private TabellenDatenStruktur _tabellenStruktur;

    /** Array mit allen Zusatzinformationen die in dem Csv Dokument ausgegeben werden. */
    private String[][] _zusatzinformationen;

    //~ KONSTRUKTOREN  (und vom Konstruktor verwendete Methoden) ==============

    /**
     * Erzeugt eine Instanz der Klasse CsvExport.
     * @param tabellenKopfzeile   Tabellenkopfzeile.
     * @param tabellenInhalt    Tabelleninhalt.
     * @param tabellenStruktur Tabellendatenstruktur.
     * @param zusatzInformationen Zusatzinformationen.
     * @param spaltenAuswahl aktuelle Spaltenauswahl.
     */
    public CsvExport(String[] tabellenKopfzeile, TableViewer tabellenInhalt, TabellenDatenStruktur tabellenStruktur, String[][] zusatzInformationen, List<String> spaltenAuswahl) {
        _tabellenKopfzeile   = tabellenKopfzeile;
        _tabellenInhalt      = tabellenInhalt;
        _tabellenStruktur    = tabellenStruktur;
        _zusatzinformationen = zusatzInformationen;
        _spaltenAuswahl      = spaltenAuswahl;
    }

    //~ METHODEN ==============================================================

    /**
     * Tabellenkopfzeile wie auch der Inhalt der Tabelle wird in
     * ein csv Dokument geschrieben, welches mittels file chooser ausgewhlt wurde.
     * @param isArchivAnfrage
     *
     * @return exportierte Dokumentenname.
     */
    public String erzeugeCSV() {
        try {
            Shell      shell      = PlatformUI.getWorkbench().getActiveWorkbenchWindow().getShell();
            FileDialog fileDialog = new FileDialog(shell, SWT.SAVE);

            fileDialog.setFilterExtensions(new String[] { "*.csv" });
            fileDialog.setText("Exportieren des Tabelleninhaltes in CSV Format");
            fileDialog.setFilterPath(OrdnerEinstellungen.ermittleProjektAusgabenUnterOrdner(KonstantenGTM.ORDNER_EXPORT_CSV));

            String gewaehlteFileName = fileDialog.open();

            try {
                if (gewaehlteFileName != null) {
                    PrintWriter exportSchreiber = new PrintWriter(new FileWriter(gewaehlteFileName));

                    for (String[] a_zusatzinformationen : _zusatzinformationen) {
                        for (int i = 0; i < 2; i++) {
                            exportSchreiber.print(a_zusatzinformationen[i]);
                            exportSchreiber.print(";");
                        }

                        exportSchreiber.println();
                    }

                    int   spaltenAnzahl      = _tabellenInhalt.getTable().getColumnCount();
                    int[] spaltenreihenfolge = _tabellenInhalt.getTable().getColumnOrder();

                    for (int i = 0; i < spaltenAnzahl; i++) {
                        if (_spaltenAuswahl.contains(_tabellenKopfzeile[spaltenreihenfolge[i]])) {
                            exportSchreiber.print(_tabellenKopfzeile[spaltenreihenfolge[i]]);
                        }

                        if (i < spaltenAnzahl - 1) {
                            exportSchreiber.print(";");
                        }
                    }

                    exportSchreiber.println();

                    LinkedList<ITabellenZeile> alleZeilen = _tabellenStruktur.getZeilen();

                    for (ITabellenZeile zeilenObj : alleZeilen) {
                        for (int j = 0; j < _spaltenAuswahl.size(); j++) {
                            exportSchreiber.print(zeilenObj.getAttribut(spaltenreihenfolge[j]));

                            if (j < spaltenAnzahl - 1) {
                                exportSchreiber.print(";");
                            }
                        }

                        exportSchreiber.println();
                    }

                    exportSchreiber.close();
                }
            }
            catch (NullPointerException ex) {
                ex.printStackTrace();

                return "";
            }

            return gewaehlteFileName;
        }
        catch (Exception ex) {
            ex.printStackTrace();

            return "";
        }
    }

   
}


//~Formatiert mit 'inovat Kodierkonvention' am 03.09.10
