/*
 * @(#)DarstellungTlsSicht.java   13.03.12
 *
 * Copyright (c) 2008 by inovat, Dipl.-Ing. H. C. Kni
 * ALL RIGHTS RESERVED.
 *
 * THIS SOFTWARE IS  PROVIDED  "AS IS"  AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF  MERCHANTABILITY  AND  FITNESS  FOR  A PARTICULAR  PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL inovat OR ITS CONTRIBUTORS BE
 * LIABLE FOR ANY  DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
 * OR CONSEQUENTIAL DAMAGES  (INCL., BUT NOT LIMITED TO, PROCUREMENT
 * OF SUBSTITUTE GOODS OR SERVICES;  LOSS OF USE, DATA, OR  PROFITS;
 * OR BUSINESS INTERRUPTION)  HOWEVER  CAUSED  AND  ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,  OR TORT (INCL.
 * NEGLIGENCE OR OTHERWISE)  ARISING  IN  ANY  WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */



package de.inovat.buv.plugin.gtm.navigation.gui.sichte;

//~ NICHT JDK IMPORTE =========================================================

import de.inovat.buv.gtm.datvew.lib.DatenVew;
import de.inovat.buv.gtm.datvew.tls.De;
import de.inovat.buv.gtm.datvew.tls.Eak;
import de.inovat.buv.gtm.datvew.tls.Geraet;
import de.inovat.buv.plugin.gtm.navigation.gui.lib.IDarstellung;
import de.inovat.buv.plugin.gtm.navigation.gui.lib.LabelProviderGTM;

import org.eclipse.jface.viewers.ILabelProvider;
import org.eclipse.jface.viewers.ITreeContentProvider;
import org.eclipse.jface.viewers.Viewer;

//~ JDK IMPORTE ===============================================================

import java.util.List;

//~ KLASSEN ===================================================================

/**
 * IDarstellung-Implementation fr die "TLS Sicht".
 *
 * @author inovat
 * @author Liliya Givorgizova (LG)
 * @version $Revision: 155 $ / $Date: 2014-10-07 11:11:48 +0200 (Di, 07 Okt 2014) $ / ($Author: LG $)
 */
public class DarstellungTlsSicht implements IDarstellung {
    @Override
    public ITreeContentProvider getContentProvider() {
        return new TreeContentProviderTLS();
    }

    @Override
    public Object getInput() {
        return DatenVew.getInstanz().getListeTlsRootGeraete();
    }

    @Override
    public ILabelProvider getLabelProvider() {
        return new LabelProviderGTM();
    }

    @Override
    public String getName() {
        return "TLS Sicht";
    }

    //~ METHODEN ==============================================================

    @Override
    public boolean istDynamisch() {
        return false;
    }

    @Override
    public boolean istModellAenderungUeberwacht() {
        return false;
    }

    @Override
    public boolean istSucheEingeschaltet() {
        return true;
    }

    //~ INNERE KLASSEN ========================================================

    /**
     * TreeContentProvider fr die TLS-Sicht.
     */
    class TreeContentProviderTLS implements ITreeContentProvider {
        @Override
        public void dispose() {}

        //~ GET METHODEN ======================================================

        @Override
        public Object[] getChildren(Object parentElement) {
            if (parentElement instanceof Geraet) {
                Geraet geraet = (Geraet) parentElement;

                return geraet.ermittleKinder();
            } else if (parentElement instanceof Eak) {

                // Kindknoten eines Eak sind De
                Eak eak = (Eak) parentElement;

                return eak.getListeDe().toArray();
            } else if (parentElement instanceof De) {

                // De's haben keine Kinder
                return null;
            }

            return null;
        }

        @SuppressWarnings("unchecked")
        @Override
        public Object[] getElements(Object inputElement) {
            if (inputElement instanceof List) {
                List root = (List) inputElement;

                return root.toArray();
            }

            return null;
        }

        @Override
        public Object getParent(Object element) {
            if (element instanceof Geraet) {
                Geraet gereat = (Geraet) element;

                return gereat.getUeberGeordnetesGeraet();
            } else if (element instanceof Eak) {
                Eak eak = (Eak) element;

                return eak.getUeberGeordnetesGeraet();
            } else if (element instanceof De) {
                De de = (De) element;

                return de.getUeberGeordnetesEak();
            } else {
                return null;
            }
        }

        @Override
        public boolean hasChildren(Object element) {
            return !(element instanceof De);
        }

        //~ METHODEN ==========================================================

        @Override
        public void inputChanged(Viewer viewer, Object oldInput, Object newInput) {}
    }
}


//~Formatiert mit 'inovat Kodierkonvention' am 15.03.12
