/*
 * @(#)TreeContentProviderZs.java   13.03.12
 *
 * Copyright (c) 2008 by inovat, Dipl.-Ing. H. C. Kni
 * ALL RIGHTS RESERVED.
 *
 * THIS SOFTWARE IS  PROVIDED  "AS IS"  AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF  MERCHANTABILITY  AND  FITNESS  FOR  A PARTICULAR  PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL inovat OR ITS CONTRIBUTORS BE
 * LIABLE FOR ANY  DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
 * OR CONSEQUENTIAL DAMAGES  (INCL., BUT NOT LIMITED TO, PROCUREMENT
 * OF SUBSTITUTE GOODS OR SERVICES;  LOSS OF USE, DATA, OR  PROFITS;
 * OR BUSINESS INTERRUPTION)  HOWEVER  CAUSED  AND  ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,  OR TORT (INCL.
 * NEGLIGENCE OR OTHERWISE)  ARISING  IN  ANY  WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */



package de.inovat.buv.plugin.gtm.navigation.gui.sichte;

//~ NICHT JDK IMPORTE =========================================================

import de.inovat.buv.gtm.datvew.lib.AuswerteQuerschnitt;
import de.inovat.buv.gtm.datvew.lib.DatenVew;
import de.inovat.buv.gtm.datvew.lib.Fahrbahnen;
import de.inovat.buv.gtm.datvew.lib.Messquerschnitt;
import de.inovat.buv.gtm.datvew.lib.Strasse;
import de.inovat.buv.gtm.datvew.lib.ZaehlStelle;
import de.inovat.buv.gtm.datvew.tls.De;

import org.eclipse.jface.viewers.ITreeContentProvider;
import org.eclipse.jface.viewers.Viewer;

//~ JDK IMPORTE ===============================================================

import java.util.List;

//~ KLASSEN ===================================================================

/**
 * TreeContentProviderZs definiert die Baum-Struktur fr Zhlstellen
 * (mit und ohne Straen).
 *
 * @author inovat
 * @author Liliya Givorgizova (LG)
 * @version $Revision: 155 $ / $Date: 2014-10-07 11:11:48 +0200 (Di, 07 Okt 2014) $ / ($Author: LG $)
 */
public class TreeContentProviderZs implements ITreeContentProvider {

    /** Sicht, fr die das ContentProvider implementiert wird. */
    private Sicht _sicht;

    //~ KONSTANTE AUFZAEHLUNGSTYPEN ===========================================

    /**
     * Darstellungsicht.
     */
    enum Sicht { ZS, ZS_MIT_STRASSEN, MQ }

    //~ KONSTRUKTOREN  (und vom Konstruktor verwendete Methoden) ==============

    /**
     * Erzeugt eine Instanz der Klasse TreeContentProviderZs.
     *
     * @param sicht Sicht, fr die das ContentProvider implementiert wird.
     */
    public TreeContentProviderZs(Sicht sicht) {
        _sicht = sicht;
    }

    //~ METHODEN ==============================================================

    @Override
    public void dispose() {}

    //~ GET METHODEN ==========================================================

    @Override
    public Object[] getChildren(Object parentElement) {
        return treeZaehlStellenGetChildren(parentElement);
    }

    @SuppressWarnings("unchecked")
    @Override
    public Object[] getElements(Object inputElement) {
        if (inputElement instanceof List) {
            List root = (List) inputElement;

            return root.toArray();
        }

        return null;
    }

    @Override
    public Object getParent(Object element) {
        return treeZaehlStellenGetParent(element);
    }

    @Override
    public boolean hasChildren(Object element) {
        return treeZaehlStellenHasChildren(element);
    }

    //~ METHODEN ==============================================================

    @Override
    public void inputChanged(Viewer viewer, Object oldInput, Object newInput) {}

    /**
     * Ermittle Kinder fr das Element aus dem Baum "ZhlstelleSicht"
     *
     * @param parentElement parentElement.
     *
     * @return Array von Kindern.
     */
    private Object[] treeZaehlStellenGetChildren(Object parentElement) {
        if (parentElement instanceof Strasse) {
            Strasse           strasse = (Strasse) parentElement;
            List<ZaehlStelle> liste   = DatenVew.getInstanz().ermittleListeZaehlStellen(strasse.getSystemObjekt().getPidOrId());

            return liste.toArray();
        } else if (parentElement instanceof ZaehlStelle) {
            ZaehlStelle zs = (ZaehlStelle) parentElement;

            return zs.getArAWQ();
        } else if (parentElement instanceof AuswerteQuerschnitt) {
            AuswerteQuerschnitt awq = (AuswerteQuerschnitt) parentElement;

            return new Object[] { awq.getMessquerschnitt() };
        } else if (parentElement instanceof Messquerschnitt) {
            Messquerschnitt mq = (Messquerschnitt) parentElement;

            return mq.getArFahrbahnen();
        } else if (parentElement instanceof Fahrbahnen) {
            Fahrbahnen fs = (Fahrbahnen) parentElement;

            if (fs.getFsQuellePid() != null) {
                De de = DatenVew.getInstanz().ermittleDe(fs.getFsQuellePid());

                if (de != null) {
                    return new Object[] { de };
                }
            }
        }

        return null;
    }

    /**
     * Ermittle Parent fr das Element aus dem Baum "ZhlstelleSicht"
     *
     * @param element Element.
     *
     * @return Parent-Element.
     */
    private Object treeZaehlStellenGetParent(Object element) {
        if (element instanceof Strasse) {
            return null;
        } else if (element instanceof ZaehlStelle) {
            if (_sicht == Sicht.ZS_MIT_STRASSEN) {
                ZaehlStelle zaehlStelle = (ZaehlStelle) element;

                return zaehlStelle.getParentStrasseZuZaehlStelle();
            } else {
                return null;
            }
        } else if (element instanceof AuswerteQuerschnitt) {
            AuswerteQuerschnitt awq = (AuswerteQuerschnitt) element;

            return awq.getParentZaehlStelleZuAuswerteQuerschnitt();
        } else if (element instanceof Messquerschnitt) {
            if (_sicht == Sicht.MQ) {
                Messquerschnitt mq = (Messquerschnitt) element;

                return mq.getParentAuswerteQuerschnittZuMQ();
            } else {
                return null;
            }
        } else if (element instanceof Fahrbahnen) {
            Fahrbahnen fahrbahnen = (Fahrbahnen) element;

            return fahrbahnen.getParentMQZuEinerFahrbahn();
        } else if (element instanceof De) {
            De de = (De) element;

            return DatenVew.getInstanz().ermittleFahrbahnen(de.getSystemObjekt().getPidOrId());
        } else {
            return null;
        }
    }

    /**
     * Ermittle, ob das Element aus dem Baum "ZhlstelleSicht" Kinder hat.
     *
     * @param element Element.
     *
     * @return true, falls das Element aus dem Baum "ZhlstelleSicht" Kinder hat,
     * false - sonst.
     */
    private boolean treeZaehlStellenHasChildren(Object element) {
        return (element instanceof Strasse) ||              //
               (element instanceof ZaehlStelle) ||          //
               (element instanceof AuswerteQuerschnitt) ||  //
               (element instanceof Messquerschnitt) ||      //
               (element instanceof Fahrbahnen);
    }
}


//~Formatiert mit 'inovat Kodierkonvention' am 19.07.12
