/*
 * @(#)Zustaende.java   05.03.10
 *
 * Copyright (c) 2008 by inovat, Dipl.-Ing. H. C. Kni
 * ALL RIGHTS RESERVED.
 *
 * THIS SOFTWARE IS  PROVIDED  "AS IS"  AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF  MERCHANTABILITY  AND  FITNESS  FOR  A PARTICULAR  PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL inovat OR ITS CONTRIBUTORS BE
 * LIABLE FOR ANY  DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
 * OR CONSEQUENTIAL DAMAGES  (INCL., BUT NOT LIMITED TO, PROCUREMENT
 * OF SUBSTITUTE GOODS OR SERVICES;  LOSS OF USE, DATA, OR  PROFITS;
 * OR BUSINESS INTERRUPTION)  HOWEVER  CAUSED  AND  ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,  OR TORT (INCL.
 * NEGLIGENCE OR OTHERWISE)  ARISING  IN  ANY  WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */



package de.inovat.buv.projektlib.konstanten;

//~ NICHT JDK IMPORTE =========================================================

import de.inovat.buv.projektlib.dav.DavDatenVew;

//~ JDK IMPORTE ===============================================================

import java.util.ArrayList;
import java.util.List;

//~ KLASSEN ===================================================================

/**
 * Klasse definiert und verwaltet alle Zustnde und Konstanten von Projekt.
 *
 * @author inovat
 * @author Liliya Givorgizova (LG)
 * @version $Revision: 38 $ / $Date: 2013-10-08 15:30:34 +0200 (Di, 08 Okt 2013) $ / ($Author: LG $)
 */
public class Zustaende {

    /** Standard Name des Projekts. */
    private static final String PROJEKT_NAME_STANDARD = "inovatProjekt";

    /** Name des Projekts. */
    public static final String PROJEKT_NAME;

    //~ STATISCHE INITIALISIERER ==============================================

    static {

        // Prfe, ob der ProjektName in Aufrufparametern eingegeben ist:
        String name;
        String param = DavDatenVew.getInstanz().getAufrufParameterAlsString(AufrufParameter.PROJEKT_NAME);

        if (param != null) {
            name = param.replaceAll("[^a-zA-Z0-9-_]", "");
        } else {
            name = PROJEKT_NAME_STANDARD;
        }

        PROJEKT_NAME = name;
    }

    //~ AUFZAEHLUNGSTYPEN =====================================================

    /**
     * =============================================================================================================
     * Bundeslnder.
     * =============================================================================================================
     */
    public enum BundesLaender {
        BADEN_WUERTTENBERG("Baden-Wrttemberg", "BW"),           //
        BAYERN("BAYERN", "BY"),                                  //
        BERLIN("BERLIN", "BE"),                                  //
        BRANDERBURG("Brandenburg", "BB"),                        //
        BREMEN("Bremen", "HB"),                                  //
        HAMBURG("Hamburg", "HH"),                                //
        HESSEN("Hessen", "HE"),                                  //
        MECKLENBURG_VORPOMMERN("Mecklenburg-Vorpommern", "MV"),  //
        NIEDERSACHSEN("Niedersachsen", "NI"),                    //
        NORDRHEIN_WESTFALEN("Nordrhein-Westfalen", "NW"),        //
        RHEINLAND_PFALZ("Rheinland-Pfalz", "RP"),                //
        SAARLAND("SAARLAND", "SL"),                              //
        SACHSEN("Sachsen", "SN"),                                //
        SACHSEN_ANHALT("Sachsen-Anhalt", "ST"),                  //
        SCHLESWIG_HOLSTEIN("Schleswig-Holstein", "SH"),          //
        THUERINGEN("Thringen", "TH"),                           //

        //
        UNBEKANNT("unbekannt", "AA");

        private final String abkuerzung;
        private final String land;

        //~ KONSTRUKTOREN  (und vom Konstruktor verwendete Methoden) ==========

        BundesLaender(String land, String abkuerzung) {
            this.land       = land;
            this.abkuerzung = abkuerzung;
        }

        //~ METHODEN ==========================================================

        /**
         * Ermittle die Liste aller Bundeslnder.
         *
         * @return Liste aller Bundeslnder.
         */
        public static List<String> ermittleBundesLaender() {
            List<String> liste = new ArrayList<String>();

            for (BundesLaender bl : values()) {
                liste.add(bl.land);
            }

            return liste;
        }

        /**
         * Ermittle das Zustand 'Bundesland' fr den angegebenen Text.
         *
         * @param bl Bundeslandname oder -abkrzung.
         *
         * @return Bundesland fr den angegebenen Text oder UNBEKANNT.
         */
        public static BundesLaender ermittleBundesland(String bl) {
            for (BundesLaender blv : values()) {
                if ((blv.abkuerzung.toLowerCase().equals(bl.toLowerCase())) || (blv.land.toLowerCase().equals(bl.toLowerCase()))) {
                    return blv;
                }
            }

            return UNBEKANNT;
        }

        //~ GET METHODEN ======================================================

        public String getAbkuerzung() {
            return abkuerzung;
        }

        public String getLand() {
            return land;
        }
    }
}


//~Formatiert mit 'inovat Kodierkonvention' am 08.10.13
