/*
 * Copyright 2008 by inovat, innovative systeme - verkehr - tunnel - technik, Dipl.-Ing. H. C. Kni, Kln
 * <p>
 * This file is part of de.inovat.pat.datkat2html
 * <p>
 * de.inovat.pat.datkat2html is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * <p>
 * de.inovat.pat.datkat2html is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * <p>
 * You should have received a copy of the GNU General Public License
 * along with de.inovat.pat.datkat2html; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 * <p>
 * Contact Information:<br>
 * inovat, Dipl.-Ing. H. C. Kni<br>
 * Klner Strae 30<br>
 * 50859 Kln<br>
 * Phone: +49 2234 4301 800<br>
 * mailto: info@inovat.de
 */
package de.inovat.pat.datkat2html.ausgabe.beschreibung;

import java.util.ArrayList;
import java.util.List;

/**
 * Klasse verwaltet dtd-Element attributDefinition.
 * 
 * <!ELEMENT attributDefinition (
 * 		info,
 * 		( zeichenkette | ganzzahl | zeitstempel | objektReferenz | kommazahl ),
 * 		default? )
 * >
 * 
 * <!ELEMENT default EMPTY >
 * <!ATTLIST default
 * 		wert CDATA #REQUIRED
 * >
 * 
 * <!ELEMENT zeichenkette EMPTY >
 * <!ATTLIST zeichenkette laenge CDATA #REQUIRED >
 * <!ATTLIST zeichenkette
 * 	kodierung (ISO-8859-1|TLS-Wechseltextzeichen) "ISO-8859-1" >
 * 
 * <!ELEMENT ganzzahl ( ( bereich | zustand )+ ) >
 * <!ATTLIST ganzzahl bits CDATA #IMPLIED >
 * 
 * <!ELEMENT kommazahl  EMPTY >
 * <!ATTLIST kommazahl einheit CDATA #IMPLIED >
 * <!ATTLIST kommazahl genauigkeit (einfach|doppelt) "doppelt" >
 * 
 * <!ELEMENT zeitstempel  EMPTY >
 * <!ATTLIST zeitstempel
 * 	relativ (ja|nein) "nein"
 * 	genauigkeit (sekunden|millisekunden) "millisekunden"
 * >
 * 
 * <!ELEMENT objektReferenz EMPTY >
 * <!ATTLIST objektReferenz typ NMTOKEN #IMPLIED>
 * <!ATTLIST objektReferenz undefiniert (erlaubt|verboten) "verboten">
 * <!ATTLIST objektReferenz referenzierungsart (assoziation|aggregation|komposition) "assoziation">
 * 
 * 
 * @author inovat
 * @author Liliya Givorgizova (LG)
 * @version $Revision: 408 $ / $Date: 2010-04-06 08:14:07 +0200 (Di, 06. Apr 2010) $ / ($Author: HCK $)
 */

public class AttributDefinitionBeschreibung {
// ------------------------------------------------------------------------
// VARIABLENDEKLARATIONEN
// ------------------------------------------------------------------------

	/** Attributtyp zeichenkette. */
	public static final String ZEICHENKETTE="Zeichenkette";
	/** Attributtyp ganzzahl. */
	public static final String GANZZAHL="Ganze Zahl";
	/** Attributtyp zeitstempel. */
	public static final String ZEITSTEMPEL="Zeitstempel";
	/** Attributtyp objektReferenz. */
	public static final String OBJEKT_REFERENZ="Objektreferenz";
	/** Attributtyp kommazahl. */
	public static final String KOMMA_ZAHL="Kommazahl";
// Private ----------------------------------------------------------------
	/** bersicht der AttributDefinitionBeschreibung. */
	private Uebersicht _uebersicht;

	/**
	 * Das zwei-dimensionale  Array.
	 *
	 * Element [0][0] gleich 'typ' ist.
	 * Element [0][1] enthlt den TypNamen (siehe in dieser Klasse definierte Konstanten)
	 *
	 * Weitere Zeile enthalten die Information ber die Attributlisten (siehe DTD)
	 * und sind vom Typ abhngig, jeweils Paar (AttributName - Wert).
	 *
	 * Z.B. fr den Typ zeichenkette kann Array so aussehen:
	 *
	 * 'typ'		'zeichenkette'
	 * 'laenge'		'30'
	 * 'kodierung'	'ISO-8859-1'
	 *
	 */
	private String[][] _arrAttributTyp;

	/**
	 * Fr der Attributtyp ganzzahl definierte Bereiche.
	 */
	private List<BereichBeschreibung> _bereiche=new ArrayList<BereichBeschreibung>();
	/**
	 * Fr der Attributtyp ganzzahl definierte Zustnde.
	 */
	private List<ZustandBeschreibung> _zustaende=new ArrayList<ZustandBeschreibung>();

	/** Default (kann null sein). */
	private String _default;

// ------------------------------------------------------------------------
// STATISCHE METHODEN
// ------------------------------------------------------------------------

	/**
	 * Getter fr Eigenschaft 'zEICHENKETTE'.
	 *
	 * @return Wert der Eigenschaft 'zEICHENKETTE'.
	 *
	 * @see  {#link ZEICHENKETTE}
	 */
	public static String getZEICHENKETTE() {
		return ZEICHENKETTE;
	}

	/**
	 * Getter fr Eigenschaft 'gANZZAHL'.
	 *
	 * @return Wert der Eigenschaft 'gANZZAHL'.
	 *
	 * @see  {#link GANZZAHL}
	 */
	public static String getGANZZAHL() {
		return GANZZAHL;
	}

	/**
	 * Getter fr Eigenschaft 'zEITSTEMPEL'.
	 *
	 * @return Wert der Eigenschaft 'zEITSTEMPEL'.
	 *
	 * @see  {#link ZEITSTEMPEL}
	 */
	public static String getZEITSTEMPEL() {
		return ZEITSTEMPEL;
	}

	/**
	 * Getter fr Eigenschaft 'oBJEKT_REFERENZ'.
	 *
	 * @return Wert der Eigenschaft 'oBJEKT_REFERENZ'.
	 *
	 * @see  {#link OBJEKT_REFERENZ}
	 */
	public static String getOBJEKT_REFERENZ() {
		return OBJEKT_REFERENZ;
	}

	/**
	 * Getter fr Eigenschaft 'kOMMA_ZAHL'.
	 *
	 * @return Wert der Eigenschaft 'kOMMA_ZAHL'.
	 *
	 * @see  {#link KOMMA_ZAHL}
	 */
	public static String getKOMMA_ZAHL() {
		return KOMMA_ZAHL;
	}

// ------------------------------------------------------------------------
// KONSTRUKTOREN  (und vom Konstruktor verwende Methoden)
// ------------------------------------------------------------------------

	/**
	 * Erzeugt eine Instanz der Klasse AttributDefinitionBeschreibung.
	 *
	 * @param uebersicht
	 * @param arrAttributTyp
	 * @param bereiche
	 * @param zustaende
	 * @param default1
	 */
	public AttributDefinitionBeschreibung(Uebersicht uebersicht,
			String[][] arrAttributTyp, List<BereichBeschreibung> bereiche,
			List<ZustandBeschreibung> zustaende, String default1) {
		_uebersicht = uebersicht;
		_arrAttributTyp = arrAttributTyp;
		if(bereiche!=null){
			_bereiche = bereiche;
		}
		if(zustaende!=null){
			_zustaende = zustaende;
		}
		_default = default1;
	}

// ------------------------------------------------------------------------
// GETTER / SETTER METHODEN
// ------------------------------------------------------------------------

	/**
	 * Getter fr Eigenschaft 'arrAttributTyp'.
	 *
	 * @return Wert der Eigenschaft 'arrAttributTyp'.
	 *
	 * @see  {#link _arrAttributTyp}
	 */
	public String[][] getArrAttributTyp() {
		return _arrAttributTyp;
	}

	/**
	 * Getter fr Eigenschaft 'bereiche'.
	 *
	 * @return Wert der Eigenschaft 'bereiche'.
	 *
	 * @see  {#link _bereiche}
	 */
	public List<BereichBeschreibung> getBereiche() {
		return _bereiche;
	}

	/**
	 * Getter fr Eigenschaft 'default'.
	 *
	 * @return Wert der Eigenschaft 'default'.
	 *
	 * @see  {#link _default}
	 */
	public String getDefault() {
		return _default;
	}

	/**
	 * Getter fr Eigenschaft 'uebersicht'.
	 *
	 * @return Wert der Eigenschaft 'uebersicht'.
	 *
	 * @see  {#link _uebersicht}
	 */
	public Uebersicht getUebersicht() {
		return _uebersicht;
	}

	/**
	 * Getter fr Eigenschaft 'zustaende'.
	 *
	 * @return Wert der Eigenschaft 'zustaende'.
	 *
	 * @see  {#link _zustaende}
	 */
	public List<ZustandBeschreibung> getZustaende() {
		return _zustaende;
	}
}
